@@ -29,36 +29,27 @@ import logging
 import os
 
 from django.conf import settings
-from django.conf.urls.defaults import patterns, url, include
-from django.core.exceptions import ImproperlyConfigured
+from django.conf.urls import include  # noqa
+from django.conf.urls import patterns  # noqa
+from django.conf.urls import url  # noqa
+from django.core.exceptions import ImproperlyConfigured  # noqa
 from django.core.urlresolvers import reverse
 from django.utils.datastructures import SortedDict
-from django.utils.functional import SimpleLazyObject
-from django.utils.importlib import import_module
-from django.utils.module_loading import module_has_submodule
-from django.utils.translation import ugettext as _
+from django.utils.functional import SimpleLazyObject  # noqa
+from django.utils.importlib import import_module  # noqa
+from django.utils.module_loading import module_has_submodule  # noqa
+from django.utils.translation import ugettext_lazy as _
 
+from horizon import conf
+from horizon.decorators import _current_component  # noqa
+from horizon.decorators import require_auth  # noqa
+from horizon.decorators import require_perms  # noqa
 from horizon import loaders
-from horizon.decorators import require_auth, require_perms, _current_component
 
 
 LOG = logging.getLogger(__name__)
 
 
-# Default configuration dictionary. Do not mutate directly. Use copy.copy().
-HORIZON_CONFIG = {
-    # Allow for ordering dashboards; list or tuple if provided.
-    'dashboards': None,
-    # Name of a default dashboard; defaults to first alphabetically if None
-    'default_dashboard': None,
-    # Default redirect url for users' home
-    'user_home': settings.LOGIN_REDIRECT_URL,
-    'exceptions': {'unauthorized': [],
-                   'not_found': [],
-                   'recoverable': []}
-}
-
-
 def _decorate_urlconf(urlpatterns, decorator, *args, **kwargs):
     for pattern in urlpatterns:
         if getattr(pattern, 'callback', None):
@@ -168,7 +159,7 @@ class Registry(object):
 
 
 class Panel(HorizonComponent):
-    """ A base class for defining Horizon dashboard panels.
+    """A base class for defining Horizon dashboard panels.
 
     All Horizon dashboard panels should extend from this class. It provides
     the appropriate hooks for automatically constructing URLconfs, and
@@ -223,7 +214,7 @@ class Panel(HorizonComponent):
         return "<Panel: %s>" % self.slug
 
     def get_absolute_url(self):
-        """ Returns the default URL for this panel.
+        """Returns the default URL for this panel.
 
         The default URL is defined as the URL pattern with ``name="index"`` in
         the URLconf for this panel.
@@ -247,12 +238,12 @@ class Panel(HorizonComponent):
         _decorate_urlconf(urlpatterns, require_perms, permissions)
         _decorate_urlconf(urlpatterns, _current_component, panel=self)
 
-        # Return the three arguments to django.conf.urls.defaults.include
+        # Return the three arguments to django.conf.urls.include
         return urlpatterns, self.slug, self.slug
 
 
 class PanelGroup(object):
-    """ A container for a set of :class:`~horizon.Panel` classes.
+    """A container for a set of :class:`~horizon.Panel` classes.
 
     When iterated, it will yield each of the ``Panel`` instances it
     contains.
@@ -289,13 +280,13 @@ class PanelGroup(object):
         for name in self.panels:
             try:
                 panel_instances.append(self.dashboard.get_panel(name))
-            except NotRegistered, e:
+            except NotRegistered as e:
                 LOG.debug(e)
         return iter(panel_instances)
 
 
 class Dashboard(Registry, HorizonComponent):
-    """ A base class for defining Horizon dashboards.
+    """A base class for defining Horizon dashboards.
 
     All Horizon dashboards should extend from this base class. It provides the
     appropriate hooks for automatic discovery of :class:`~horizon.Panel`
@@ -365,9 +356,12 @@ class Dashboard(Registry, HorizonComponent):
         which are not connected to specific panels. Default: ``None``.
 
     .. attribute:: nav
+    .. method:: nav(context)
 
-        Optional boolean to control whether or not this dashboard should
-        appear in automatically-generated navigation. Default: ``True``.
+        The ``nav`` attribute can be either boolean value or a callable
+        which accepts a ``RequestContext`` object as a single argument
+        to control whether or not this dashboard should appear in
+        automatically-generated navigation. Default: ``True``.
 
     .. attribute:: supports_tenants
 
@@ -380,6 +374,7 @@ class Dashboard(Registry, HorizonComponent):
 
         Boolean value to determine whether this dashboard can be viewed
         without being logged in. Defaults to ``False``.
+
     """
     _registerable_class = Panel
     name = ''
@@ -399,15 +394,13 @@ class Dashboard(Registry, HorizonComponent):
         self._panel_groups = None
 
     def get_panel(self, panel):
-        """
-        Returns the specified :class:`~horizon.Panel` instance registered
+        """Returns the specified :class:`~horizon.Panel` instance registered
         with this dashboard.
         """
         return self._registered(panel)
 
     def get_panels(self):
-        """
-        Returns the :class:`~horizon.Panel` instances registered with this
+        """Returns the :class:`~horizon.Panel` instances registered with this
         dashboard in order, without any panel groupings.
         """
         all_panels = []
@@ -424,10 +417,11 @@ class Dashboard(Registry, HorizonComponent):
         panel_groups = []
 
         # Gather our known panels
-        for panel_group in self._panel_groups.values():
-            for panel in panel_group:
-                registered.pop(panel.__class__)
-            panel_groups.append((panel_group.slug, panel_group))
+        if self._panel_groups is not None:
+            for panel_group in self._panel_groups.values():
+                for panel in panel_group:
+                    registered.pop(panel.__class__)
+                panel_groups.append((panel_group.slug, panel_group))
 
         # Deal with leftovers (such as add-on registrations)
         if len(registered):
@@ -440,7 +434,7 @@ class Dashboard(Registry, HorizonComponent):
         return SortedDict(panel_groups)
 
     def get_absolute_url(self):
-        """ Returns the default URL for this dashboard.
+        """Returns the default URL for this dashboard.
 
         The default URL is defined as the URL pattern with ``name="index"``
         in the URLconf for the :class:`~horizon.Panel` specified by
@@ -448,7 +442,7 @@ class Dashboard(Registry, HorizonComponent):
         """
         try:
             return self._registered(self.default_panel).get_absolute_url()
-        except:
+        except Exception:
             # Logging here since this will often be called in a template
             # where the exception would be hidden.
             LOG.exception("Error reversing absolute URL for %s." % self)
@@ -465,8 +459,9 @@ class Dashboard(Registry, HorizonComponent):
             if panel.slug == self.default_panel:
                 default_panel = panel
                 continue
+            url_slug = panel.slug.replace('.', '/')
             urlpatterns += patterns('',
-                    url(r'^%s/' % panel.slug, include(panel._decorated_urls)))
+                    url(r'^%s/' % url_slug, include(panel._decorated_urls)))
         # Now the default view, which should come last
         if not default_panel:
             raise NotRegistered('The default panel "%s" is not registered.'
@@ -482,11 +477,11 @@ class Dashboard(Registry, HorizonComponent):
         _decorate_urlconf(urlpatterns, require_perms, permissions)
         _decorate_urlconf(urlpatterns, _current_component, dashboard=self)
 
-        # Return the three arguments to django.conf.urls.defaults.include
+        # Return the three arguments to django.conf.urls.include
         return urlpatterns, self.slug, self.slug
 
     def _autodiscover(self):
-        """ Discovers panels to register from the current dashboard module. """
+        """Discovers panels to register from the current dashboard module."""
         if getattr(self, "_autodiscover_complete", False):
             return
 
@@ -520,7 +515,7 @@ class Dashboard(Registry, HorizonComponent):
             try:
                 before_import_registry = copy.copy(self._registry)
                 import_module('.%s.panel' % panel, package)
-            except:
+            except Exception:
                 self._registry = before_import_registry
                 if module_has_submodule(mod, panel):
                     raise
@@ -528,7 +523,7 @@ class Dashboard(Registry, HorizonComponent):
 
     @classmethod
     def register(cls, panel):
-        """ Registers a :class:`~horizon.Panel` with this dashboard. """
+        """Registers a :class:`~horizon.Panel` with this dashboard."""
         panel_class = Horizon.register_panel(cls, panel)
         # Support template loading from panel template directories.
         panel_mod = import_module(panel.__module__)
@@ -541,7 +536,7 @@ class Dashboard(Registry, HorizonComponent):
 
     @classmethod
     def unregister(cls, panel):
-        """ Unregisters a :class:`~horizon.Panel` from this dashboard. """
+        """Unregisters a :class:`~horizon.Panel` from this dashboard."""
         success = Horizon.unregister_panel(cls, panel)
         if success:
             # Remove the panel's template directory.
@@ -557,7 +552,7 @@ class Workflow(object):
 
 
 try:
-    from django.utils.functional import empty
+    from django.utils.functional import empty  # noqa
 except ImportError:
     #Django 1.3 fallback
     empty = None
@@ -574,9 +569,19 @@ class LazyURLPattern(SimpleLazyObject):
             self._setup()
         return reversed(self._wrapped)
 
+    def __len__(self):
+        if self._wrapped is empty:
+            self._setup()
+        return len(self._wrapped)
+
+    def __getitem__(self, idx):
+        if self._wrapped is empty:
+            self._setup()
+        return self._wrapped[idx]
+
 
 class Site(Registry, HorizonComponent):
-    """ The overarching class which encompasses all dashboards and panels. """
+    """The overarching class which encompasses all dashboards and panels."""
 
     # Required for registry
     _registerable_class = Dashboard
@@ -591,9 +596,7 @@ class Site(Registry, HorizonComponent):
 
     @property
     def _conf(self):
-        conf = copy.copy(HORIZON_CONFIG)
-        conf.update(getattr(settings, 'HORIZON_CONFIG', {}))
-        return conf
+        return conf.HORIZON_CONFIG
 
     @property
     def dashboards(self):
@@ -604,11 +607,11 @@ class Site(Registry, HorizonComponent):
         return self._conf['default_dashboard']
 
     def register(self, dashboard):
-        """ Registers a :class:`~horizon.Dashboard` with Horizon."""
+        """Registers a :class:`~horizon.Dashboard` with Horizon."""
         return self._register(dashboard)
 
     def unregister(self, dashboard):
-        """ Unregisters a :class:`~horizon.Dashboard` from Horizon. """
+        """Unregisters a :class:`~horizon.Dashboard` from Horizon."""
         return self._unregister(dashboard)
 
     def registered(self, dashboard):
@@ -626,18 +629,18 @@ class Site(Registry, HorizonComponent):
         return dash_instance._unregister(panel)
 
     def get_dashboard(self, dashboard):
-        """ Returns the specified :class:`~horizon.Dashboard` instance. """
+        """Returns the specified :class:`~horizon.Dashboard` instance."""
         return self._registered(dashboard)
 
     def get_dashboards(self):
-        """ Returns an ordered tuple of :class:`~horizon.Dashboard` modules.
+        """Returns an ordered tuple of :class:`~horizon.Dashboard` modules.
 
         Orders dashboards according to the ``"dashboards"`` key in
-        ``settings.HORIZON_CONFIG`` or else returns all registered dashboards
+        ``HORIZON_CONFIG`` or else returns all registered dashboards
         in alphabetical order.
 
         Any remaining :class:`~horizon.Dashboard` classes registered with
-        Horizon but not listed in ``settings.HORIZON_CONFIG['dashboards']``
+        Horizon but not listed in ``HORIZON_CONFIG['dashboards']``
         will be appended to the end of the list alphabetically.
         """
         if self.dashboards:
@@ -658,9 +661,9 @@ class Site(Registry, HorizonComponent):
             return dashboards
 
     def get_default_dashboard(self):
-        """ Returns the default :class:`~horizon.Dashboard` instance.
+        """Returns the default :class:`~horizon.Dashboard` instance.
 
-        If ``"default_dashboard"`` is specified in ``settings.HORIZON_CONFIG``
+        If ``"default_dashboard"`` is specified in ``HORIZON_CONFIG``
         then that dashboard will be returned. If not, the first dashboard
         returned by :func:`~horizon.get_dashboards` will be returned.
         """
@@ -672,7 +675,7 @@ class Site(Registry, HorizonComponent):
             raise NotRegistered("No dashboard modules have been registered.")
 
     def get_user_home(self, user):
-        """ Returns the default URL for a particular user.
+        """Returns the default URL for a particular user.
 
         This method can be used to customize where a user is sent when
         they log in, etc. By default it returns the value of
@@ -680,7 +683,7 @@ class Site(Registry, HorizonComponent):
 
         An alternative function can be supplied to customize this behavior
         by specifying a either a URL or a function which returns a URL via
-        the ``"user_home"`` key in ``settings.HORIZON_CONFIG``. Each of these
+        the ``"user_home"`` key in ``HORIZON_CONFIG``. Each of these
         would be valid::
 
             {"user_home": "/home",}  # A URL
@@ -710,7 +713,7 @@ class Site(Registry, HorizonComponent):
             return self.get_absolute_url()
 
     def get_absolute_url(self):
-        """ Returns the default URL for Horizon's URLconf.
+        """Returns the default URL for Horizon's URLconf.
 
         The default URL is determined by calling
         :meth:`~horizon.Dashboard.get_absolute_url`
@@ -721,7 +724,7 @@ class Site(Registry, HorizonComponent):
 
     @property
     def _lazy_urls(self):
-        """ Lazy loading for URL patterns.
+        """Lazy loading for URL patterns.
 
         This method avoids problems associated with attempting to evaluate
         the the URLconf before the settings module has been loaded.
@@ -732,7 +735,7 @@ class Site(Registry, HorizonComponent):
         return LazyURLPattern(url_patterns), self.namespace, self.slug
 
     def _urls(self):
-        """ Constructs the URLconf for Horizon from registered Dashboards. """
+        """Constructs the URLconf for Horizon from registered Dashboards."""
         urlpatterns = self._get_default_urlpatterns()
         self._autodiscover()
 
@@ -740,10 +743,12 @@ class Site(Registry, HorizonComponent):
         for dash in self._registry.values():
             dash._autodiscover()
 
+        # Load the plugin-based panel configuration
+        self._load_panel_customization()
+
         # Allow for override modules
-        config = getattr(settings, "HORIZON_CONFIG", {})
-        if config.get("customization_module", None):
-            customization_module = config["customization_module"]
+        if self._conf.get("customization_module", None):
+            customization_module = self._conf["customization_module"]
             bits = customization_module.split('.')
             mod_name = bits.pop()
             package = '.'.join(bits)
@@ -751,7 +756,7 @@ class Site(Registry, HorizonComponent):
             try:
                 before_import_registry = copy.copy(self._registry)
                 import_module('%s.%s' % (package, mod_name))
-            except:
+            except Exception:
                 self._registry = before_import_registry
                 if module_has_submodule(mod, mod_name):
                     raise
@@ -761,11 +766,11 @@ class Site(Registry, HorizonComponent):
             urlpatterns += patterns('',
                     url(r'^%s/' % dash.slug, include(dash._decorated_urls)))
 
-        # Return the three arguments to django.conf.urls.defaults.include
+        # Return the three arguments to django.conf.urls.include
         return urlpatterns, self.namespace, self.slug
 
     def _autodiscover(self):
-        """ Discovers modules to register from ``settings.INSTALLED_APPS``.
+        """Discovers modules to register from ``settings.INSTALLED_APPS``.
 
         This makes sure that the appropriate modules get imported to register
         themselves with Horizon.
@@ -781,15 +786,112 @@ class Site(Registry, HorizonComponent):
                 try:
                     before_import_registry = copy.copy(self._registry)
                     import_module('%s.%s' % (app, mod_name))
-                except:
+                except Exception:
                     self._registry = before_import_registry
                     if module_has_submodule(mod, mod_name):
                         raise
 
+    def _load_panel_customization(self):
+        """Applies the plugin-based panel configurations.
+
+        This method parses the panel customization from the ``HORIZON_CONFIG``
+        and make changes to the dashboard accordingly.
+
+        It supports adding, removing and setting default panels on the
+        dashboard. It also support registering a panel group.
+        """
+        panel_customization = self._conf.get("panel_customization", [])
+
+        for config in panel_customization:
+            if config.get('PANEL'):
+                self._process_panel_configuration(config)
+            elif config.get('PANEL_GROUP'):
+                self._process_panel_group_configuration(config)
+            else:
+                LOG.warning("Skipping %s because it doesn't have PANEL or "
+                            "PANEL_GROUP defined.", config.__name__)
+
+    def _process_panel_configuration(self, config):
+        """Add, remove and set default panels on the dashboard."""
+        try:
+            dashboard = config.get('PANEL_DASHBOARD')
+            if not dashboard:
+                LOG.warning("Skipping %s because it doesn't have "
+                            "PANEL_DASHBOARD defined.", config.__name__)
+                return
+            panel_slug = config.get('PANEL')
+            dashboard_cls = self.get_dashboard(dashboard)
+            panel_group = config.get('PANEL_GROUP')
+            default_panel = config.get('DEFAULT_PANEL')
+
+            # Set the default panel
+            if default_panel:
+                dashboard_cls.default_panel = default_panel
+
+            # Remove the panel
+            if config.get('REMOVE_PANEL', False):
+                for panel in dashboard_cls.get_panels():
+                    if panel_slug == panel.slug:
+                        dashboard_cls.unregister(panel.__class__)
+            elif config.get('ADD_PANEL', None):
+                # Add the panel to the dashboard
+                panel_path = config['ADD_PANEL']
+                mod_path, panel_cls = panel_path.rsplit(".", 1)
+                try:
+                    mod = import_module(mod_path)
+                except ImportError:
+                    LOG.warning("Could not load panel: %s", mod_path)
+                    return
+
+                panel = getattr(mod, panel_cls)
+                dashboard_cls.register(panel)
+                if panel_group:
+                    dashboard_cls.get_panel_group(panel_group).\
+                        panels.append(panel.slug)
+                else:
+                    panels = list(dashboard_cls.panels)
+                    panels.append(panel)
+                    dashboard_cls.panels = tuple(panels)
+        except Exception as e:
+            LOG.warning('Could not process panel %(panel)s: %(exc)s',
+                        {'panel': panel_slug, 'exc': e})
+
+    def _process_panel_group_configuration(self, config):
+        """Adds a panel group to the dashboard."""
+        panel_group_slug = config.get('PANEL_GROUP')
+        try:
+            dashboard = config.get('PANEL_GROUP_DASHBOARD')
+            if not dashboard:
+                LOG.warning("Skipping %s because it doesn't have "
+                            "PANEL_GROUP_DASHBOARD defined.", config.__name__)
+                return
+            dashboard_cls = self.get_dashboard(dashboard)
+
+            panel_group_name = config.get('PANEL_GROUP_NAME')
+            if not panel_group_name:
+                LOG.warning("Skipping %s because it doesn't have "
+                            "PANEL_GROUP_NAME defined.", config.__name__)
+                return
+            # Create the panel group class
+            panel_group = type(panel_group_slug,
+                               (PanelGroup, ),
+                               {'slug': panel_group_slug,
+                                'name': panel_group_name},)
+            # Add the panel group to dashboard
+            panels = list(dashboard_cls.panels)
+            panels.append(panel_group)
+            dashboard_cls.panels = tuple(panels)
+            # Trigger the autodiscovery to completely load the new panel group
+            dashboard_cls._autodiscover_complete = False
+            dashboard_cls._autodiscover()
+        except Exception as e:
+            LOG.warning('Could not process panel group %(panel_group)s: '
+                        '%(exc)s',
+                        {'panel_group': panel_group_slug, 'exc': e})
+
 
 class HorizonSite(Site):
-    """
-    A singleton implementation of Site such that all dealings with horizon
+    """A singleton implementation of Site such that all dealings with horizon
     get the same instance no matter what. There can be only one.
     """
     _instance = None
