@@ -25,7 +25,7 @@ import json
 import logging
 import time
 
-from django.conf import settings  # noqa
+from django.conf import settings
 from django.contrib.auth import REDIRECT_FIELD_NAME  # noqa
 from django.contrib.auth.views import redirect_to_login  # noqa
 from django.contrib import messages as django_messages
@@ -34,7 +34,7 @@ from django.http import HttpResponseRedirect  # noqa
 from django import shortcuts
 from django.utils.encoding import iri_to_uri  # noqa
 from django.utils import timezone
-from django.utils.translation import ugettext_lazy as _  # noqa
+from django.utils.translation import ugettext_lazy as _
 
 from horizon import exceptions
 from horizon.utils import functions as utils
@@ -43,12 +43,12 @@ LOG = logging.getLogger(__name__)
 
 
 class HorizonMiddleware(object):
-    """ The main Horizon middleware class. Required for use of Horizon. """
+    """The main Horizon middleware class. Required for use of Horizon."""
 
     logout_reason = None
 
     def process_request(self, request):
-        """ Adds data necessary for Horizon to function to the request. """
+        """Adds data necessary for Horizon to function to the request."""
         # Activate timezone handling
         tz = request.session.get('django_timezone')
         if tz:
@@ -65,6 +65,44 @@ class HorizonMiddleware(object):
         request.horizon = {'dashboard': None,
                            'panel': None,
                            'async_messages': []}
+
+        if not hasattr(request, "user") or not request.user.is_authenticated():
+            # proceed no further if the current request is already known
+            # not to be authenticated
+            return None
+
+        # If we use cookie-based sessions, check that the cookie size does not
+        # reach the max size accepted by common web browsers.
+        if (
+            settings.SESSION_ENGINE ==
+            'django.contrib.sessions.backends.signed_cookies'
+        ):
+            max_cookie_size = getattr(
+                settings, 'SESSION_COOKIE_MAX_SIZE', None)
+            session_cookie_name = getattr(
+                settings, 'SESSION_COOKIE_NAME', None)
+            session_key = request.COOKIES.get(session_cookie_name)
+            if max_cookie_size is not None and session_key is not None:
+                cookie_size = sum((
+                    len(key) + len(value)
+                    for key, value in request.COOKIES.iteritems()
+                ))
+                if cookie_size >= max_cookie_size:
+                    LOG.error(
+                        'Total Cookie size for user_id: %(user_id)s is '
+                        '%(cookie_size)sB >= %(max_cookie_size)sB. '
+                        'You need to configure file-based or database-backed '
+                        'sessions instead of cookie-based sessions: '
+                        'http://docs.openstack.org/developer/horizon/topics/'
+                        'deployment.html#session-storage'
+                        % {
+                            'user_id': request.session.get(
+                                'user_id', 'Unknown'),
+                            'cookie_size': cookie_size,
+                            'max_cookie_size': max_cookie_size,
+                        }
+                    )
+
         if (isinstance(last_activity, int)
                 and (timestamp - last_activity) > timeout):
             request.session.pop('last_activity')
@@ -76,8 +114,7 @@ class HorizonMiddleware(object):
         request.session['last_activity'] = timestamp
 
     def process_exception(self, request, exception):
-        """
-        Catches internal Horizon exception classes such as NotAuthorized,
+        """Catches internal Horizon exception classes such as NotAuthorized,
         NotFound and Http302 and handles them gracefully.
         """
         if isinstance(exception, (exceptions.NotAuthorized,
@@ -109,11 +146,10 @@ class HorizonMiddleware(object):
             return shortcuts.redirect(exception.location)
 
     def process_response(self, request, response):
-        """
-        Convert HttpResponseRedirect to HttpResponse if request is via ajax
+        """Convert HttpResponseRedirect to HttpResponse if request is via ajax
         to allow ajax request to redirect url
         """
-        if request.is_ajax():
+        if request.is_ajax() and hasattr(request, 'horizon'):
             queued_msgs = request.horizon['async_messages']
             if type(response) == http.HttpResponseRedirect:
                 # Drop our messages back into the session as per usual so they
