@@ -5,7 +5,7 @@ horizon.instances = {
 
   getConsoleLog: function(via_user_submit) {
     var form_element = $("#tail_length"),
-        data;
+      data;
 
     if (!via_user_submit) {
       via_user_submit = false;
@@ -38,7 +38,7 @@ horizon.instances = {
    * network id for network_id.
    **/
   get_network_element: function(network_id) {
-      return $('li > label[for^="id_network_' + network_id + '"]');
+    return $('li > label[for^="id_network_' + network_id + '"]');
   },
 
   /*
@@ -51,15 +51,8 @@ horizon.instances = {
     $(this.get_network_element("")).each(function(){
       var $this = $(this);
       var $input = $this.children("input");
-      var name = $this.text().replace(/^\s+/,"")
-                             .replace(/&/g, '&amp;')
-                             .replace(/</g, '&lt;')
-                             .replace(/>/g, '&gt;')
-                             .replace(/"/g, '&quot;')
-                             .replace(/'/g, '&#x27;')
-                             .replace(/\//g, '&#x2F;');
       var network_property = {
-        name:name,
+        name:$this.text().replace(/^\s+/,""),
         id:$input.attr("id"),
         value:$input.attr("value")
       };
@@ -94,13 +87,13 @@ horizon.instances = {
       $("#networkListId div.input input:checkbox").removeAttr('checked');
       active_networks.each(function(index, value){
         $("#networkListId div.input input:checkbox[value=" + value + "]")
-        .attr('checked','checked')
-        .parents("li").attr('data-index',index);
+          .attr('checked','checked')
+          .parents("li").attr('data-index',index);
       });
       $("#networkListId div.input ul").html(
         lists.sort(function(a,b){
-          if( $(a).data("index") < $(b).data("index")) return -1;
-          if( $(a).data("index") > $(b).data("index")) return 1;
+          if( $(a).data("index") < $(b).data("index")) { return -1; }
+          if( $(a).data("index") > $(b).data("index")) { return 1; }
           return 0;
         })
       );
@@ -134,19 +127,19 @@ horizon.instances = {
     });
     if ($("#networkListId > div.control-group.error").length > 0) {
       var errortext = $("#networkListId > div.control-group.error").find("span.help-inline").text();
-      $("#selected_network_h4").before($('<div class="dynamic-error">').html(errortext));
+      $("#selected_network_label").before($('<div class="dynamic-error">').html(errortext));
     }
     $(".networklist").sortable({
-        connectWith: "ul.networklist",
-        placeholder: "ui-state-highlight",
-        distance: 5,
-        start:function(e,info){
-          $("#selected_network").addClass("dragging");
-        },
-        stop:function(e,info){
-          $("#selected_network").removeClass("dragging");
-          updateForm();
-        }
+      connectWith: "ul.networklist",
+      placeholder: "ui-state-highlight",
+      distance: 5,
+      start:function(e,info){
+        $("#selected_network").addClass("dragging");
+      },
+      stop:function(e,info){
+        $("#selected_network").removeClass("dragging");
+        updateForm();
+      }
     }).disableSelection();
   },
 
@@ -168,7 +161,7 @@ horizon.addInitFunction(function () {
   // Handle field toggles for the Launch Instance source type field
   function update_launch_source_displayed_fields (field) {
     var $this = $(field),
-        base_type = $this.val();
+      base_type = $this.val();
 
     $this.closest(".control-group").nextAll().hide();
 
@@ -210,7 +203,7 @@ horizon.addInitFunction(function () {
   // Handle field toggles for the Launch Instance volume type field
   function update_image_id_fields (field) {
     var $this = $(field),
-        volume_opt = $this.val();
+      volume_opt = $this.val();
     var $option = $this.find("option:selected");
     var $form = $this.closest('form');
     var $volSize = $form.find('input#id_volume_size');
@@ -220,4 +213,62 @@ horizon.addInitFunction(function () {
   $(document).on('change', '.workflow #id_image_id', function (evt) {
     update_image_id_fields(this);
   });
+
+  horizon.instances.decrypt_password = function(encrypted_password, private_key) {
+    var crypt = new JSEncrypt();
+    crypt.setKey(private_key);
+    return crypt.decrypt(encrypted_password);
+  };
+
+  $(document).on('change', '#id_private_key_file', function (evt) {
+    var file = evt.target.files[0];
+    var reader = new FileReader();
+    if (file) {
+      reader.onloadend = function(event) {
+        $("#id_private_key").val(event.target.result);
+      };
+      reader.onerror = function(event) {
+        horizon.clearErrorMessages();
+        horizon.alert('error', gettext('Could not read the file'));
+      };
+      reader.readAsText(file);
+    }
+    else {
+      horizon.clearErrorMessages();
+      horizon.alert('error', gettext('Could not decrypt the password'));
+    }
+  });
+  /*
+    The font-family is changed because with the default policy the major I
+    and minor the l cannot be distinguished.
+  */
+  $(document).on('show', '#password_instance_modal', function (evt) {
+    $("#id_decrypted_password").css("font-family","monospace");
+    $("#id_decrypted_password").css("cursor","text");
+    $("#id_encrypted_password").css("cursor","text");
+    $("#id_keypair_name").css("cursor","text");
+  });
+
+  $(document).on('click', '#decryptpassword_button', function (evt) {
+    encrypted_password = $("#id_encrypted_password").val();
+    private_key = $('#id_private_key').val();
+    if (!private_key) {
+      evt.preventDefault();
+      $(this).closest('.modal').modal('hide');
+    }
+    else {
+      if (private_key.length > 0) {
+        evt.preventDefault();
+        decrypted_password = horizon.instances.decrypt_password(encrypted_password, private_key);
+        if (decrypted_password === false || decrypted_password === null) {
+          horizon.clearErrorMessages();
+          horizon.alert('error', gettext('Could not decrypt the password'));
+        }
+        else {
+          $("#id_decrypted_password").val(decrypted_password);
+          $("#decryptpassword_button").hide();
+        }
+      }
+    }
+  });
 });
