@@ -4,8 +4,8 @@ horizon.datatables = {
     var $rows_to_update = $('tr.status_unknown.ajax-update');
     if ($rows_to_update.length) {
       var interval = $rows_to_update.attr('data-update-interval'),
-          $table = $rows_to_update.closest('table'),
-          decay_constant = $table.attr('decay_constant');
+        $table = $rows_to_update.closest('table'),
+        decay_constant = $table.attr('decay_constant');
 
       // Do not update this row if the action column is expanded
       if ($rows_to_update.find('.actions_column .btn-group.open').length) {
@@ -18,7 +18,7 @@ horizon.datatables = {
       // Trigger the update handlers.
       $rows_to_update.each(function(index, row) {
         var $row = $(this),
-            $table = $row.closest('table.datatable');
+          $table = $row.closest('table.datatable');
         horizon.ajax.queue({
           url: $row.attr('data-update-url'),
           error: function (jqXHR, textStatus, errorThrown) {
@@ -34,7 +34,10 @@ horizon.datatables = {
                 if(row_count === 0) {
                   colspan = $table.find('th[colspan]').attr('colspan');
                   template = horizon.templates.compiled_templates["#empty_row_template"];
-                  params = {"colspan": colspan};
+                  params = {
+                      "colspan": colspan,
+                      no_items_label: gettext("No items to display.")
+                  };
                   empty_row = template.render(params);
                   $row.replaceWith(empty_row);
                 } else {
@@ -56,29 +59,29 @@ horizon.datatables = {
             if ($new_row.hasClass('status_unknown')) {
               var spinner_elm = $new_row.find("td.status_unknown:last");
 
-              if ($new_row.find('a.btn-action-required').length > 0) {
+              if ($new_row.find('.btn-action-required').length > 0) {
                 spinner_elm.prepend(
-                     $("<div />")
-                     .addClass("action_required_img")
-                     .append(
-                         $("<img />")
-                         .attr("src", "/static/dashboard/img/action_required.png")));
+                  $("<div />")
+                    .addClass("action_required_img")
+                    .append(
+                      $("<img />")
+                        .attr("src", "/static/dashboard/img/action_required.png")));
               } else {
                 // Replacing spin.js here with an animated gif to reduce CPU
                 spinner_elm.prepend(
-                     $("<div />")
-                     .addClass("loading_gif")
-                     .append(
-                         $("<img />")
-                         .attr("src", "/static/dashboard/img/loading.gif")));
+                  $("<div />")
+                    .addClass("loading_gif")
+                    .append(
+                      $("<img />")
+                        .attr("src", "/static/dashboard/img/loading.gif")));
               }
             }
 
             // Only replace row if the html content has changed
-            if($new_row.html() != $row.html()) {
-              if($row.find(':checkbox').is(':checked')) {
+            if($new_row.html() !== $row.html()) {
+              if($row.find('.table-row-multi-select:checkbox').is(':checked')) {
                 // Preserve the checkbox if it's already clicked
-                $new_row.find(':checkbox').prop('checked', true);
+                $new_row.find('.table-row-multi-select:checkbox').prop('checked', true);
               }
               $row.replaceWith($new_row);
               // Reset tablesorter's data cache.
@@ -90,36 +93,34 @@ horizon.datatables = {
           complete: function (jqXHR, textStatus) {
             // Revalidate the button check for the updated table
             horizon.datatables.validate_button();
+
+            // Set interval decay to this table, and increase if it already exist
+            if(decay_constant === undefined) {
+              decay_constant = 1;
+            } else {
+              decay_constant++;
+            }
+            $table.attr('decay_constant', decay_constant);
+            // Poll until there are no rows in an "unknown" state on the page.
+            next_poll = interval * decay_constant;
+            // Limit the interval to 30 secs
+            if(next_poll > 30 * 1000) { next_poll = 30 * 1000; }
+            setTimeout(horizon.datatables.update, next_poll);
           }
         });
       });
-
-      // Set interval decay to this table, and increase if it already exist
-      if(decay_constant === undefined) {
-        decay_constant = 1;
-      } else {
-        decay_constant++;
-      }
-      $table.attr('decay_constant', decay_constant);
-      // Poll until there are no rows in an "unknown" state on the page.
-      next_poll = interval * decay_constant;
-      // Limit the interval to 30 secs
-      if(next_poll > 30 * 1000) next_poll = 30 * 1000;
-      setTimeout(horizon.datatables.update, next_poll);
     }
   },
 
   validate_button: function () {
     // Disable form button if checkbox are not checked
     $("form").each(function (i) {
-      var checkboxes = $(this).find(":checkbox");
-      if(!checkboxes.length) {
-        // Do nothing if no checkboxes in this form
-        return;
-      }
-      if(!checkboxes.filter(":checked").length) {
-        $(this).find(".table_actions button.btn-danger").addClass("disabled");
-      }
+      var checkboxes = $(this).find(".table-row-multi-select:checkbox");
+      var action_buttons = $(this).find(".table_actions button.btn-danger");
+
+      // Buttons should be enabled only if there are checked checkboxes
+      action_buttons.toggleClass("disabled",
+                                 !checkboxes.filter(":checked").length);
     });
   }
 };
@@ -127,10 +128,10 @@ horizon.datatables = {
 /* Generates a confirmation modal dialog for the given action. */
 horizon.datatables.confirm = function (action) {
   var $action = $(action),
-      $modal_parent = $(action).closest('.modal'),
-      name_array = new Array(),
-      closest_table_id, action_string, name_string,
-      title, body, modal, form;
+    $modal_parent = $(action).closest('.modal'),
+    name_array = [],
+    closest_table_id, action_string, name_string,
+    title, body, modal, form;
   if($action.hasClass("disabled")) {
     return;
   }
@@ -142,7 +143,7 @@ horizon.datatables.confirm = function (action) {
   if ($("#"+closest_table_id+" tr[data-display]").length > 0) {
     if($(action).closest("div").hasClass("table_actions")) {
       // One or more checkboxes selected
-      $("#"+closest_table_id+" tr[data-display]").has(":checkbox:checked").each(function() {
+      $("#"+closest_table_id+" tr[data-display]").has(".table-row-multi-select:checkbox:checked").each(function() {
         name_array.push(" \"" + $(this).attr("data-display") + "\"");
       });
       name_array.join(", ");
@@ -175,25 +176,46 @@ horizon.datatables.confirm = function (action) {
 };
 
 $.tablesorter.addParser({
-    // set a unique id
-    id: 'sizeSorter',
-    is: function(s) {
-        // Not an auto-detected parser
-        return false;
-    },
-    // compare int values
-    format: function(s) {
-      var sizes = {BYTE: 0, B: 0, KB: 1, MB: 2,
-                   GB: 3, TB: 4, PB: 5};
-      var regex = /([\d\.,]+)\s*(byte|B|KB|MB|GB|TB|PB)+/i;
-      var match = s.match(regex);
-      if (match && match.length === 3){
-        return parseFloat(match[1]) *
-                          Math.pow(1024, sizes[match[2].toUpperCase()]);
-      }
-      return parseInt(s, 10);
-    },
-    type: 'numeric'
+  // set a unique id
+  id: 'sizeSorter',
+  is: function(s) {
+    // Not an auto-detected parser
+    return false;
+  },
+  // compare int values
+  format: function(s) {
+    var sizes = {
+      BYTE: 0,
+      B: 0,
+      KB: 1,
+      MB: 2,
+      GB: 3,
+      TB: 4,
+      PB: 5
+    };
+    var regex = /([\d\.,]+)\s*(byte|B|KB|MB|GB|TB|PB)+/i;
+    var match = s.match(regex);
+    if (match && match.length === 3){
+      return parseFloat(match[1]) *
+        Math.pow(1024, sizes[match[2].toUpperCase()]);
+    }
+    return parseInt(s, 10);
+  },
+  type: 'numeric'
+});
+
+$.tablesorter.addParser({
+  // set a unique id
+  id: 'timesinceSorter',
+  is: function(s) {
+    // Not an auto-detected parser
+    return false;
+  },
+  // compare int values
+  format: function(s, table, cell, cellIndex) {
+    return $(cell).find('span').data('seconds');
+  },
+  type: 'numeric'
 });
 
 horizon.datatables.disable_buttons = function() {
@@ -205,7 +227,7 @@ horizon.datatables.disable_buttons = function() {
 
 horizon.datatables.update_footer_count = function (el, modifier) {
   var $el = $(el),
-      $browser, $footer, row_count, footer_text_template, footer_text;
+    $browser, $footer, row_count, footer_text_template, footer_text;
   if (!modifier) {
     modifier = 0;
   }
@@ -229,7 +251,10 @@ horizon.datatables.add_no_results_row = function (table) {
   template = horizon.templates.compiled_templates["#empty_row_template"];
   if (!table.find("tbody tr:visible").length && typeof(template) !== "undefined") {
     colspan = table.find("th[colspan]").attr('colspan');
-    params = {"colspan": colspan};
+    params = {
+        "colspan": colspan,
+        no_items_label: gettext("No items to display.")
+    };
     table.find("tbody").append(template.render(params));
   }
 };
@@ -240,50 +265,52 @@ horizon.datatables.remove_no_results_row = function (table) {
 
 /*
  * Fixes the striping of the table after filtering results.
-**/
+ **/
 horizon.datatables.fix_row_striping = function (table) {
   table.trigger('applyWidgetId', ['zebra']);
 };
 
 horizon.datatables.set_table_sorting = function (parent) {
 // Function to initialize the tablesorter plugin strictly on sortable columns.
-$(parent).find("table.datatable").each(function () {
-  var $table = $(this),
+  $(parent).find("table.datatable").each(function () {
+    var $table = $(this),
       header_options = {};
-  // Disable if not sortable or has <= 1 item
-  if ($table.find('tbody tr').not('.empty').length > 1){
-    $table.find("thead th[class!='table_header']").each(function (i, val) {
-      $th = $(this);
-      if (!$th.hasClass('sortable')) {
-        header_options[i] = {sorter: false};
-      } else if ($th.data('type') == 'size'){
-        header_options[i] = {sorter: 'sizeSorter'};
-      } else if ($th.data('type') == 'ip'){
-        header_options[i] = {sorter: 'ipAddress'};
-      }
-    });
-    $table.tablesorter({
-      headers: header_options,
-      widgets: ['zebra'],
-      selectorHeaders: "thead th[class!='table_header']",
-      cancelSelection: false
-    });
-  }
-});
+    // Disable if not sortable or has <= 1 item
+    if ($table.find('tbody tr').not('.empty').length > 1){
+      $table.find("thead th[class!='table_header']").each(function (i, val) {
+        $th = $(this);
+        if (!$th.hasClass('sortable')) {
+          header_options[i] = {sorter: false};
+        } else if ($th.data('type') === 'size'){
+          header_options[i] = {sorter: 'sizeSorter'};
+        } else if ($th.data('type') === 'ip'){
+          header_options[i] = {sorter: 'ipAddress'};
+        } else if ($th.data('type') === 'timesince'){
+          header_options[i] = {sorter: 'timesinceSorter'};
+        }
+      });
+      $table.tablesorter({
+        headers: header_options,
+        widgets: ['zebra'],
+        selectorHeaders: "thead th[class!='table_header']",
+        cancelSelection: false
+      });
+    }
+  });
 };
 
 horizon.datatables.add_table_checkboxes = function(parent) {
   $(parent).find('table thead .multi_select_column').each(function(index, thead) {
-    if (!$(thead).find(':checkbox').length &&
-        $(thead).parents('table').find('tbody :checkbox').length) {
-      $(thead).append('<input type="checkbox">');
+    if (!$(thead).find('.table-row-multi-select:checkbox').length &&
+      $(thead).parents('table').find('tbody .table-row-multi-select:checkbox').length) {
+      $(thead).append('<input type="checkbox" class="table-row-multi-select">');
     }
   });
 };
 
 horizon.datatables.set_table_query_filter = function (parent) {
   $(parent).find('table').each(function (index, elm) {
-    var input = $($(elm).find('div.table_search input')),
+    var input = $($(elm).find('div.table_search.client input')),
         table_selector;
     if (input.length > 0) {
       // Disable server-side searcing if we have client-side searching since
@@ -345,7 +372,7 @@ horizon.datatables.set_table_fixed_filter = function (parent) {
     });
     $(elm).find('div.table_filter button').each(function (i, button) {
       // Select the first non-empty category
-      if ($(button).text().indexOf(' (0)') == -1) {
+      if ($(button).text().indexOf(' (0)') === -1) {
         $(button).addClass('active');
         $(button).trigger('click');
         return false;
@@ -361,24 +388,24 @@ horizon.addInitFunction(function() {
     horizon.datatables.update_footer_count($(el), 0);
   });
   // Bind the "select all" checkbox action.
-  $('div.table_wrapper, #modal_wrapper').on('click', 'table thead .multi_select_column :checkbox', function(evt) {
+  $('div.table_wrapper, #modal_wrapper').on('click', 'table thead .multi_select_column .table-row-multi-select:checkbox', function(evt) {
     var $this = $(this),
-        $table = $this.closest('table'),
-        is_checked = $this.prop('checked'),
-        checkboxes = $table.find('tbody :visible:checkbox');
+      $table = $this.closest('table'),
+      is_checked = $this.prop('checked'),
+      checkboxes = $table.find('tbody .table-row-multi-select:visible:checkbox');
     checkboxes.prop('checked', is_checked);
   });
   // Change "select all" checkbox behaviour while any checkbox is checked/unchecked.
-  $("div.table_wrapper, #modal_wrapper").on("click", 'table tbody :checkbox', function (evt) {
+  $("div.table_wrapper, #modal_wrapper").on("click", 'table tbody .table-row-multi-select:checkbox', function (evt) {
     var $table = $(this).closest('table');
-    var $multi_select_checkbox = $table.find('thead .multi_select_column :checkbox'); 
-    var any_unchecked = $table.find("tbody :checkbox").not(":checked");
-    $multi_select_checkbox.prop('checked', !(any_unchecked.length > 0));
+    var $multi_select_checkbox = $table.find('thead .multi_select_column .table-row-multi-select:checkbox');
+    var any_unchecked = $table.find("tbody .table-row-multi-select:checkbox").not(":checked");
+    $multi_select_checkbox.prop('checked', any_unchecked.length === 0);
   });
   // Enable dangerous buttons only if one or more checkbox is checked.
-  $("div.table_wrapper, #modal_wrapper").on("click", ':checkbox', function (evt) {
+  $("div.table_wrapper, #modal_wrapper").on("click", '.table-row-multi-select:checkbox', function (evt) {
     var $form = $(this).closest("form");
-    var any_checked = $form.find("tbody :checkbox").is(":checked");
+    var any_checked = $form.find("tbody .table-row-multi-select:checkbox").is(":checked");
     if(any_checked) {
       $form.find(".table_actions button.btn-danger").removeClass("disabled");
     }else {
@@ -398,5 +425,11 @@ horizon.addInitFunction(function() {
   horizon.modals.addModalInitFunction(horizon.datatables.set_table_query_filter);
   horizon.modals.addModalInitFunction(horizon.datatables.set_table_fixed_filter);
 
+  // Also apply on tables in tabs views for lazy-loaded data.
+  horizon.tabs.addTabLoadFunction(horizon.datatables.add_table_checkboxes);
+  horizon.tabs.addTabLoadFunction(horizon.datatables.set_table_sorting);
+  horizon.tabs.addTabLoadFunction(horizon.datatables.set_table_query_filter);
+  horizon.tabs.addTabLoadFunction(horizon.datatables.set_table_fixed_filter);
+
   horizon.datatables.update();
 });
