@@ -1,6 +1,6 @@
 /* Namespace for core functionality related to client-side templating. */
 horizon.templates = {
-  template_ids: ["#modal_template", "#empty_row_template", "#alert_message_template", "#spinner-modal", "#project_user_template"],
+  template_ids: ["#modal_template", "#empty_row_template", "#alert_message_template", "#spinner-modal", "#membership_template"],
   compiled_templates: {}
 };
 
