@@ -22,9 +22,10 @@
 Template tags for customizing Horizon.
 """
 
-from django import template
 from django.conf import settings
-from django.utils.translation import ugettext as _
+from django.core.urlresolvers import reverse
+from django import template
+from django.utils.translation import ugettext_lazy as _
 
 
 register = template.Library()
@@ -45,6 +46,12 @@ def site_title(parser, token):
     return settings.SITE_BRANDING
 
 
+@register.simple_tag
+def site_branding_link():
+    return getattr(settings, "SITE_BRANDING_LINK",
+                   reverse("horizon:user_home"))
+
+
 # TODO(jeffjapan): This is just an assignment tag version of the above, replace
 #                  when the dashboard is upgraded to a django version that
 #                  supports the @assignment_tag decorator syntax instead.
