@@ -32,8 +32,8 @@ register = template.Library()
 
 class ParseDateNode(template.Node):
     def render(self, datestring):
-        """
-        Parses a date-like input string into a timezone aware Python datetime.
+        """Parses a date-like input string into a timezone aware Python
+        datetime.
         """
         formats = ["%Y-%m-%dT%H:%M:%S.%f", "%Y-%m-%d %H:%M:%S.%f",
                 "%Y-%m-%dT%H:%M:%S", "%Y-%m-%d %H:%M:%S"]
