@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -10,11 +12,11 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from django import template
+from django.template import base
 from django.template import defaultfilters
 from django.utils import safestring
 
-register = template.Library()
+register = base.Library()
 
 
 @register.filter(is_safe=True)
@@ -22,9 +24,9 @@ register = template.Library()
 def shellfilter(value):
     """Replace HTML chars for shell usage."""
     replacements = {'\\': '\\\\',
-                    '`': '\`',
-                    "'": "\\'",
-                    '"': '\\"'}
+                   '`': '\`',
+                   "'": "\\'",
+                   '"': '\\"'}
     for search, repl in replacements.items():
         value = value.replace(search, repl)
     return safestring.mark_safe(value)
