@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2012 United States Government as represented by the
 # Administrator of the National Aeronautics and Space Administration.
 # All Rights Reserved.
@@ -20,12 +22,9 @@
 Template tags for displaying sizes
 """
 
-from oslo_utils import units
-
 from django import template
 from django.utils import formats
-from django.utils.translation import gettext_lazy as _
-from django.utils.translation import ngettext_lazy
+from django.utils import translation
 
 
 register = template.Library()
@@ -36,42 +35,34 @@ def int_format(value):
 
 
 def float_format(value):
-    rounded_value = round(value, 1)
-    if rounded_value.is_integer():
-        decimal_pos = 0
-    else:
-        decimal_pos = 1
-    return formats.number_format(rounded_value, decimal_pos)
+    return formats.number_format(round(value, 1), 1)
 
 
 def filesizeformat(bytes, filesize_number_format):
     try:
         bytes = float(bytes)
     except (TypeError, ValueError, UnicodeDecodeError):
-        return ngettext_lazy("%(size)d B",
-                             "%(size)d B", 0) % {'size': 0}
+        return translation.ungettext_lazy("%(size)d Byte",
+                "%(size)d Bytes", 0) % {'size': 0}
 
-    if bytes == float('inf'):
-        return _('Infinity')
-    if bytes < units.Ki:
+    if bytes < 1024:
         bytes = int(bytes)
-        return ngettext_lazy("%(size)d B",
-                             "%(size)d B", bytes) % {'size': bytes}
-    if bytes < units.Mi:
-        return _("%s KB") % filesize_number_format(bytes / units.Ki)
-    if bytes < units.Gi:
-        return _("%s MB") % filesize_number_format(bytes / units.Mi)
-    if bytes < units.Ti:
-        return _("%s GB") % filesize_number_format(bytes / units.Gi)
-    if bytes < units.Pi:
-        return _("%s TB") % filesize_number_format(bytes / units.Ti)
-    if bytes < units.Ei:
-        return _("%s PB") % filesize_number_format(bytes / units.Pi)
-    if bytes < units.Zi:
-        return _("%s EB") % filesize_number_format(bytes / units.Ei)
-    if bytes < units.Yi:
-        return _("%s ZB") % filesize_number_format(bytes / units.Zi)
-    return _("%s YB") % filesize_number_format(bytes / units.Yi)
+        return translation.ungettext_lazy("%(size)d Byte",
+                "%(size)d Bytes", bytes) % {'size': bytes}
+    if bytes < 1024 * 1024:
+        return translation.ugettext_lazy("%s KB") % \
+            filesize_number_format(bytes / 1024)
+    if bytes < 1024 * 1024 * 1024:
+        return translation.ugettext_lazy("%s MB") % \
+            filesize_number_format(bytes / (1024 * 1024))
+    if bytes < 1024 * 1024 * 1024 * 1024:
+        return translation.ugettext_lazy("%s GB") % \
+            filesize_number_format(bytes / (1024 * 1024 * 1024))
+    if bytes < 1024 * 1024 * 1024 * 1024 * 1024:
+        return translation.ugettext_lazy("%s TB") % \
+            filesize_number_format(bytes / (1024 * 1024 * 1024 * 1024))
+    return translation.ugettext_lazy("%s PB") % \
+            filesize_number_format(bytes / (1024 * 1024 * 1024 * 1024 * 1024))
 
 
 def float_cast_filesizeformat(value, multiplier=1, format=int_format):
@@ -79,20 +70,20 @@ def float_cast_filesizeformat(value, multiplier=1, format=int_format):
         value = float(value)
         value = filesizeformat(value * multiplier, format).replace(' ', '')
     except (TypeError, ValueError):
-        value = value or _('0 B')
+        value = value or '0 bytes'
     return value
 
 
 @register.filter(name='mbformat')
 def mbformat(mb):
-    return float_cast_filesizeformat(mb, units.Mi, int_format)
+    return float_cast_filesizeformat(mb, 1024 * 1024, int_format)
 
 
 @register.filter(name='mb_float_format')
 def mb_float_format(mb):
-    return float_cast_filesizeformat(mb, units.Mi, float_format)
+    return float_cast_filesizeformat(mb, 1024 * 1024, float_format)
 
 
 @register.filter(name='diskgbformat')
 def diskgbformat(gb):
-    return float_cast_filesizeformat(gb, units.Gi, float_format)
+    return float_cast_filesizeformat(gb, 1024 * 1024 * 1024, float_format)
