@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2012 United States Government as represented by the
 # Administrator of the National Aeronautics and Space Administration.
 # All Rights Reserved.
@@ -27,7 +29,7 @@ register = template.Library()
 
 @register.filter("truncate")
 def truncate(value, size):
-    # pylint: disable=chained-comparison
     if len(value) > size and size > 3:
         return value[0:(size - 3)] + '...'
-    return value[0:size]
+    else:
+        return value[0:size]
