@@ -18,22 +18,34 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import logging
 import os
 import socket
 
+from django.contrib.auth.middleware import AuthenticationMiddleware  # noqa
+from django.contrib.auth.models import Permission  # noqa
+from django.contrib.auth.models import User  # noqa
+from django.contrib.contenttypes.models import ContentType  # noqa
+from django.contrib.messages.storage import default_storage  # noqa
+from django.core.handlers import wsgi
 from django import http
 from django import test as django_test
-from django.contrib.auth.models import Permission
-from django.contrib.contenttypes.models import ContentType
-from django.contrib.messages.storage import default_storage
-from django.contrib.auth.middleware import AuthenticationMiddleware
-from django.contrib.auth.models import User
-from django.core.handlers import wsgi
-from django.test.client import RequestFactory
+from django.test.client import RequestFactory  # noqa
 from django.utils import unittest
 
-from selenium.webdriver.firefox.webdriver import WebDriver
-from selenium.webdriver.support import ui as selenium_ui
+LOG = logging.getLogger(__name__)
+
+
+try:
+    from selenium.webdriver.firefox.webdriver import WebDriver  # noqa
+    from selenium.webdriver.support import ui as selenium_ui
+except ImportError as e:
+    # NOTE(saschpe): Several distribution can't ship selenium due to its
+    # non-free license. So they have to patch it out of test-requirements.txt
+    # Avoid import failure and force not running selenium tests.
+    LOG.warning("{0}, force WITH_SELENIUM=False".format(str(e)))
+    os.environ['WITH_SELENIUM'] = ''
+
 
 import mox
 
@@ -48,14 +60,14 @@ class RequestFactoryWithMessages(RequestFactory):
     def get(self, *args, **kwargs):
         req = super(RequestFactoryWithMessages, self).get(*args, **kwargs)
         req.user = User()
-        req.session = []
+        req.session = {}
         req._messages = default_storage(req)
         return req
 
     def post(self, *args, **kwargs):
         req = super(RequestFactoryWithMessages, self).post(*args, **kwargs)
         req.user = User()
-        req.session = []
+        req.session = {}
         req._messages = default_storage(req)
         return req
 
@@ -63,8 +75,7 @@ class RequestFactoryWithMessages(RequestFactory):
 @unittest.skipIf(os.environ.get('SKIP_UNITTESTS', False),
                      "The SKIP_UNITTESTS env variable is set.")
 class TestCase(django_test.TestCase):
-    """
-    Specialized base test case class for Horizon which gives access to
+    """Specialized base test case class for Horizon which gives access to
     numerous additional features:
 
       * The ``mox`` mocking framework via ``self.mox``.
@@ -103,15 +114,13 @@ class TestCase(django_test.TestCase):
             del self.user._perm_cache
 
     def assertNoMessages(self, response=None):
-        """
-        Asserts that no messages have been attached by the ``contrib.messages``
-        framework.
+        """Asserts that no messages have been attached by the
+        ``contrib.messages`` framework.
         """
         self.assertMessageCount(response, success=0, warn=0, info=0, error=0)
 
     def assertMessageCount(self, response=None, **kwargs):
-        """
-        Asserts that the specified number of messages have been attached
+        """Asserts that the specified number of messages have been attached
         for various message types. Usage would look like
         ``self.assertMessageCount(success=1)``.
         """
@@ -170,3 +179,64 @@ class SeleniumTestCase(django_test.LiveServerTestCase):
         socket.setdefaulttimeout(10)
         self.ui = selenium_ui
         super(SeleniumTestCase, self).setUp()
+
+
+class JasmineTests(SeleniumTestCase):
+    """Helper class which allows you to create a simple Jasmine test running
+    through Selenium
+
+    To run a jasmine test suite create a class which extends JasmineTests in
+    the :file:`horizon/test/jasmine/jasmine_tests.py` and define two class
+    attributes
+
+    .. attribute:: sources
+
+        A list of of JS source files (the {{STATIC_URL}} will be added
+        automatically, these are the source files tested
+
+    .. attribute:: specs
+
+        A list of of Jasmine JS spec files (the {{STATIC_URL}} will be added
+        automatically
+
+    .. attribute:: template_name
+
+        A template which will contain the html needed by the test,
+        this attribute is optional, if it is not specified the default template
+        will be used. The template, if specified, must extends
+        :file:`horizon/jasmine/jasmine.html` and insert the html in a block
+        which name must be content
+    """
+    sources = []
+    specs = []
+    template_name = None
+
+    def run_jasmine(self):
+        self.selenium.get(
+            "%s%s%s" % (self.live_server_url,
+                        "/jasmine/",
+                        self.__class__.__name__))
+
+        wait = self.ui.WebDriverWait(self.selenium, 120)
+
+        def jasmine_done(driver):
+            text = driver.find_element_by_class_name("duration").text
+            return "finished" in text
+
+        wait.until(jasmine_done)
+        failures = \
+            self.selenium.find_elements_by_css_selector(".specDetail.failed")
+
+        results = []
+        for failure in failures:
+            results.append(
+                failure.find_element_by_class_name("description").text)
+            results.append(
+                failure.find_element_by_class_name("stackTrace").text)
+
+        self.assertEqual(results, [], '\n\n' + '\n\n'.join(results) + '\n\n')
+
+    def test(self):
+        if self.__class__ == JasmineTests:
+            return
+        self.run_jasmine()
