@@ -14,13 +14,16 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.core.urlresolvers import reverse  # noqa
+from django.core.urlresolvers import reverse
+from django import forms
 from django import http
 from django import shortcuts
+from django.template import defaultfilters
 
 from mox import IsA  # noqa
 
 from horizon import tables
+from horizon.tables import formset as table_formset
 from horizon.tables import views as table_views
 from horizon.test import helpers as test
 
@@ -63,6 +66,11 @@ TEST_DATA_5 = (
                'down', 'optional_1'),
 )
 
+TEST_DATA_6 = (
+    FakeObject('1', 'object_1', 'DELETED', 'down'),
+    FakeObject('2', 'object_2', 'CREATED', 'up'),
+)
+
 
 class MyLinkAction(tables.LinkAction):
     name = "login"
@@ -93,6 +101,13 @@ class MyColumn(tables.Column):
     pass
 
 
+class MyRowSelectable(tables.Row):
+    ajax = True
+
+    def can_be_selected(self, datum):
+        return datum.value != 'DELETED'
+
+
 class MyRow(tables.Row):
     ajax = True
 
@@ -145,6 +160,19 @@ class MyFilterAction(tables.FilterAction):
         return filter(comp, objs)
 
 
+class MyUpdateAction(tables.UpdateAction):
+    def allowed(self, *args):
+        return True
+
+    def update_cell(self, *args):
+        pass
+
+
+class MyUpdateActionNotAllowed(MyUpdateAction):
+    def allowed(self, *args):
+        return False
+
+
 def get_name(obj):
     return "custom %s" % obj.name
 
@@ -155,7 +183,12 @@ def get_link(obj):
 
 class MyTable(tables.DataTable):
     id = tables.Column('id', hidden=True, sortable=False)
-    name = tables.Column(get_name, verbose_name="Verbose Name", sortable=True)
+    name = tables.Column(get_name,
+                         verbose_name="Verbose Name",
+                         sortable=True,
+                         form_field=forms.CharField(required=True),
+                         form_field_attributes={'class': 'test'},
+                         update_action=MyUpdateAction)
     value = tables.Column('value',
                           sortable=True,
                           link='http://example.com/',
@@ -178,6 +211,29 @@ class MyTable(tables.DataTable):
         row_actions = (MyAction, MyLinkAction, MyBatchAction, MyToggleAction)
 
 
+class MyTableSelectable(MyTable):
+    class Meta:
+        name = "my_table"
+        columns = ('id', 'name', 'value', 'status')
+        row_class = MyRowSelectable
+        status_columns = ["status"]
+        multi_select = True
+
+
+class MyTableNotAllowedInlineEdit(MyTable):
+    name = tables.Column(get_name,
+                         verbose_name="Verbose Name",
+                         sortable=True,
+                         form_field=forms.CharField(required=True),
+                         form_field_attributes={'class': 'test'},
+                         update_action=MyUpdateActionNotAllowed)
+
+    class Meta:
+        name = "my_table"
+        columns = ('id', 'name', 'value', 'optional', 'status')
+        row_class = MyRow
+
+
 class NoActionsTable(tables.DataTable):
     id = tables.Column('id')
 
@@ -190,7 +246,7 @@ class NoActionsTable(tables.DataTable):
 
 class DataTableTests(test.TestCase):
     def test_table_instantiation(self):
-        """ Tests everything that happens when the table is instantiated. """
+        """Tests everything that happens when the table is instantiated."""
         self.table = MyTable(self.request, TEST_DATA)
         # Properties defined on the table
         self.assertEqual(self.table.data, TEST_DATA)
@@ -238,6 +294,11 @@ class DataTableTests(test.TestCase):
         self.assertEqual(actions.auto, "actions")
         self.assertEqual(actions.get_final_attrs().get('class', ""),
                          "actions_column")
+        # In-line edit action on column.
+        name_column = self.table.columns['name']
+        self.assertEqual(name_column.update_action, MyUpdateAction)
+        self.assertEqual(name_column.form_field.__class__, forms.CharField)
+        self.assertEqual(name_column.form_field_attributes, {'class': 'test'})
 
     def test_table_force_no_multiselect(self):
         class TempTable(MyTable):
@@ -263,6 +324,22 @@ class DataTableTests(test.TestCase):
                                  ['<Column: multi_select>',
                                   '<Column: id>'])
 
+    def test_table_natural_no_inline_editing(self):
+        class TempTable(MyTable):
+            name = tables.Column(get_name,
+                                 verbose_name="Verbose Name",
+                                 sortable=True)
+
+            class Meta:
+                name = "my_table"
+                columns = ('id', 'name', 'value', 'optional', 'status')
+
+        self.table = TempTable(self.request, TEST_DATA_2)
+        name_column = self.table.columns['name']
+        self.assertIsNone(name_column.update_action)
+        self.assertIsNone(name_column.form_field)
+        self.assertEqual(name_column.form_field_attributes, {})
+
     def test_table_natural_no_actions_column(self):
         class TempTable(MyTable):
             class Meta:
@@ -375,7 +452,7 @@ class DataTableTests(test.TestCase):
         self.assertEqual(row.cells['id'].get_status_class(cell_status),
                          'status_down')
         cell_status = row3.cells['id'].status
-        self.assertEqual(cell_status, None)
+        self.assertIsNone(cell_status)
         self.assertEqual(row.cells['id'].get_status_class(cell_status),
                          'status_unknown')
 
@@ -445,6 +522,172 @@ class DataTableTests(test.TestCase):
         resp = http.HttpResponse(table_actions)
         self.assertContains(resp, "table_search", 0)
 
+    def test_inline_edit_available_cell_rendering(self):
+        self.table = MyTable(self.request, TEST_DATA_2)
+        row = self.table.get_rows()[0]
+        name_cell = row.cells['name']
+
+        # Check if in-line edit is available in the cell,
+        # but is not in inline_edit_mod.
+        self.assertEqual(name_cell.inline_edit_available,
+                         True)
+        self.assertEqual(name_cell.inline_edit_mod,
+                         False)
+
+        # Check if is cell is rendered correctly.
+        name_cell_rendered = name_cell.render()
+        resp = http.HttpResponse(name_cell_rendered)
+
+        self.assertContains(resp, '<td', 1)
+        self.assertContains(resp, 'inline_edit_available', 1)
+        self.assertContains(resp,
+                            'data-update-url="?action=cell_update&amp;'
+                            'table=my_table&amp;cell_name=name&amp;obj_id=1"',
+                            1)
+        self.assertContains(resp, 'table_cell_wrapper', 1)
+        self.assertContains(resp, 'table_cell_data_wrapper', 1)
+        self.assertContains(resp, 'table_cell_action', 1)
+        self.assertContains(resp, 'ajax-inline-edit', 1)
+
+    def test_inline_edit_available_not_allowed_cell_rendering(self):
+        self.table = MyTableNotAllowedInlineEdit(self.request, TEST_DATA_2)
+
+        row = self.table.get_rows()[0]
+        name_cell = row.cells['name']
+
+        # Check if in-line edit is available in the cell,
+        # but is not in inline_edit_mod.
+        self.assertEqual(name_cell.inline_edit_available,
+                         True)
+        self.assertEqual(name_cell.inline_edit_mod,
+                         False)
+
+        # Check if is cell is rendered correctly.
+        name_cell_rendered = name_cell.render()
+        resp = http.HttpResponse(name_cell_rendered)
+
+        self.assertContains(resp, '<td', 1)
+        self.assertContains(resp, 'inline_edit_available', 1)
+        self.assertContains(resp,
+                            'data-update-url="?action=cell_update&amp;'
+                            'table=my_table&amp;cell_name=name&amp;obj_id=1"',
+                            1)
+        self.assertContains(resp, 'table_cell_wrapper', 0)
+        self.assertContains(resp, 'table_cell_data_wrapper', 0)
+        self.assertContains(resp, 'table_cell_action', 0)
+        self.assertContains(resp, 'ajax-inline-edit', 0)
+
+    def test_inline_edit_mod_cell_rendering(self):
+        self.table = MyTable(self.request, TEST_DATA_2)
+        name_col = self.table.columns['name']
+        name_col.auto = "form_field"
+
+        row = self.table.get_rows()[0]
+        name_cell = row.cells['name']
+        name_cell.inline_edit_mod = True
+
+        # Check if in-line edit is available in the cell,
+        # and is in inline_edit_mod, also column auto must be
+        # set as form_field.
+        self.assertEqual(name_cell.inline_edit_available,
+                         True)
+        self.assertEqual(name_cell.inline_edit_mod,
+                         True)
+        self.assertEqual(name_col.auto,
+                         'form_field')
+
+        # Check if is cell is rendered correctly.
+        name_cell_rendered = name_cell.render()
+        resp = http.HttpResponse(name_cell_rendered)
+
+        self.assertContains(resp,
+                            '<input class="test" id="name__1" name="name__1"'
+                            ' type="text" value="custom object_1" />',
+                            count=1, html=True)
+
+        self.assertContains(resp, '<td', 1)
+        self.assertContains(resp, 'inline_edit_available', 1)
+        self.assertContains(resp,
+                            'data-update-url="?action=cell_update&amp;'
+                            'table=my_table&amp;cell_name=name&amp;obj_id=1"',
+                            1)
+        self.assertContains(resp, 'table_cell_wrapper', 1)
+        self.assertContains(resp, 'inline-edit-error', 1)
+        self.assertContains(resp, 'inline-edit-form', 1)
+        self.assertContains(resp, 'inline-edit-actions', 1)
+        self.assertContains(resp, 'inline-edit-submit', 1)
+        self.assertContains(resp, 'inline-edit-cancel', 1)
+
+    def test_inline_edit_mod_checkbox_with_label(self):
+        class TempTable(MyTable):
+            name = tables.Column(get_name,
+                                 verbose_name="Verbose Name",
+                                 sortable=True,
+                                 form_field=forms.BooleanField(
+                                     required=True,
+                                     label="Verbose Name"),
+                                 form_field_attributes={'class': 'test'},
+                                 update_action=MyUpdateAction)
+
+            class Meta:
+                name = "my_table"
+                columns = ('id', 'name', 'value', 'optional', 'status')
+
+        self.table = TempTable(self.request, TEST_DATA_2)
+        name_col = self.table.columns['name']
+        name_col.auto = "form_field"
+
+        row = self.table.get_rows()[0]
+        name_cell = row.cells['name']
+        name_cell.inline_edit_mod = True
+
+        # Check if is cell is rendered correctly.
+        name_cell_rendered = name_cell.render()
+        resp = http.HttpResponse(name_cell_rendered)
+
+        self.assertContains(resp,
+                            '<input checked="checked" class="test" '
+                            'id="name__1" name="name__1" type="checkbox" '
+                            'value="custom object_1" />',
+                            count=1, html=True)
+        self.assertContains(resp,
+                            '<label class="inline-edit-label" for="name__1">'
+                            'Verbose Name</label>',
+                            count=1, html=True)
+
+    def test_inline_edit_mod_textarea(self):
+        class TempTable(MyTable):
+            name = tables.Column(get_name,
+                                 verbose_name="Verbose Name",
+                                 sortable=True,
+                                 form_field=forms.CharField(
+                                     widget=forms.Textarea(),
+                                     required=False),
+                                 form_field_attributes={'class': 'test'},
+                                 update_action=MyUpdateAction)
+
+            class Meta:
+                name = "my_table"
+                columns = ('id', 'name', 'value', 'optional', 'status')
+
+        self.table = TempTable(self.request, TEST_DATA_2)
+        name_col = self.table.columns['name']
+        name_col.auto = "form_field"
+
+        row = self.table.get_rows()[0]
+        name_cell = row.cells['name']
+        name_cell.inline_edit_mod = True
+
+        # Check if is cell is rendered correctly.
+        name_cell_rendered = name_cell.render()
+        resp = http.HttpResponse(name_cell_rendered)
+
+        self.assertContains(resp,
+                            '<textarea class="test" cols="40" id="name__1" '
+                            'name="name__1" rows="10">\r\ncustom object_1'
+                            '</textarea>',
+                            count=1, html=True)
+
     def test_table_actions(self):
         # Single object action
         action_string = "my_table__delete__1"
@@ -520,7 +763,7 @@ class DataTableTests(test.TestCase):
         self.assertEqual(self.table.parse_action(action_string),
                          ('my_table', 'delete', None))
         handled = self.table.maybe_handle()
-        self.assertEqual(handled, None)
+        self.assertIsNone(handled)
         self.assertEqual(list(req._messages)[0].message,
                          "Please select a row before taking that action.")
 
@@ -558,7 +801,7 @@ class DataTableTests(test.TestCase):
         req = self.factory.post('/my_url/', {action_string: '2'})
         self.table = MyTable(req, TEST_DATA)
         handled = self.table.maybe_handle()
-        self.assertEqual(handled, None)
+        self.assertIsNone(handled)
         self.assertQuerysetEqual(self.table.filtered_data,
                                  ['<FakeObject: object_2>'])
 
@@ -566,7 +809,7 @@ class DataTableTests(test.TestCase):
         req = self.factory.get('/my_url/', {action_string: '2'})
         self.table = MyTable(req, TEST_DATA)
         handled = self.table.maybe_handle()
-        self.assertEqual(handled, None)
+        self.assertIsNone(handled)
         self.assertQuerysetEqual(self.table.filtered_data,
                                  ['<FakeObject: object_1>',
                                   '<FakeObject: object_2>',
@@ -590,19 +833,134 @@ class DataTableTests(test.TestCase):
         req = self.factory.get('/my_url/', params)
         self.table = MyTable(req)
         resp = self.table.maybe_preempt()
-        self.assertEqual(resp, None)
+        self.assertIsNone(resp)
         resp = self.table.maybe_handle()
-        self.assertEqual(resp, None)
+        self.assertIsNone(resp)
 
         # Verbose names
         table_actions = self.table.get_table_actions()
-        self.assertEqual(unicode(table_actions[0].verbose_name), "filter")
+        self.assertEqual(unicode(table_actions[0].verbose_name), "Filter")
         self.assertEqual(unicode(table_actions[1].verbose_name), "Delete Me")
 
         row_actions = self.table.get_row_actions(TEST_DATA[0])
         self.assertEqual(unicode(row_actions[0].verbose_name), "Delete Me")
         self.assertEqual(unicode(row_actions[1].verbose_name), "Log In")
 
+    def test_inline_edit_update_action_get_non_ajax(self):
+        # Non ajax inline edit request should return None.
+        url = ('/my_url/?action=cell_update'
+               '&table=my_table&cell_name=name&obj_id=1')
+        req = self.factory.get(url, {})
+        self.table = MyTable(req, TEST_DATA_2)
+        handled = self.table.maybe_preempt()
+        # Checking the response header.
+        self.assertIsNone(handled)
+
+    def test_inline_edit_update_action_get(self):
+        # Get request should return td field with data.
+        url = ('/my_url/?action=cell_update'
+               '&table=my_table&cell_name=name&obj_id=1')
+        req = self.factory.get(url, {},
+                               HTTP_X_REQUESTED_WITH='XMLHttpRequest')
+        self.table = MyTable(req, TEST_DATA_2)
+        handled = self.table.maybe_preempt()
+        # Checking the response header.
+        self.assertEqual(handled.status_code, 200)
+        # Checking the response content.
+        resp = handled
+        self.assertContains(resp, '<td', 1)
+        self.assertContains(resp, 'inline_edit_available', 1)
+        self.assertContains(
+            resp,
+            'data-update-url="/my_url/?action=cell_update&amp;'
+            'table=my_table&amp;cell_name=name&amp;obj_id=1"',
+            1)
+        self.assertContains(resp, 'table_cell_wrapper', 1)
+        self.assertContains(resp, 'table_cell_data_wrapper', 1)
+        self.assertContains(resp, 'table_cell_action', 1)
+        self.assertContains(resp, 'ajax-inline-edit', 1)
+
+    def test_inline_edit_update_action_get_not_allowed(self):
+        # Name column has required validation, sending blank
+        # will return error.
+        url = ('/my_url/?action=cell_update'
+               '&table=my_table&cell_name=name&obj_id=1')
+        req = self.factory.post(url, {})
+        self.table = MyTableNotAllowedInlineEdit(req, TEST_DATA_2)
+        handled = self.table.maybe_preempt()
+        # Checking the response header.
+        self.assertEqual(handled.status_code, 401)
+
+    def test_inline_edit_update_action_get_inline_edit_mod(self):
+        # Get request in inline_edit_mode should return td with form field.
+        url = ('/my_url/?inline_edit_mod=true&action=cell_update'
+               '&table=my_table&cell_name=name&obj_id=1')
+        req = self.factory.get(url, {},
+                               HTTP_X_REQUESTED_WITH='XMLHttpRequest')
+        self.table = MyTable(req, TEST_DATA_2)
+        handled = self.table.maybe_preempt()
+        # Checking the response header.
+        self.assertEqual(handled.status_code, 200)
+        # Checking the response content.
+        resp = handled
+        self.assertContains(resp,
+                            '<input class="test" id="name__1" name="name__1"'
+                            ' type="text" value="custom object_1" />',
+                            count=1, html=True)
+
+        self.assertContains(resp, '<td', 1)
+        self.assertContains(resp, 'inline_edit_available', 1)
+        self.assertContains(
+            resp,
+            'data-update-url="/my_url/?action=cell_update&amp;'
+            'table=my_table&amp;cell_name=name&amp;obj_id=1"',
+            1)
+        self.assertContains(resp, 'table_cell_wrapper', 1)
+        self.assertContains(resp, 'inline-edit-error', 1)
+        self.assertContains(resp, 'inline-edit-form', 1)
+        self.assertContains(resp, 'inline-edit-actions', 1)
+        self.assertContains(resp, '<button', 2)
+        self.assertContains(resp, 'inline-edit-submit', 1)
+        self.assertContains(resp, 'inline-edit-cancel', 1)
+
+    def test_inline_edit_update_action_post(self):
+        # Post request should invoke the cell update table action.
+        url = ('/my_url/?action=cell_update'
+               '&table=my_table&cell_name=name&obj_id=1')
+        req = self.factory.post(url, {'name__1': 'test_name'})
+        self.table = MyTable(req, TEST_DATA_2)
+        # checking the response header
+        handled = self.table.maybe_preempt()
+        self.assertEqual(handled.status_code, 200)
+
+    def test_inline_edit_update_action_post_not_allowed(self):
+        # Post request should invoke the cell update table action.
+        url = ('/my_url/?action=cell_update'
+               '&table=my_table&cell_name=name&obj_id=1')
+        req = self.factory.post(url, {'name__1': 'test_name'})
+        self.table = MyTableNotAllowedInlineEdit(req, TEST_DATA_2)
+        # checking the response header
+        handled = self.table.maybe_preempt()
+        self.assertEqual(handled.status_code, 401)
+
+    def test_inline_edit_update_action_post_validation_error(self):
+        # Name column has required validation, sending blank
+        # will return error.
+        url = ('/my_url/?action=cell_update'
+               '&table=my_table&cell_name=name&obj_id=1')
+        req = self.factory.post(url, {})
+        self.table = MyTable(req, TEST_DATA_2)
+        handled = self.table.maybe_preempt()
+        # Checking the response header.
+        self.assertEqual(handled.status_code, 400)
+        self.assertEqual(handled._headers['content-type'],
+                         ('Content-Type', 'application/json'))
+        # Checking the response content.
+        resp = handled
+        self.assertContains(resp,
+                            '"message": "This field is required."',
+                            count=1, status_code=400)
+
     def test_column_uniqueness(self):
         table1 = MyTable(self.request)
         table2 = MyTable(self.request)
@@ -677,6 +1035,76 @@ class DataTableTests(test.TestCase):
         self.assertEqual(list(req._messages)[0].message,
                         u"Downed Item: N/A")
 
+    def test_table_column_can_be_selected(self):
+        self.table = MyTableSelectable(self.request, TEST_DATA_6)
+        #non selectable row
+        row = self.table.get_rows()[0]
+        #selectable
+        row1 = self.table.get_rows()[1]
+
+        id_col = self.table.columns['id']
+        name_col = self.table.columns['name']
+        value_col = self.table.columns['value']
+        # transform
+        self.assertEqual(row.cells['id'].data, '1')  # Standard attr access
+        self.assertEqual(row.cells['name'].data, 'custom object_1')  # Callable
+        # name and verbose_name
+        self.assertEqual(unicode(id_col), "Id")
+        self.assertEqual(unicode(name_col), "Verbose Name")
+        self.assertIn("sortable", name_col.get_final_attrs().get('class', ""))
+        # hidden
+        self.assertEqual(id_col.hidden, True)
+        self.assertIn("hide", id_col.get_final_attrs().get('class', ""))
+        self.assertEqual(name_col.hidden, False)
+        self.assertNotIn("hide", name_col.get_final_attrs().get('class', ""))
+        # link, link_classes and get_link_url
+        self.assertIn('href="http://example.com/"', row.cells['value'].value)
+        self.assertIn('class="link-modal"', row.cells['value'].value)
+        self.assertIn('href="/auth/login/"', row.cells['status'].value)
+        # classes
+        self.assertEqual(value_col.get_final_attrs().get('class', ""),
+                         "green blue sortable anchor normal_column")
+
+        self.assertQuerysetEqual(row.get_cells(),
+                                 ['<Cell: multi_select, my_table__row__1>',
+                                  '<Cell: id, my_table__row__1>',
+                                  '<Cell: name, my_table__row__1>',
+                                  '<Cell: value, my_table__row__1>',
+                                  '<Cell: status, my_table__row__1>',
+                                  ])
+        #can_be_selected = False
+        self.assertTrue(row.get_cells()[0].data == "")
+        #can_be_selected = True
+        self.assertIn('checkbox', row1.get_cells()[0].data)
+        #status
+        cell_status = row.cells['status'].status
+        self.assertEqual(row.cells['status'].get_status_class(cell_status),
+                         'status_down')
+        # status_choices
+        id_col.status = True
+        id_col.status_choices = (('1', False), ('2', True))
+        cell_status = row.cells['id'].status
+        self.assertEqual(cell_status, False)
+        self.assertEqual(row.cells['id'].get_status_class(cell_status),
+                         'status_down')
+        # Ensure data is not cached on the column across table instances
+        self.table = MyTable(self.request, TEST_DATA_6)
+        row = self.table.get_rows()[0]
+        self.assertTrue("down" in row.cells['status'].value)
+
+    def test_broken_filter(self):
+        class MyTableBrokenFilter(MyTable):
+            value = tables.Column('value',
+                                  filters=(defaultfilters.timesince,))
+
+        value = "not_a_date"
+        data = TEST_DATA[0]
+        data.value = value
+
+        table = MyTableBrokenFilter(self.request, [data])
+        resp = http.HttpResponse(table.render())
+        self.assertContains(resp, value)
+
 
 class SingleTableView(table_views.DataTableView):
     table_class = MyTable
@@ -752,3 +1180,33 @@ class DataTableViewTests(test.TestCase):
         self.assertEqual(context['my_table_table'].__class__, MyTable)
         self.assertEqual(context['table_with_permissions_table'].__class__,
                          TableWithPermissions)
+
+
+class FormsetTableTests(test.TestCase):
+
+    def test_populate(self):
+        """Create a FormsetDataTable and populate it with data."""
+
+        class TableForm(forms.Form):
+            name = forms.CharField()
+            value = forms.IntegerField()
+
+        TableFormset = forms.formsets.formset_factory(TableForm, extra=0)
+
+        class Table(table_formset.FormsetDataTable):
+            formset_class = TableFormset
+
+            name = tables.Column('name')
+            value = tables.Column('value')
+
+            class Meta:
+                name = 'table'
+
+        table = Table(self.request)
+        table.data = TEST_DATA_4
+        formset = table.get_formset()
+        self.assertEqual(len(formset), 2)
+        form = formset[0]
+        form_data = form.initial
+        self.assertEqual(form_data['name'], 'object_1')
+        self.assertEqual(form_data['value'], 2)
