@@ -22,11 +22,14 @@
 URL patterns for testing Horizon views.
 """
 
-from django.conf.urls.defaults import patterns, url, include
-from django.contrib.staticfiles.urls import staticfiles_urlpatterns
-from django.views.generic import TemplateView
+from django.conf.urls import include  # noqa
+from django.conf.urls import patterns  # noqa
+from django.conf.urls import url  # noqa
+from django.contrib.staticfiles.urls import staticfiles_urlpatterns  # noqa
+from django.views.generic import TemplateView  # noqa
 
 import horizon
+from horizon.test.jasmine import jasmine
 
 
 urlpatterns = patterns('',
@@ -37,7 +40,8 @@ urlpatterns = patterns('',
     url(r'auth/', include('django.contrib.auth.urls')),
     url(r'^qunit/$',
         TemplateView.as_view(template_name="horizon/qunit.html"),
-        name='qunit_tests')
+        name='qunit_tests'),
+    url(r'^jasmine/(.*?)$', jasmine.dispatcher)
 )
 
 urlpatterns += staticfiles_urlpatterns()
