@@ -20,10 +20,10 @@
 #    under the License.
 
 import logging
-import urlparse
 
-from django.conf import settings  # noqa
-from django.utils.translation import ugettext_lazy as _  # noqa
+from django.conf import settings
+from django.utils.translation import ugettext_lazy as _
+import six.moves.urllib.parse as urlparse
 
 from keystoneclient import exceptions as keystone_exceptions
 
@@ -76,7 +76,7 @@ except ImportError:
 
 
 class Service(base.APIDictWrapper):
-    """ Wrapper for a dict based on the service data from keystone. """
+    """Wrapper for a dict based on the service data from keystone."""
     _attrs = ['id', 'type', 'name']
 
     def __init__(self, service, region, *args, **kwargs):
@@ -207,19 +207,19 @@ def domain_update(request, domain_id, name=None, description=None,
     return manager.update(domain_id, name, description, enabled)
 
 
-def tenant_create(request, name, description=None, enabled=None, domain=None):
+def tenant_create(request, name, description=None, enabled=None,
+                  domain=None, **kwargs):
     manager = VERSIONS.get_project_manager(request, admin=True)
     if VERSIONS.active < 3:
-        return manager.create(name, description, enabled)
+        return manager.create(name, description, enabled, **kwargs)
     else:
         return manager.create(name, domain,
                               description=description,
-                              enabled=enabled)
+                              enabled=enabled, **kwargs)
 
 
 def get_default_domain(request):
-    """
-    Gets the default domain object to use when creating Identity object.
+    """Gets the default domain object to use when creating Identity object.
     Returns the domain context if is set, otherwise return the domain
     of the logon user.
     """
@@ -255,9 +255,8 @@ def tenant_delete(request, project):
 
 def tenant_list(request, paginate=False, marker=None, domain=None, user=None):
     manager = VERSIONS.get_project_manager(request, admin=True)
-    page_size = request.session.get('horizon_pagesize',
-                                    getattr(settings, 'API_RESULT_PAGE_SIZE',
-                                            20))
+    page_size = utils.get_page_size(request)
+
     limit = None
     if paginate:
         limit = page_size + 1
@@ -274,13 +273,13 @@ def tenant_list(request, paginate=False, marker=None, domain=None, user=None):
 
 
 def tenant_update(request, project, name=None, description=None,
-                  enabled=None, domain=None):
+                  enabled=None, domain=None, **kwargs):
     manager = VERSIONS.get_project_manager(request, admin=True)
     if VERSIONS.active < 3:
-        return manager.update(project, name, description, enabled)
+        return manager.update(project, name, description, enabled, **kwargs)
     else:
         return manager.update(project, name=name, description=description,
-                              enabled=enabled, domain=domain)
+                              enabled=enabled, domain=domain, **kwargs)
 
 
 def user_list(request, project=None, domain=None, group=None):
@@ -378,8 +377,6 @@ def user_update(request, user, **data):
                 _("Password changed. Please log in again to continue.")
             )
 
-    return VERSIONS.upgrade_v2_user(user)
-
 
 def user_update_enabled(request, user, enabled):
     manager = keystoneclient(request, admin=True).users
@@ -399,11 +396,11 @@ def user_update_password(request, user, password, admin=True):
 
 def user_update_own_password(request, origpassword, password):
     client = keystoneclient(request, admin=False)
+    client.user_id = request.user.id
     if VERSIONS.active < 3:
-        client.user_id = request.user.id
         return client.users.update_own_password(origpassword, password)
     else:
-        return client.users.update(request.user.id, password=password)
+        return client.users.update_password(origpassword, password)
 
 
 def user_update_tenant(request, user, project, admin=True):
@@ -492,7 +489,7 @@ def role_delete(request, role_id):
 
 
 def role_list(request):
-    """ Returns a global list of available roles. """
+    """Returns a global list of available roles."""
     return keystoneclient(request, admin=True).roles.list()
 
 
@@ -506,7 +503,7 @@ def roles_for_user(request, user, project):
 
 def add_tenant_user_role(request, project=None, user=None, role=None,
                          group=None, domain=None):
-    """ Adds a role for a user on a tenant. """
+    """Adds a role for a user on a tenant."""
     manager = keystoneclient(request, admin=True).roles
     if VERSIONS.active < 3:
         return manager.add_user_role(user, role, project)
@@ -517,7 +514,7 @@ def add_tenant_user_role(request, project=None, user=None, role=None,
 
 def remove_tenant_user_role(request, project=None, user=None, role=None,
                             group=None, domain=None):
-    """ Removes a given single role for a user from a tenant. """
+    """Removes a given single role for a user from a tenant."""
     manager = keystoneclient(request, admin=True).roles
     if VERSIONS.active < 3:
         return manager.remove_user_role(user, role, project)
@@ -527,7 +524,7 @@ def remove_tenant_user_role(request, project=None, user=None, role=None,
 
 
 def remove_tenant_user(request, project=None, user=None, domain=None):
-    """ Removes all roles from a user on a tenant, removing them from it. """
+    """Removes all roles from a user on a tenant, removing them from it."""
     client = keystoneclient(request, admin=True)
     roles = client.roles.roles_for_user(user, project)
     for role in roles:
@@ -541,22 +538,22 @@ def roles_for_group(request, group, domain=None, project=None):
 
 
 def add_group_role(request, role, group, domain=None, project=None):
-    """ Adds a role for a group on a domain or project ."""
+    """Adds a role for a group on a domain or project."""
     manager = keystoneclient(request, admin=True).roles
     return manager.grant(role=role, group=group, domain=domain,
                          project=project)
 
 
 def remove_group_role(request, role, group, domain=None, project=None):
-    """ Removes a given single role for a group from a domain or project. """
+    """Removes a given single role for a group from a domain or project."""
     manager = keystoneclient(request, admin=True).roles
     return manager.revoke(role=role, group=group, project=project,
                           domain=domain)
 
 
 def remove_group_roles(request, group, domain=None, project=None):
-    """ Removes all roles from a group on a domain or project,
-        removing them from it.
+    """Removes all roles from a group on a domain or project,
+    removing them from it.
     """
     client = keystoneclient(request, admin=True)
     roles = client.roles.list(group=group, domain=domain, project=project)
@@ -566,8 +563,7 @@ def remove_group_roles(request, group, domain=None, project=None):
 
 
 def get_default_role(request):
-    """
-    Gets the default role object from Keystone and saves it as a global
+    """Gets the default role object from Keystone and saves it as a global
     since this is configured in settings and should not change from request
     to request. Supports lookup by name or id.
     """
