@@ -10,25 +10,16 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import logging
-
-from django.conf import settings
-from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ugettext_lazy as _
 
 import horizon
 
-
-LOG = logging.getLogger(__name__)
+from openstack_dashboard.dashboards.admin import dashboard
 
 
 class Aggregates(horizon.Panel):
     name = _("Host Aggregates")
     slug = 'aggregates'
-    policy_rules = (("compute", "compute_extension:aggregates"),)
-    permissions = ('openstack.services.compute',)
 
-    def allowed(self, context):
-        if (('compute' in settings.SYSTEM_SCOPE_SERVICES) !=
-                bool(context['request'].user.system_scoped)):
-            return False
-        return super().allowed(context)
+
+dashboard.Admin.register(Aggregates)
