@@ -11,8 +11,7 @@
 #    under the License.
 
 from django.template import defaultfilters as filters
-from django.utils.translation import gettext_lazy as _
-from django.utils.translation import ngettext_lazy
+from django.utils.translation import ugettext_lazy as _
 
 from horizon import tables
 
@@ -21,28 +20,8 @@ from openstack_dashboard.dashboards.admin.aggregates import constants
 
 
 class DeleteAggregateAction(tables.DeleteAction):
-    policy_rules = (("compute", "os_compute_api:os-aggregates:delete"),)
-
-    @staticmethod
-    def action_present(count):
-        return ngettext_lazy(
-            "Delete Host Aggregate",
-            "Delete Host Aggregates",
-            count
-        )
-
-    @staticmethod
-    def action_past(count):
-        return ngettext_lazy(
-            "Deleted Host Aggregate",
-            "Deleted Host Aggregates",
-            count
-        )
-
-    def allowed(self, request, aggregate):
-        if aggregate and aggregate.hosts:
-            return False
-        return True
+    data_type_singular = _("Host Aggregate")
+    data_type_plural = _("Host Aggregates")
 
     def delete(self, request, obj_id):
         api.nova.aggregate_delete(request, obj_id)
@@ -52,45 +31,21 @@ class CreateAggregateAction(tables.LinkAction):
     name = "create"
     verbose_name = _("Create Host Aggregate")
     url = constants.AGGREGATES_CREATE_URL
-    classes = ("ajax-modal",)
-    policy_rules = (("compute", "os_compute_api:os-aggregates:create"),)
-    icon = "plus"
+    classes = ("ajax-modal", "btn-create")
 
 
 class ManageHostsAction(tables.LinkAction):
     name = "manage"
     verbose_name = _("Manage Hosts")
     url = constants.AGGREGATES_MANAGE_HOSTS_URL
-    classes = ("ajax-modal",)
-    icon = "plus"
-
-
-class UpdateMetadataAction(tables.LinkAction):
-    name = "update-metadata"
-    verbose_name = _("Update Metadata")
-    ajax = False
-    policy_rules = (("compute", "os_compute_api:os-aggregates:set_metadata"),)
-    icon = "pencil"
-    attrs = {"ng-controller": "MetadataModalHelperController as modal"}
-
-    def __init__(self, attrs=None, **kwargs):
-        kwargs['preempt'] = True
-        super().__init__(attrs, **kwargs)
-
-    def get_link_url(self, datum):
-        aggregate_id = self.table.get_object_id(datum)
-        self.attrs['ng-click'] = (
-            "modal.openMetadataModal('aggregate', '%s', true)" % aggregate_id)
-        return "javascript:void(0);"
+    classes = ("ajax-modal", "btn-create")
 
 
 class UpdateAggregateAction(tables.LinkAction):
     name = "update"
     verbose_name = _("Edit Host Aggregate")
     url = constants.AGGREGATES_UPDATE_URL
-    classes = ("ajax-modal",)
-    policy_rules = (("compute", "os_compute_api:os-aggregates:update"),)
-    icon = "pencil"
+    classes = ("ajax-modal", "btn-edit")
 
 
 class AggregateFilterAction(tables.FilterAction):
@@ -108,18 +63,18 @@ class AvailabilityZoneFilterAction(tables.FilterAction):
         q = filter_string.lower()
 
         def comp(availabilityZone):
-            return q in availabilityZone.zoneName.lower()
+            return q in availabilityZone.name.lower()
 
         return filter(comp, availability_zones)
 
 
 def get_aggregate_hosts(aggregate):
-    return aggregate.hosts
+    return [host for host in aggregate.hosts]
 
 
 def get_metadata(aggregate):
     return [' = '.join([key, val]) for key, val
-            in aggregate.metadata.items()]
+            in aggregate.metadata.iteritems()]
 
 
 def get_available(zone):
@@ -129,52 +84,44 @@ def get_available(zone):
 def get_zone_hosts(zone):
     hosts = zone.hosts
     host_details = []
-    if hosts is None:
-        return []
     for name, services in hosts.items():
-        up = all(s['active'] and s['available'] for s in services.values())
+        up = all([s['active'] and s['available'] for k, s in services.items()])
         up = _("Services Up") if up else _("Services Down")
         host_details.append("%(host)s (%(up)s)" % {'host': name, 'up': up})
     return host_details
 
 
-def safe_unordered_list(value):
-    return filters.unordered_list(value, autoescape=True)
-
-
 class HostAggregatesTable(tables.DataTable):
-    name = tables.WrappingColumn('name', verbose_name=_('Name'))
+    name = tables.Column('name', verbose_name=_('Name'))
     availability_zone = tables.Column('availability_zone',
                                       verbose_name=_('Availability Zone'))
     hosts = tables.Column(get_aggregate_hosts,
                           verbose_name=_("Hosts"),
                           wrap_list=True,
-                          filters=(safe_unordered_list,))
+                          filters=(filters.unordered_list,))
     metadata = tables.Column(get_metadata,
                              verbose_name=_("Metadata"),
                              wrap_list=True,
-                             filters=(safe_unordered_list,))
+                             filters=(filters.unordered_list,))
 
-    class Meta(object):
+    class Meta:
         name = "host_aggregates"
-        hidden_title = False
         verbose_name = _("Host Aggregates")
         table_actions = (AggregateFilterAction,
                          CreateAggregateAction,
                          DeleteAggregateAction)
         row_actions = (UpdateAggregateAction,
                        ManageHostsAction,
-                       UpdateMetadataAction,
                        DeleteAggregateAction)
 
 
 class AvailabilityZonesTable(tables.DataTable):
-    name = tables.WrappingColumn('zoneName',
-                                 verbose_name=_('Availability Zone Name'))
+    name = tables.Column('zoneName',
+                         verbose_name=_('Availability Zone Name'))
     hosts = tables.Column(get_zone_hosts,
                           verbose_name=_('Hosts'),
                           wrap_list=True,
-                          filters=(safe_unordered_list,))
+                          filters=(filters.unordered_list,))
     available = tables.Column(get_available,
                               verbose_name=_('Available'),
                               status=True,
@@ -183,9 +130,8 @@ class AvailabilityZonesTable(tables.DataTable):
     def get_object_id(self, zone):
         return zone.zoneName
 
-    class Meta(object):
+    class Meta:
         name = "availability_zones"
-        hidden_title = False
         verbose_name = _("Availability Zones")
-        table_actions = (AvailabilityZoneFilterAction,)
+        table_actions = (AggregateFilterAction,)
         multi_select = False
