@@ -10,19 +10,20 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.urls import re_path
+from django.conf.urls import patterns  # noqa
+from django.conf.urls import url  # noqa
 
 from openstack_dashboard.dashboards.admin.aggregates \
     import views
 
 
-urlpatterns = [
-    re_path(r'^$',
-            views.IndexView.as_view(), name='index'),
-    re_path(r'^create/$',
-            views.CreateView.as_view(), name='create'),
-    re_path(r'^(?P<id>[^/]+)/update/$',
-            views.UpdateView.as_view(), name='update'),
-    re_path(r'^(?P<id>[^/]+)/manage_hosts/$',
-            views.ManageHostsView.as_view(), name='manage_hosts'),
-]
+urlpatterns = patterns('openstack_dashboard.dashboards.admin.aggregates.views',
+    url(r'^$',
+        views.IndexView.as_view(), name='index'),
+    url(r'^create/$',
+        views.CreateView.as_view(), name='create'),
+    url(r'^(?P<id>[^/]+)/update/$',
+        views.UpdateView.as_view(), name='update'),
+    url(r'^(?P<id>[^/]+)/manage_hosts/$',
+        views.ManageHostsView.as_view(), name='manage_hosts'),
+)
