@@ -14,31 +14,16 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.utils.translation import ugettext_lazy as _  # noqa
+from django.utils.translation import ugettext_lazy as _
 
 from horizon import tables
 from horizon.templatetags import sizeformat
 
 
-def get_memory(hypervisor):
-    return sizeformat.mbformat(hypervisor.memory_mb)
-
-
-def get_memory_used(hypervisor):
-    return sizeformat.mbformat(hypervisor.memory_mb_used)
-
-
-def get_local(hypervisor):
-    return sizeformat.diskgbformat(hypervisor.local_gb)
-
-
-def get_local_used(hypervisor):
-    return sizeformat.diskgbformat(hypervisor.local_gb_used)
-
-
 class AdminHypervisorsTable(tables.DataTable):
-    hypervisor_hostname = tables.Column("hypervisor_hostname",
-                                        verbose_name=_("Hostname"))
+    hostname = tables.Column("hypervisor_hostname",
+                             link=("horizon:admin:hypervisors:detail"),
+                             verbose_name=_("Hostname"))
 
     hypervisor_type = tables.Column("hypervisor_type",
                                     verbose_name=_("Type"))
@@ -49,25 +34,47 @@ class AdminHypervisorsTable(tables.DataTable):
     vcpus_used = tables.Column("vcpus_used",
                                verbose_name=_("VCPUs (used)"))
 
-    memory = tables.Column(get_memory,
+    memory = tables.Column('memory_mb',
                            verbose_name=_("RAM (total)"),
-                           attrs={'data-type': 'size'})
+                           attrs={'data-type': 'size'},
+                           filters=(sizeformat.mbformat,))
 
-    memory_used = tables.Column(get_memory_used,
+    memory_used = tables.Column('memory_mb_used',
                                 verbose_name=_("RAM (used)"),
-                                attrs={'data-type': 'size'})
+                                attrs={'data-type': 'size'},
+                                filters=(sizeformat.mbformat,))
 
-    local = tables.Column(get_local,
+    local = tables.Column('local_gb',
                           verbose_name=_("Storage (total)"),
-                          attrs={'data-type': 'size'})
+                          attrs={'data-type': 'size'},
+                          filters=(sizeformat.diskgbformat,))
 
-    local_used = tables.Column(get_local_used,
+    local_used = tables.Column('local_gb_used',
                                verbose_name=_("Storage (used)"),
-                               attrs={'data-type': 'size'})
+                               attrs={'data-type': 'size'},
+                          filters=(sizeformat.diskgbformat,))
 
     running_vms = tables.Column("running_vms",
                                 verbose_name=_("Instances"))
 
+    def get_object_id(self, hypervisor):
+        return hypervisor.hypervisor_hostname
+
     class Meta:
         name = "hypervisors"
         verbose_name = _("Hypervisors")
+
+
+class AdminHypervisorInstancesTable(tables.DataTable):
+    name = tables.Column("name",
+                         verbose_name=_("Instance Name"))
+
+    instance_id = tables.Column("uuid",
+                                verbose_name=_("Instance ID"))
+
+    def get_object_id(self, server):
+        return server['uuid']
+
+    class Meta:
+        name = "hypervisor_instances"
+        verbose_name = _("Hypervisor Instances")
