@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2013 B1 Systems GmbH
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -12,65 +14,55 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ugettext_lazy as _
 
 from horizon import exceptions
 from horizon import tables
-from horizon import tabs
-
 from openstack_dashboard import api
 from openstack_dashboard.dashboards.admin.hypervisors \
     import tables as project_tables
-from openstack_dashboard.dashboards.admin.hypervisors \
-    import tabs as project_tabs
 
 
-class AdminIndexView(tabs.TabbedTableView):
-    tab_group_class = project_tabs.HypervisorHostTabs
+class AdminIndexView(tables.DataTableView):
+    table_class = project_tables.AdminHypervisorsTable
     template_name = 'admin/hypervisors/index.html'
-    page_title = _("All Hypervisors")
+
+    def get_data(self):
+        hypervisors = []
+        try:
+            hypervisors = api.nova.hypervisor_list(self.request)
+        except Exception:
+            exceptions.handle(self.request,
+                _('Unable to retrieve hypervisor information.'))
+
+        return hypervisors
 
     def get_context_data(self, **kwargs):
-        context = super().get_context_data(**kwargs)
+        context = super(AdminIndexView, self).get_context_data(**kwargs)
         try:
             context["stats"] = api.nova.hypervisor_stats(self.request)
         except Exception:
             exceptions.handle(self.request,
-                              _('Unable to retrieve hypervisor statistics.'))
-        try:
-            context["providers"] = api.placement.get_providers(self.request)
-        except Exception:
-            exceptions.handle(self.request,
-                              _('Unable to retrieve providers statistics.'))
+                _('Unable to retrieve hypervisor statistics.'))
+
         return context
 
 
 class AdminDetailView(tables.DataTableView):
     table_class = project_tables.AdminHypervisorInstancesTable
     template_name = 'admin/hypervisors/detail.html'
-    page_title = _("Servers")
 
     def get_data(self):
         instances = []
         try:
-            id, name = self.kwargs['hypervisor'].split('_', 1)
             result = api.nova.hypervisor_search(self.request,
-                                                name)
+                                                self.kwargs['hypervisor'])
             for hypervisor in result:
-                if str(hypervisor.id) == id:
-                    try:
-                        instances += hypervisor.servers
-                    except AttributeError:
-                        pass
+                try:
+                    instances += hypervisor.servers
+                except AttributeError:
+                    pass
         except Exception:
-            exceptions.handle(
-                self.request,
+            exceptions.handle(self.request,
                 _('Unable to retrieve hypervisor instances list.'))
         return instances
-
-    def get_context_data(self, **kwargs):
-        context = super().get_context_data(**kwargs)
-        hypervisor_name = self.kwargs['hypervisor'].split('_', 1)[1]
-        breadcrumb = [(hypervisor_name, None)]
-        context['custom_breadcrumb'] = breadcrumb
-        return context
