@@ -18,14 +18,17 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.conf.urls.defaults import patterns, url
+from django.conf.urls import patterns  # noqa
+from django.conf.urls import url  # noqa
 
-from .views import IndexView, CreateView, UpdateView, DetailView
+from openstack_dashboard.dashboards.admin.images import views
 
 
 urlpatterns = patterns('openstack_dashboard.dashboards.admin.images.views',
-    url(r'^images/$', IndexView.as_view(), name='index'),
-    url(r'^create/$', CreateView.as_view(), name='create'),
-    url(r'^(?P<image_id>[^/]+)/update/$', UpdateView.as_view(), name='update'),
-    url(r'^(?P<image_id>[^/]+)/detail/$', DetailView.as_view(), name='detail')
+    url(r'^images/$', views.IndexView.as_view(), name='index'),
+    url(r'^create/$', views.CreateView.as_view(), name='create'),
+    url(r'^(?P<image_id>[^/]+)/update/$',
+        views.UpdateView.as_view(), name='update'),
+    url(r'^(?P<image_id>[^/]+)/detail/$',
+        views.DetailView.as_view(), name='detail')
 )
