@@ -25,9 +25,9 @@ import horizon
 from openstack_dashboard.dashboards.admin import dashboard
 
 
-class Quotas(horizon.Panel):
+class Info(horizon.Panel):
     name = _("System Info")
     slug = 'info'
 
 
-dashboard.Admin.register(Quotas)
+dashboard.Admin.register(Info)
