@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2012 United States Government as represented by the
 # Administrator of the National Aeronautics and Space Administration.
 # All Rights Reserved.
@@ -20,9 +18,10 @@
 
 from horizon import tabs
 
+from openstack_dashboard.dashboards.admin.info import constants
 from openstack_dashboard.dashboards.admin.info import tabs as project_tabs
 
 
 class IndexView(tabs.TabbedTableView):
     tab_group_class = project_tabs.SystemInfoTabs
-    template_name = 'admin/info/index.html'
+    template_name = constants.INFO_TEMPLATE_NAME
