@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2013 Kylin OS, Inc
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -13,7 +15,7 @@
 #    under the License.
 
 
-from django.urls import reverse
+from django.core.urlresolvers import reverse
 from django.utils.translation import ugettext_lazy as _
 
 from horizon import exceptions
@@ -21,8 +23,6 @@ from horizon import forms
 from horizon import messages
 
 from openstack_dashboard import api
-from openstack_dashboard.dashboards.project.instances \
-    import forms as project_forms
 
 
 class LiveMigrateForm(forms.SelfHandlingForm):
@@ -30,9 +30,9 @@ class LiveMigrateForm(forms.SelfHandlingForm):
                                    required=False,
                                    widget=forms.TextInput(
                                        attrs={'readonly': 'readonly'}))
-    host = forms.ThemableChoiceField(
-        label=_("New Host"),
-        help_text=_("Choose a Host to migrate to."))
+    host = forms.ChoiceField(label=_("New Host"),
+                             required=True,
+                             help_text=_("Choose a Host to migrate to."))
     disk_over_commit = forms.BooleanField(label=_("Disk Over Commit"),
                                           initial=False, required=False)
     block_migration = forms.BooleanField(label=_("Block Migration"),
@@ -50,37 +50,31 @@ class LiveMigrateForm(forms.SelfHandlingForm):
     def populate_host_choices(self, request, initial):
         hosts = initial.get('hosts')
         current_host = initial.get('current_host')
-        host_list = [(host, host) for host in hosts if host != current_host]
+        host_list = [(host.hypervisor_hostname,
+                      host.hypervisor_hostname)
+                     for host in hosts
+                     if host.service['host'] != current_host]
         if host_list:
-            host_list.insert(0, ("AUTO_SCHEDULE",
-                                 _("Automatically schedule new host.")))
+            host_list.insert(0, ("", _("Select a new host")))
         else:
-            host_list.insert(0, ("", _("No other hosts available")))
+            host_list.insert(0, ("", _("No other hosts available.")))
         return sorted(host_list)
 
     def handle(self, request, data):
         try:
             block_migration = data['block_migration']
             disk_over_commit = data['disk_over_commit']
-            host = None if data['host'] == 'AUTO_SCHEDULE' else data['host']
             api.nova.server_live_migrate(request,
                                          data['instance_id'],
-                                         host,
+                                         data['host'],
                                          block_migration=block_migration,
                                          disk_over_commit=disk_over_commit)
             msg = _('The instance is preparing the live migration '
-                    'to a new host.')
-            messages.info(request, msg)
+                    'to host "%s".') % data['host']
+            messages.success(request, msg)
             return True
         except Exception:
-            if data['host']:
-                msg = _('Failed to live migrate instance to '
-                        'host "%s".') % data['host']
-            else:
-                msg = _('Failed to live migrate instance to a new host.')
+            msg = _('Failed to live migrate instance to '
+                    'host "%s".') % data['host']
             redirect = reverse('horizon:admin:instances:index')
             exceptions.handle(request, msg, redirect=redirect)
-
-
-class RescueInstanceForm(project_forms.RescueInstanceForm):
-    failure_url = 'horizon:admin:instances:index'
