@@ -19,13 +19,19 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.utils.datastructures import SortedDict  # noqa
-from django.utils.translation import ugettext_lazy as _  # noqa
+from django.core.urlresolvers import reverse
+from django.core.urlresolvers import reverse_lazy
+from django.utils.datastructures import SortedDict
+from django.utils.translation import ugettext_lazy as _
 
 from horizon import exceptions
+from horizon import forms
 from horizon import tables
+from horizon.utils import memoized
 
 from openstack_dashboard import api
+from openstack_dashboard.dashboards.admin.instances \
+    import forms as project_forms
 from openstack_dashboard.dashboards.admin.instances \
     import tables as project_tables
 from openstack_dashboard.dashboards.project.instances import views
@@ -48,6 +54,11 @@ def spice(args, **kvargs):
     return views.spice(args, **kvargs)
 
 
+# re-use rdp from project.instances.views to make reflection work
+def rdp(args, **kvargs):
+    return views.rdp(args, **kvargs)
+
+
 class AdminUpdateView(views.UpdateView):
     workflow_class = update_instance.AdminUpdateInstance
 
@@ -74,6 +85,14 @@ class AdminIndexView(tables.DataTableView):
             exceptions.handle(self.request,
                               _('Unable to retrieve instance list.'))
         if instances:
+            try:
+                api.network.servers_update_addresses(self.request, instances)
+            except Exception:
+                exceptions.handle(
+                    self.request,
+                    message=_('Unable to retrieve IP addresses from Neutron.'),
+                    ignore=True)
+
             # Gather our flavors to correlate against IDs
             try:
                 flavors = api.nova.flavor_list(self.request)
@@ -108,3 +127,48 @@ class AdminIndexView(tables.DataTableView):
                 tenant = tenant_dict.get(inst.tenant_id, None)
                 inst.tenant_name = getattr(tenant, "name", None)
         return instances
+
+
+class LiveMigrateView(forms.ModalFormView):
+    form_class = project_forms.LiveMigrateForm
+    template_name = 'admin/instances/live_migrate.html'
+    context_object_name = 'instance'
+    success_url = reverse_lazy("horizon:admin:instances:index")
+
+    def get_context_data(self, **kwargs):
+        context = super(LiveMigrateView, self).get_context_data(**kwargs)
+        context["instance_id"] = self.kwargs['instance_id']
+        return context
+
+    @memoized.memoized_method
+    def get_hosts(self, *args, **kwargs):
+        try:
+            return api.nova.hypervisor_list(self.request)
+        except Exception:
+            redirect = reverse("horizon:admin:instances:index")
+            msg = _('Unable to retrieve hypervisor information.')
+            exceptions.handle(self.request, msg, redirect=redirect)
+
+    @memoized.memoized_method
+    def get_object(self, *args, **kwargs):
+        instance_id = self.kwargs['instance_id']
+        try:
+            return api.nova.server_get(self.request, instance_id)
+        except Exception:
+            redirect = reverse("horizon:admin:instances:index")
+            msg = _('Unable to retrieve instance details.')
+            exceptions.handle(self.request, msg, redirect=redirect)
+
+    def get_initial(self):
+        initial = super(LiveMigrateView, self).get_initial()
+        _object = self.get_object()
+        if _object:
+            current_host = getattr(_object, 'OS-EXT-SRV-ATTR:host', '')
+            initial.update({'instance_id': self.kwargs['instance_id'],
+                            'current_host': current_host,
+                            'hosts': self.get_hosts()})
+        return initial
+
+
+class DetailView(views.DetailView):
+    redirect_url = 'horizon:admin:instances:index'
