@@ -14,8 +14,8 @@
 import json
 import uuid
 
-from django.core.urlresolvers import reverse  # noqa
-from django import http  # noqa
+from django.core.urlresolvers import reverse
+from django import http
 from mox import IsA  # noqa
 
 from openstack_dashboard import api
@@ -27,13 +27,9 @@ INDEX_URL = reverse("horizon:admin:metering:index")
 
 class MeteringViewTests(test.APITestCase, test.BaseAdminViewTests):
     def test_stats_page(self):
-        resources = self.resources.list()
-        ceilometerclient = self.stub_ceilometerclient()
-        ceilometerclient.resources = self.mox.CreateMockAnything()
-        # I am returning only 1 resource
-        ceilometerclient.resources.list(q=IsA(list)).AndReturn(resources[:1])
-
         meters = self.meters.list()
+
+        ceilometerclient = self.stub_ceilometerclient()
         ceilometerclient.meters = self.mox.CreateMockAnything()
         ceilometerclient.meters.list(None).AndReturn(meters)
 
@@ -45,6 +41,13 @@ class MeteringViewTests(test.APITestCase, test.BaseAdminViewTests):
         self.assertTemplateUsed(res, 'admin/metering/index.html')
         self.assertTemplateUsed(res, 'admin/metering/stats.html')
 
+    def test_report_page(self):
+        # getting report page with no api access
+        res = self.client.get(reverse('horizon:admin:metering:index') +
+            "?tab=ceilometer_overview__daily_report")
+        self.assertTemplateUsed(res, 'admin/metering/index.html')
+        self.assertTemplateUsed(res, 'admin/metering/daily.html')
+
     def _verify_series(self, series, value, date, expected_names):
         expected_names.reverse()
         data = json.loads(series)
@@ -58,7 +61,7 @@ class MeteringViewTests(test.APITestCase, test.BaseAdminViewTests):
             self.assertEqual(d.get('name'), expected_names.pop())
             self.assertEqual(d.get('unit'), '')
 
-        self.assertEquals(data.get('settings'), {})
+        self.assertEqual(data.get('settings'), {})
 
     @test.create_stubs({api.keystone: ('tenant_list',)})
     def test_stats_for_line_chart(self):
@@ -150,6 +153,44 @@ class MeteringViewTests(test.APITestCase, test.BaseAdminViewTests):
         self._verify_series(res._container[0], 4.55, '2012-12-21T11:00:55',
                             expected_names)
 
+    @test.create_stubs({api.keystone: ('tenant_list',)})
+    def test_report(self):
+        meters = self.meters.list()
+        ceilometerclient = self.stub_ceilometerclient()
+        ceilometerclient.meters = self.mox.CreateMockAnything()
+        ceilometerclient.meters.list(None).AndReturn(meters)
+
+        api.keystone.tenant_list(IsA(http.HttpRequest),
+                                 domain=None,
+                                 paginate=False). \
+            MultipleTimes()\
+            .AndReturn([self.tenants.list(), False])
+
+        statistics = self.statistics.list()
+        ceilometerclient = self.stub_ceilometerclient()
+        ceilometerclient.statistics = self.mox.CreateMockAnything()
+
+        ceilometerclient.statistics.list(meter_name="instance",
+                                         period=IsA(int), q=IsA(list)).\
+            MultipleTimes().\
+            AndReturn(statistics)
+        ceilometerclient.statistics.list(meter_name="disk.read.bytes",
+                                         period=IsA(int), q=IsA(list)).\
+            MultipleTimes().\
+            AndReturn(statistics)
+        ceilometerclient.statistics.list(meter_name="disk.write.bytes",
+                                         period=IsA(int), q=IsA(list)).\
+            MultipleTimes().\
+            AndReturn(statistics)
+
+        self.mox.ReplayAll()
+
+        # generate report with mock data
+        res = self.client.post(reverse('horizon:admin:metering:report'),
+                               data={"date_options": "7"})
+
+        self.assertTemplateUsed(res, 'admin/metering/report.html')
+
 
 class MeteringStatsTabTests(test.APITestCase):
 
@@ -181,8 +222,6 @@ class MeteringStatsTabTests(test.APITestCase):
         api.nova.flavor_list(request, None).AndReturn(self.flavors.list())
 
         ceilometerclient = self.stub_ceilometerclient()
-        ceilometerclient.resources = self.mox.CreateMockAnything()
-        ceilometerclient.resources.list(q=IsA(list)).AndReturn(resources)
 
         meters = []
         for r in resources:
@@ -200,10 +239,10 @@ class MeteringStatsTabTests(test.APITestCase):
         tab = tabs.GlobalStatsTab(None)
         context_data = tab.get_context_data(request)
 
-        self.assertTrue('meters' in context_data)
+        self.assertTrue('nova_meters' in context_data)
         meter_hints = {}
-        for d in context_data['meters']:
-            meter_hints[d.name] = d.title
+        for d in context_data['nova_meters']:
+            meter_hints[d.name] = d.description
 
         expected_meters = ['instance:%s' % f for f in flavors]
         expected_meters.extend(['instance', 'cpu'])
