@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -10,13 +12,12 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from django.conf.urls import url
+from django.conf.urls import patterns  # noqa
+from django.conf.urls import url  # noqa
 
 from openstack_dashboard.dashboards.admin.metering import views
 
-urlpatterns = [
+urlpatterns = patterns('openstack_dashboard.dashboards.admin.metering.views',
     url(r'^$', views.IndexView.as_view(), name='index'),
-    url(r'^create/$', views.CreateUsageReport.as_view(), name='create'),
     url(r'^samples$', views.SamplesView.as_view(), name='samples'),
-    url(r'^report/csv$', views.CsvReportView.as_view(), name='csvreport'),
-]
+    url(r'^report$', views.ReportView.as_view(), name='report'))
