@@ -16,9 +16,8 @@
 
 import logging
 
-from django.core.urlresolvers import reverse  # noqa
-from django.utils import datastructures  # noqa
-from django.utils.translation import ugettext_lazy as _  # noqa
+from django.core.urlresolvers import reverse
+from django.utils.translation import ugettext_lazy as _
 
 from horizon import exceptions
 from horizon import forms
@@ -113,7 +112,7 @@ class UpdateNetwork(forms.SelfHandlingForm):
                       'admin_state_up': data['admin_state'],
                       'shared': data['shared'],
                       'router:external': data['external']}
-            network = api.neutron.network_modify(request, data['network_id'],
+            network = api.neutron.network_update(request, data['network_id'],
                                                  **params)
             msg = _('Network %s was successfully updated.') % data['name']
             LOG.debug(msg)
