@@ -44,29 +44,31 @@ class CreatePort(forms.SelfHandlingForm):
     admin_state = forms.BooleanField(label=_("Admin State"),
                                      initial=True, required=False)
     device_id = forms.CharField(max_length=100, label=_("Device ID"),
-                                help_text='Device ID attached to the port',
+                                help_text=_("Device ID attached to the port"),
                                 required=False)
     device_owner = forms.CharField(max_length=100, label=_("Device Owner"),
-                                help_text='Device owner attached to the port',
-                                required=False)
+                                   help_text=_("Device owner attached to the "
+                                               "port"),
+                                   required=False)
 
     def handle(self, request, data):
         try:
             # We must specify tenant_id of the network which a subnet is
             # created for if admin user does not belong to the tenant.
-            network = api.quantum.network_get(request, data['network_id'])
+            network = api.neutron.network_get(request, data['network_id'])
             data['tenant_id'] = network.tenant_id
             data['admin_state_up'] = data['admin_state']
+            del data['network_name']
             del data['admin_state']
 
-            port = api.quantum.port_create(request, **data)
+            port = api.neutron.port_create(request, **data)
             msg = _('Port %s was successfully created.') % port['id']
             LOG.debug(msg)
             messages.success(request, msg)
             return port
-        except:
+        except Exception:
             msg = _('Failed to create a port for network %s') \
-                  % data['network_id']
+                % data['network_id']
             LOG.info(msg)
             redirect = reverse('horizon:admin:networks:detail',
                                args=(data['network_id'],))
@@ -76,17 +78,18 @@ class CreatePort(forms.SelfHandlingForm):
 class UpdatePort(project_forms.UpdatePort):
     #tenant_id = forms.CharField(widget=forms.HiddenInput())
     device_id = forms.CharField(max_length=100, label=_("Device ID"),
-                                help_text='Device ID attached to the port',
+                                help_text=_("Device ID attached to the port"),
                                 required=False)
     device_owner = forms.CharField(max_length=100, label=_("Device Owner"),
-                                help_text='Device owner attached to the port',
-                                required=False)
+                                   help_text=_("Device owner attached to the "
+                                               "port"),
+                                   required=False)
     failure_url = 'horizon:admin:networks:detail'
 
     def handle(self, request, data):
         try:
             LOG.debug('params = %s' % data)
-            port = api.quantum.port_modify(request, data['port_id'],
+            port = api.neutron.port_update(request, data['port_id'],
                                            name=data['name'],
                                            admin_state_up=data['admin_state'],
                                            device_id=data['device_id'],
