@@ -18,20 +18,17 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.conf.urls.defaults import patterns, url
+from django.conf.urls import patterns  # noqa
+from django.conf.urls import url  # noqa
 
-from .views import (IndexView, TenantUsageView,
-                    CreateProjectView, UpdateProjectView,
-                    CreateUserView)
+from openstack_dashboard.dashboards.admin.projects import views
 
 
 urlpatterns = patterns('',
-    url(r'^$', IndexView.as_view(), name='index'),
-    url(r'^create$', CreateProjectView.as_view(), name='create'),
+    url(r'^$', views.IndexView.as_view(), name='index'),
+    url(r'^create$', views.CreateProjectView.as_view(), name='create'),
     url(r'^(?P<tenant_id>[^/]+)/update/$',
-        UpdateProjectView.as_view(), name='update'),
-    url(r'^(?P<tenant_id>[^/]+)/usage/$',
-        TenantUsageView.as_view(), name='usage'),
-    url(r'^(?P<tenant_id>[^/]+)/create_user/$',
-        CreateUserView.as_view(), name='create_user'),
+        views.UpdateProjectView.as_view(), name='update'),
+    url(r'^(?P<project_id>[^/]+)/usage/$',
+        views.ProjectUsageView.as_view(), name='usage'),
 )
