@@ -19,9 +19,9 @@
 #    under the License.
 
 
-from django.conf import settings  # noqa
-from django.core.urlresolvers import reverse  # noqa
-from django.utils.translation import ugettext_lazy as _  # noqa
+from django.conf import settings
+from django.core.urlresolvers import reverse
+from django.utils.translation import ugettext_lazy as _
 
 from horizon import exceptions
 from horizon import forms
@@ -53,8 +53,9 @@ class UpdateProjectQuotaAction(workflows.Action):
     injected_file_content_bytes = forms.IntegerField(min_value=-1,
                                                      label=ifcb_label)
     volumes = forms.IntegerField(min_value=-1, label=_("Volumes"))
-    snapshots = forms.IntegerField(min_value=-1, label=_("Snapshots"))
-    gigabytes = forms.IntegerField(min_value=-1, label=_("Gigabytes"))
+    snapshots = forms.IntegerField(min_value=-1, label=_("Volume Snapshots"))
+    gigabytes = forms.IntegerField(
+        min_value=-1, label=_("Total Size of Volumes and Snapshots (GB)"))
     ram = forms.IntegerField(min_value=-1, label=_("RAM (MB)"))
     floating_ips = forms.IntegerField(min_value=-1, label=_("Floating IPs"))
     fixed_ips = forms.IntegerField(min_value=-1, label=_("Fixed IPs"))
@@ -105,7 +106,8 @@ class CreateProjectInfoAction(workflows.Action):
     domain_name = forms.CharField(label=_("Domain Name"),
                                   required=False,
                                   widget=forms.HiddenInput())
-    name = forms.CharField(label=_("Name"))
+    name = forms.CharField(label=_("Name"),
+                           max_length=64)
     description = forms.CharField(widget=forms.widgets.Textarea(),
                                   label=_("Description"),
                                   required=False)
