@@ -14,11 +14,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.conf.urls.defaults import patterns, url
+from django.conf.urls import patterns  # noqa
+from django.conf.urls import url  # noqa
 
-from .views import DetailView
+from openstack_dashboard.dashboards.admin.routers.ports import views
 
 PORTS = r'^(?P<port_id>[^/]+)/%s$'
 
 urlpatterns = patterns('horizon.dashboards.admin.networks.ports.views',
-    url(PORTS % 'detail', DetailView.as_view(), name='detail'))
+    url(PORTS % 'detail', views.DetailView.as_view(), name='detail'))
