@@ -14,15 +14,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import logging
-
 from horizon import tabs
-from .tabs import PortDetailTabs
 
-
-LOG = logging.getLogger(__name__)
+from openstack_dashboard.dashboards.admin.routers.ports \
+    import tabs as project_tabs
 
 
 class DetailView(tabs.TabView):
-    tab_group_class = PortDetailTabs
+    tab_group_class = project_tabs.PortDetailTabs
     template_name = 'admin/networks/ports/detail.html'
