@@ -14,9 +14,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import logging
-
-from django.template.defaultfilters import title
+from django.template.defaultfilters import title  # noqa
 from django.utils.translation import ugettext_lazy as _
 
 from horizon import tables
@@ -24,18 +22,15 @@ from openstack_dashboard import api
 from openstack_dashboard.dashboards.project.routers import tables as r_tables
 
 
-LOG = logging.getLogger(__name__)
-
-
 class DeleteRouter(r_tables.DeleteRouter):
     redirect_url = "horizon:admin:routers:index"
 
     def delete(self, request, obj_id):
         search_opts = {'device_owner': 'network:router_interface',
                        'device_id': obj_id}
-        ports = api.quantum.port_list(request, **search_opts)
+        ports = api.neutron.port_list(request, **search_opts)
         for port in ports:
-            api.quantum.router_remove_interface(request, obj_id,
+            api.neutron.router_remove_interface(request, obj_id,
                                                 port_id=port.id)
         super(DeleteRouter, self).delete(request, obj_id)
 
@@ -47,7 +42,7 @@ class UpdateRow(tables.Row):
     ajax = True
 
     def get_data(self, request, router_id):
-        router = api.quantum.router_get(request, router_id)
+        router = api.neutron.router_get(request, router_id)
         return router
 
 
