@@ -32,17 +32,19 @@ from horizon import workflows
 
 from openstack_dashboard import api
 from openstack_dashboard.usage import quotas
-from .forms import FloatingIpAllocate
-from .workflows import IPAssociationWorkflow
+
+from openstack_dashboard.dashboards.project.access_and_security.\
+    floating_ips import forms as project_forms
+from openstack_dashboard.dashboards.project.access_and_security.\
+    floating_ips import workflows as project_workflows
 
 
 class AssociateView(workflows.WorkflowView):
-    workflow_class = IPAssociationWorkflow
-    template_name = "project/access_and_security/floating_ips/associate.html"
+    workflow_class = project_workflows.IPAssociationWorkflow
 
 
 class AllocateView(forms.ModalFormView):
-    form_class = FloatingIpAllocate
+    form_class = project_forms.FloatingIpAllocate
     template_name = 'project/access_and_security/floating_ips/allocate.html'
     success_url = reverse_lazy('horizon:project:access_and_security:index')
 
@@ -53,18 +55,18 @@ class AllocateView(forms.ModalFormView):
         context = super(AllocateView, self).get_context_data(**kwargs)
         try:
             context['usages'] = quotas.tenant_quota_usages(self.request)
-        except:
+        except Exception:
             exceptions.handle(self.request)
         return context
 
     def get_initial(self):
         try:
             pools = api.network.floating_ip_pools_list(self.request)
-        except:
+        except Exception:
             pools = []
             exceptions.handle(self.request,
                               _("Unable to retrieve floating IP pools."))
         pool_list = [(pool.id, pool.name) for pool in pools]
         if not pool_list:
-            pool_list = [(None, _("No floating IP pools available."))]
+            pool_list = [(None, _("No floating IP pools available"))]
         return {'pool_list': pool_list}
