@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2012 United States Government as represented by the
 # Administrator of the National Aeronautics and Space Administration.
 # All Rights Reserved.
@@ -18,6 +20,7 @@
 
 import re
 
+from django.core import validators
 from django.utils.translation import ugettext_lazy as _
 
 from horizon import exceptions
@@ -28,44 +31,26 @@ from openstack_dashboard import api
 
 
 NEW_LINES = re.compile(r"\r|\n")
-
-KEYPAIR_NAME_REGEX = re.compile(r"^\w+(?:[- ]\w+)*$", re.UNICODE)
-KEYPAIR_ERROR_MESSAGES = {
-    'invalid': _('Key pair name may only contain letters, '
-                 'numbers, underscores, spaces, and hyphens '
-                 'and may not be white space.')}
+KEYPAIR_ERROR_MESSAGES = {'invalid': _('Key pair names may '
+                                'only contain letters, numbers, underscores '
+                                'and hyphens.')}
 
 
 class CreateKeypair(forms.SelfHandlingForm):
-    name = forms.RegexField(max_length=255,
-                            label=_("Key Pair Name"),
-                            regex=KEYPAIR_NAME_REGEX,
-                            error_messages=KEYPAIR_ERROR_MESSAGES)
+    name = forms.CharField(max_length="255",
+                           label=_("Key Pair Name"),
+                           validators=[validators.validate_slug],
+                           error_messages=KEYPAIR_ERROR_MESSAGES)
 
     def handle(self, request, data):
         return True  # We just redirect to the download view.
 
-    def clean(self):
-        cleaned_data = super(CreateKeypair, self).clean()
-        name = cleaned_data.get('name')
-        try:
-            keypairs = api.nova.keypair_list(self.request)
-        except Exception:
-            exceptions.handle(self.request, ignore=True)
-            keypairs = []
-        if name in [keypair.name for keypair in keypairs]:
-            error_msg = _("The name is already in use.")
-            self._errors['name'] = self.error_class([error_msg])
-        return cleaned_data
-
 
 class ImportKeypair(forms.SelfHandlingForm):
-    name = forms.RegexField(max_length=255,
-                            label=_("Key Pair Name"),
-                            regex=KEYPAIR_NAME_REGEX,
-                            error_messages=KEYPAIR_ERROR_MESSAGES)
-    public_key = forms.CharField(label=_("Public Key"),
-                                 widget=forms.Textarea())
+    name = forms.CharField(max_length="255", label=_("Key Pair Name"),
+                 validators=[validators.validate_slug],
+                 error_messages=KEYPAIR_ERROR_MESSAGES)
+    public_key = forms.CharField(label=_("Public Key"), widget=forms.Textarea)
 
     def handle(self, request, data):
         try:
@@ -74,9 +59,8 @@ class ImportKeypair(forms.SelfHandlingForm):
             keypair = api.nova.keypair_import(request,
                                               data['name'],
                                               data['public_key'])
-            messages.success(request,
-                             _('Successfully imported public key: %s')
-                             % data['name'])
+            messages.success(request, _('Successfully imported public key: %s')
+                                       % data['name'])
             return keypair
         except Exception:
             exceptions.handle(request, ignore=True)
