@@ -14,18 +14,14 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import logging
-
+from django.conf import settings
 from django.core.urlresolvers import reverse
 from django.utils.translation import ugettext_lazy as _
 
 from horizon import tables
 
 from openstack_dashboard import api
-from ..floating_ips.utils import get_int_or_uuid
-
-
-LOG = logging.getLogger(__name__)
+from openstack_dashboard.utils import filters
 
 
 class DeleteGroup(tables.DeleteAction):
@@ -38,7 +34,7 @@ class DeleteGroup(tables.DeleteAction):
         return security_group.name != 'default'
 
     def delete(self, request, obj_id):
-        api.nova.security_group_delete(request, obj_id)
+        api.network.security_group_delete(request, obj_id)
 
 
 class CreateGroup(tables.LinkAction):
@@ -48,9 +44,21 @@ class CreateGroup(tables.LinkAction):
     classes = ("ajax-modal", "btn-create")
 
 
-class EditRules(tables.LinkAction):
-    name = "edit_rules"
-    verbose_name = _("Edit Rules")
+class EditGroup(tables.LinkAction):
+    name = "edit"
+    verbose_name = _("Edit Security Group")
+    url = "horizon:project:access_and_security:security_groups:update"
+    classes = ("ajax-modal", "btn-edit")
+
+    def allowed(self, request, security_group=None):
+        if not security_group:
+            return True
+        return security_group.name != 'default'
+
+
+class ManageRules(tables.LinkAction):
+    name = "manage_rules"
+    verbose_name = _("Manage Rules")
     url = "horizon:project:access_and_security:security_groups:detail"
     classes = ("btn-edit")
 
@@ -60,13 +68,13 @@ class SecurityGroupsTable(tables.DataTable):
     description = tables.Column("description", verbose_name=_("Description"))
 
     def sanitize_id(self, obj_id):
-        return get_int_or_uuid(obj_id)
+        return filters.get_int_or_uuid(obj_id)
 
     class Meta:
         name = "security_groups"
         verbose_name = _("Security Groups")
         table_actions = (CreateGroup, DeleteGroup)
-        row_actions = (EditRules, DeleteGroup)
+        row_actions = (ManageRules, EditGroup, DeleteGroup)
 
 
 class CreateRule(tables.LinkAction):
@@ -84,7 +92,7 @@ class DeleteRule(tables.DeleteAction):
     data_type_plural = _("Rules")
 
     def delete(self, request, obj_id):
-        api.nova.security_group_rule_delete(request, obj_id)
+        api.network.security_group_rule_delete(request, obj_id)
 
     def get_success_url(self, request):
         sg_id = self.table.kwargs['security_group_id']
@@ -92,34 +100,70 @@ class DeleteRule(tables.DeleteAction):
                        "security_groups:detail", args=[sg_id])
 
 
-def get_source(rule):
+def get_remote(rule):
     if 'cidr' in rule.ip_range:
         if rule.ip_range['cidr'] is None:
-            return '0.0.0.0/0 (CIDR)'
+            range = '::/0' if rule.ethertype == 'IPv6' else '0.0.0.0/0'
         else:
-            return rule.ip_range['cidr'] + ' (CIDR)'
+            range = rule.ip_range['cidr']
+        return range + ' (CIDR)'
     elif 'name' in rule.group:
         return rule.group['name']
     else:
         return None
 
 
+def get_port_range(rule):
+    ip_proto = rule.ip_protocol
+    if rule.from_port == rule.to_port:
+        return check_rule_template(rule.from_port, ip_proto)
+    else:
+        return (u"%(from)s - %(to)s" %
+                {'from': check_rule_template(rule.from_port, ip_proto),
+                 'to': check_rule_template(rule.to_port, ip_proto)})
+
+
+def filter_direction(direction):
+    if direction is None or direction.lower() == 'ingress':
+        return _('Ingress')
+    else:
+        return _('Egress')
+
+
 def filter_protocol(protocol):
     if protocol is None:
         return _('Any')
     return unicode.upper(protocol)
 
 
+def check_rule_template(port, ip_proto):
+    rules_dict = getattr(settings, 'SECURITY_GROUP_RULES', {})
+    if not rules_dict:
+        return port
+    templ_rule = filter(lambda rule: str(port) == rule['from_port']
+                        and str(port) == rule['to_port']
+                        and ip_proto == rule['ip_protocol'],
+                        [rule for rule in rules_dict.values()])
+    if templ_rule:
+        return u"%(from_port)s (%(name)s)" % templ_rule[0]
+    return port
+
+
 class RulesTable(tables.DataTable):
+    direction = tables.Column("direction",
+                              verbose_name=_("Direction"),
+                              filters=(filter_direction,))
+    ethertype = tables.Column("ethertype",
+                              verbose_name=_("Ether Type"))
     protocol = tables.Column("ip_protocol",
                              verbose_name=_("IP Protocol"),
                              filters=(filter_protocol,))
-    from_port = tables.Column("from_port", verbose_name=_("From Port"))
-    to_port = tables.Column("to_port", verbose_name=_("To Port"))
-    source = tables.Column(get_source, verbose_name=_("Source"))
+    port_range = tables.Column(get_port_range,
+                               verbose_name=_("Port Range"))
+    remote = tables.Column(get_remote, verbose_name=_("Remote"))
 
     def sanitize_id(self, obj_id):
-        return get_int_or_uuid(obj_id)
+        return filters.get_int_or_uuid(obj_id)
 
     def get_object_display(self, rule):
         return unicode(rule)
