@@ -18,17 +18,22 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.conf.urls.defaults import patterns, url
+from django.conf.urls import patterns  # noqa
+from django.conf.urls import url  # noqa
 
-from .views import CreateView, DetailView, AddRuleView
+from openstack_dashboard.dashboards.project.access_and_security.\
+    security_groups import views
 
 
 urlpatterns = patterns('',
-    url(r'^create/$', CreateView.as_view(), name='create'),
+    url(r'^create/$', views.CreateView.as_view(), name='create'),
     url(r'^(?P<security_group_id>[^/]+)/$',
-        DetailView.as_view(),
+        views.DetailView.as_view(),
         name='detail'),
     url(r'^(?P<security_group_id>[^/]+)/add_rule/$',
-        AddRuleView.as_view(),
-        name='add_rule')
+        views.AddRuleView.as_view(),
+        name='add_rule'),
+    url(r'^(?P<security_group_id>[^/]+)/update/$',
+        views.UpdateView.as_view(),
+        name='update')
 )
