@@ -5,7 +5,7 @@
 # All Rights Reserved.
 #
 # Copyright 2012 Nebula, Inc.
-# Copyright 2012 OpenStack LLC
+# Copyright 2012 OpenStack Foundation
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
@@ -29,10 +29,14 @@ from openstack_dashboard.api import keystone
 from openstack_dashboard.api import network
 from openstack_dashboard.api import nova
 
-from .keypairs.tables import KeypairsTable
-from .floating_ips.tables import FloatingIPsTable
-from .security_groups.tables import SecurityGroupsTable
-from .api_access.tables import EndpointsTable
+from openstack_dashboard.dashboards.project.access_and_security.\
+    api_access.tables import EndpointsTable
+from openstack_dashboard.dashboards.project.access_and_security.\
+    floating_ips.tables import FloatingIPsTable
+from openstack_dashboard.dashboards.project.access_and_security.\
+    keypairs.tables import KeypairsTable
+from openstack_dashboard.dashboards.project.access_and_security.\
+    security_groups.tables import SecurityGroupsTable
 
 
 class SecurityGroupsTab(tabs.TableTab):
@@ -43,8 +47,8 @@ class SecurityGroupsTab(tabs.TableTab):
 
     def get_security_groups_data(self):
         try:
-            security_groups = nova.security_group_list(self.request)
-        except:
+            security_groups = network.security_group_list(self.request)
+        except Exception:
             security_groups = []
             exceptions.handle(self.request,
                               _('Unable to retrieve security groups.'))
@@ -53,17 +57,17 @@ class SecurityGroupsTab(tabs.TableTab):
 
 class KeypairsTab(tabs.TableTab):
     table_classes = (KeypairsTable,)
-    name = _("Keypairs")
+    name = _("Key Pairs")
     slug = "keypairs_tab"
     template_name = "horizon/common/_detail_table.html"
 
     def get_keypairs_data(self):
         try:
             keypairs = nova.keypair_list(self.request)
-        except:
+        except Exception:
             keypairs = []
             exceptions.handle(self.request,
-                              _('Unable to retrieve keypair list.'))
+                              _('Unable to retrieve key pair list.'))
         return keypairs
 
 
@@ -76,14 +80,14 @@ class FloatingIPsTab(tabs.TableTab):
     def get_floating_ips_data(self):
         try:
             floating_ips = network.tenant_floating_ip_list(self.request)
-        except:
+        except Exception:
             floating_ips = []
             exceptions.handle(self.request,
                               _('Unable to retrieve floating IP addresses.'))
 
         try:
             floating_ip_pools = network.floating_ip_pools_list(self.request)
-        except:
+        except Exception:
             floating_ip_pools = []
             messages.warning(self.request,
                              _('Unable to retrieve floating IP pools.'))
@@ -91,16 +95,15 @@ class FloatingIPsTab(tabs.TableTab):
 
         instances = []
         try:
-            instances = nova.server_list(self.request, all_tenants=True)
-        except:
+            instances, has_more = nova.server_list(self.request)
+        except Exception:
             exceptions.handle(self.request,
                         _('Unable to retrieve instance list.'))
 
-        instances_dict = dict([(obj.id, obj) for obj in instances])
+        instances_dict = dict([(obj.id, obj.name) for obj in instances])
 
         for ip in floating_ips:
-            ip.instance_name = instances_dict[ip.instance_id].name \
-                if ip.instance_id in instances_dict else None
+            ip.instance_name = instances_dict.get(ip.instance_id)
             ip.pool_name = pool_dict.get(ip.pool, ip.pool)
 
         return floating_ips
@@ -116,7 +119,9 @@ class APIAccessTab(tabs.TableTab):
         services = []
         for i, service in enumerate(self.request.user.service_catalog):
             service['id'] = i
-            services.append(keystone.Service(service))
+            services.append(
+                keystone.Service(service, self.request.user.services_region))
+
         return services
 
 
