@@ -5,7 +5,7 @@
 # All Rights Reserved.
 #
 # Copyright 2012 Nebula, Inc.
-# Copyright 2012 OpenStack LLC
+# Copyright 2012 OpenStack Foundation
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
@@ -25,9 +25,10 @@ Views for Instances and Volumes.
 
 from horizon import tabs
 
-from .tabs import AccessAndSecurityTabs
+from openstack_dashboard.dashboards.project.access_and_security \
+    import tabs as project_tabs
 
 
 class IndexView(tabs.TabbedTableView):
-    tab_group_class = AccessAndSecurityTabs
+    tab_group_class = project_tabs.AccessAndSecurityTabs
     template_name = 'project/access_and_security/index.html'
