@@ -1,3 +1,4 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
 #    Copyright 2013, Big Switch Networks, Inc.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -11,6 +12,8 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
+#
+# @author: KC Wang, Big Switch Networks
 
 from django.core.urlresolvers import reverse_lazy
 from django.utils.translation import ugettext_lazy as _
@@ -35,12 +38,14 @@ class RulesTab(tabs.TableTab):
     def get_rulestable_data(self):
         try:
             tenant_id = self.request.user.tenant_id
-            request = self.tab_group.request
-            rules = api.fwaas.rule_list_for_tenant(request, tenant_id)
+            rules = api.fwaas.rule_list(self.tab_group.request,
+                                        tenant_id=tenant_id)
         except Exception:
             rules = []
             exceptions.handle(self.tab_group.request,
                               _('Unable to retrieve rules list.'))
+        for r in rules:
+            r.set_id_as_name_if_empty()
 
         return rules
 
@@ -54,12 +59,14 @@ class PoliciesTab(tabs.TableTab):
     def get_policiestable_data(self):
         try:
             tenant_id = self.request.user.tenant_id
-            request = self.tab_group.request
-            policies = api.fwaas.policy_list_for_tenant(request, tenant_id)
+            policies = api.fwaas.policy_list(self.tab_group.request,
+                                             tenant_id=tenant_id)
         except Exception:
             policies = []
             exceptions.handle(self.tab_group.request,
                               _('Unable to retrieve policies list.'))
+        for p in policies:
+            p.set_id_as_name_if_empty()
 
         return policies
 
@@ -73,23 +80,16 @@ class FirewallsTab(tabs.TableTab):
     def get_firewallstable_data(self):
         try:
             tenant_id = self.request.user.tenant_id
-            request = self.tab_group.request
-            firewalls = api.fwaas.firewall_list_for_tenant(request, tenant_id)
-
-            if api.neutron.is_extension_supported(request,
-                                                  'fwaasrouterinsertion'):
-                routers = api.neutron.router_list(request, tenant_id=tenant_id)
-
-                for fw in firewalls:
-                    router_list = [r for r in routers
-                                   if r['id'] in fw['router_ids']]
-                    fw.get_dict()['routers'] = router_list
-
+            firewalls = api.fwaas.firewall_list(self.tab_group.request,
+                                                tenant_id=tenant_id)
         except Exception:
             firewalls = []
             exceptions.handle(self.tab_group.request,
                               _('Unable to retrieve firewall list.'))
 
+        for f in firewalls:
+            f.set_id_as_name_if_empty()
+
         return firewalls
 
 
@@ -137,21 +137,11 @@ class FirewallDetailsTab(tabs.Tab):
         fid = self.tab_group.kwargs['firewall_id']
         try:
             firewall = api.fwaas.firewall_get(request, fid)
-            body = {'firewall': firewall}
-            if api.neutron.is_extension_supported(request,
-                                                  'fwaasrouterinsertion'):
-                tenant_id = self.request.user.tenant_id
-                tenant_routers = api.neutron.router_list(request,
-                                                         tenant_id=tenant_id)
-                router_ids = firewall.get_dict()['router_ids']
-                routers = [r for r in tenant_routers
-                           if r['id'] in router_ids]
-                body['routers'] = routers
         except Exception:
             exceptions.handle(request,
                               _('Unable to retrieve firewall details.'),
                               redirect=self.failure_url)
-        return body
+        return {'firewall': firewall}
 
 
 class FirewallTabs(tabs.TabGroup):
