@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2012 United States Government as represented by the
 # Administrator of the National Aeronautics and Space Administration.
 # All Rights Reserved.
@@ -16,26 +18,18 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.urls import re_path
-from django.utils.translation import gettext_lazy as _
+from django.conf.urls import patterns  # noqa
+from django.conf.urls import url  # noqa
 
-from horizon.browsers.views import AngularIndexView
 from openstack_dashboard.dashboards.project.images.images import views
-from openstack_dashboard.utils import settings as setting_utils
 
 
-if setting_utils.get_dict_config('ANGULAR_FEATURES', 'images_panel'):
-    title = _("Images")
-    urlpatterns = [
-        re_path(r'^(?P<image_id>[^/]+)/$',
-                AngularIndexView.as_view(title=title),
-                name='detail'),
-    ]
-else:
-    urlpatterns = [
-        re_path(r'^create/$', views.CreateView.as_view(), name='create'),
-        re_path(r'^(?P<image_id>[^/]+)/update/$',
-                views.UpdateView.as_view(), name='update'),
-        re_path(r'^(?P<image_id>[^/]+)/$', views.DetailView.as_view(),
-                name='detail'),
-    ]
+VIEWS_MOD = 'openstack_dashboard.dashboards.project.images.images.views'
+
+
+urlpatterns = patterns(VIEWS_MOD,
+    url(r'^create/$', views.CreateView.as_view(), name='create'),
+    url(r'^(?P<image_id>[^/]+)/update/$',
+        views.UpdateView.as_view(), name='update'),
+    url(r'^(?P<image_id>[^/]+)/$', views.DetailView.as_view(), name='detail'),
+)
