@@ -17,14 +17,14 @@
 
 import logging
 
+from django.conf import settings
 from django.core import urlresolvers
 from django import shortcuts
 from django import template
-from django.template.defaultfilters import timesince  # noqa
 from django.template.defaultfilters import title  # noqa
-from django.utils.http import urlencode  # noqa
+from django.utils.http import urlencode
 from django.utils.translation import string_concat  # noqa
-from django.utils.translation import ugettext_lazy as _  # noqa
+from django.utils.translation import ugettext_lazy as _
 
 from horizon import conf
 from horizon import exceptions
@@ -42,6 +42,7 @@ from openstack_dashboard.dashboards.project.instances import tabs
 LOG = logging.getLogger(__name__)
 
 ACTIVE_STATES = ("ACTIVE",)
+VOLUME_ATTACH_READY_STATES = ("ACTIVE", "SHUTOFF")
 SNAPSHOT_READY_STATES = ("ACTIVE", "SHUTOFF", "PAUSED", "SUSPENDED")
 
 POWER_STATES = {
@@ -73,13 +74,21 @@ def is_deleting(instance):
 class TerminateInstance(tables.BatchAction):
     name = "terminate"
     action_present = _("Terminate")
-    action_past = _("Scheduled termination of")
+    action_past = _("Scheduled termination of %(data_type)s")
     data_type_singular = _("Instance")
     data_type_plural = _("Instances")
     classes = ('btn-danger', 'btn-terminate')
+    policy_rules = (("compute", "compute:delete"),)
+
+    def get_policy_target(self, request, datum=None):
+        project_id = None
+        if datum:
+            project_id = getattr(datum, 'tenant_id', None)
+        return {"project_id": project_id}
 
     def allowed(self, request, instance=None):
-        return True
+        """Allow terminate action if instance not currently being deleted."""
+        return not is_deleting(instance)
 
     def action(self, request, obj_id):
         api.nova.server_delete(request, obj_id)
@@ -92,6 +101,13 @@ class RebootInstance(tables.BatchAction):
     data_type_singular = _("Instance")
     data_type_plural = _("Instances")
     classes = ('btn-danger', 'btn-reboot')
+    policy_rules = (("compute", "compute:reboot"),)
+
+    def get_policy_target(self, request, datum=None):
+        project_id = None
+        if datum:
+            project_id = getattr(datum, 'tenant_id', None)
+        return {"project_id": project_id}
 
     def allowed(self, request, instance=None):
         if instance is not None:
@@ -132,9 +148,19 @@ class TogglePause(tables.BatchAction):
         self.paused = instance.status == "PAUSED"
         if self.paused:
             self.current_present_action = UNPAUSE
+            policy = (("compute", "compute_extension:admin_actions:unpause"),)
         else:
             self.current_present_action = PAUSE
-        return ((instance.status in ACTIVE_STATES or self.paused)
+            policy = (("compute", "compute_extension:admin_actions:pause"),)
+
+        has_permission = True
+        policy_check = getattr(settings, "POLICY_CHECK_FUNCTION", None)
+        if policy_check:
+            has_permission = policy_check(policy, request,
+                target={'project_id': getattr(instance, 'tenant_id', None)})
+
+        return (has_permission
+                and (instance.status in ACTIVE_STATES or self.paused)
                 and not is_deleting(instance))
 
     def action(self, request, obj_id):
@@ -164,9 +190,19 @@ class ToggleSuspend(tables.BatchAction):
         self.suspended = instance.status == "SUSPENDED"
         if self.suspended:
             self.current_present_action = RESUME
+            policy = (("compute", "compute_extension:admin_actions:resume"),)
         else:
             self.current_present_action = SUSPEND
-        return ((instance.status in ACTIVE_STATES or self.suspended)
+            policy = (("compute", "compute_extension:admin_actions:suspend"),)
+
+        has_permission = True
+        policy_check = getattr(settings, "POLICY_CHECK_FUNCTION", None)
+        if policy_check:
+            has_permission = policy_check(policy, request,
+                target={'project_id': getattr(instance, 'tenant_id', None)})
+
+        return (has_permission
+                and (instance.status in ACTIVE_STATES or self.suspended)
                 and not is_deleting(instance))
 
     def action(self, request, obj_id):
@@ -183,6 +219,7 @@ class LaunchLink(tables.LinkAction):
     verbose_name = _("Launch Instance")
     url = "horizon:project:instances:launch"
     classes = ("btn-launch", "ajax-modal")
+    policy_rules = (("compute", "compute:create"),)
 
     def allowed(self, request, datum):
         try:
@@ -217,6 +254,13 @@ class EditInstance(tables.LinkAction):
     verbose_name = _("Edit Instance")
     url = "horizon:project:instances:update"
     classes = ("ajax-modal", "btn-edit")
+    policy_rules = (("compute", "compute:update"),)
+
+    def get_policy_target(self, request, datum=None):
+        project_id = None
+        if datum:
+            project_id = getattr(datum, 'tenant_id', None)
+        return {"project_id": project_id}
 
     def get_link_url(self, project):
         return self._get_link_url(project, 'instance_info')
@@ -246,8 +290,15 @@ class EditInstanceSecurityGroups(EditInstance):
 class CreateSnapshot(tables.LinkAction):
     name = "snapshot"
     verbose_name = _("Create Snapshot")
-    url = "horizon:project:images_and_snapshots:snapshots:create"
+    url = "horizon:project:images:snapshots:create"
     classes = ("ajax-modal", "btn-camera")
+    policy_rules = (("compute", "compute:snapshot"),)
+
+    def get_policy_target(self, request, datum=None):
+        project_id = None
+        if datum:
+            project_id = getattr(datum, 'tenant_id', None)
+        return {"project_id": project_id}
 
     def allowed(self, request, instance=None):
         return instance.status in SNAPSHOT_READY_STATES \
@@ -259,6 +310,13 @@ class ConsoleLink(tables.LinkAction):
     verbose_name = _("Console")
     url = "horizon:project:instances:detail"
     classes = ("btn-console",)
+    policy_rules = (("compute", "compute_extension:consoles"),)
+
+    def get_policy_target(self, request, datum=None):
+        project_id = None
+        if datum:
+            project_id = getattr(datum, 'tenant_id', None)
+        return {"project_id": project_id}
 
     def allowed(self, request, instance=None):
         return instance.status in ACTIVE_STATES and not is_deleting(instance)
@@ -275,6 +333,13 @@ class LogLink(tables.LinkAction):
     verbose_name = _("View Log")
     url = "horizon:project:instances:detail"
     classes = ("btn-log",)
+    policy_rules = (("compute", "compute_extension:console_output"),)
+
+    def get_policy_target(self, request, datum=None):
+        project_id = None
+        if datum:
+            project_id = getattr(datum, 'tenant_id', None)
+        return {"project_id": project_id}
 
     def allowed(self, request, instance=None):
         return instance.status in ACTIVE_STATES and not is_deleting(instance)
@@ -291,6 +356,13 @@ class ResizeLink(tables.LinkAction):
     verbose_name = _("Resize Instance")
     url = "horizon:project:instances:resize"
     classes = ("ajax-modal", "btn-resize")
+    policy_rules = (("compute", "compute:resize"),)
+
+    def get_policy_target(self, request, datum=None):
+        project_id = None
+        if datum:
+            project_id = getattr(datum, 'tenant_id', None)
+        return {"project_id": project_id}
 
     def get_link_url(self, project):
         return self._get_link_url(project, 'flavor_choice')
@@ -310,6 +382,13 @@ class ConfirmResize(tables.Action):
     name = "confirm"
     verbose_name = _("Confirm Resize/Migrate")
     classes = ("btn-confirm", "btn-action-required")
+    policy_rules = (("compute", "compute:confirm_resize"),)
+
+    def get_policy_target(self, request, datum=None):
+        project_id = None
+        if datum:
+            project_id = getattr(datum, 'tenant_id', None)
+        return {"project_id": project_id}
 
     def allowed(self, request, instance):
         return instance.status == 'VERIFY_RESIZE'
@@ -322,6 +401,13 @@ class RevertResize(tables.Action):
     name = "revert"
     verbose_name = _("Revert Resize/Migrate")
     classes = ("btn-revert", "btn-action-required")
+    policy_rules = (("compute", "compute:revert_resize"),)
+
+    def get_policy_target(self, request, datum=None):
+        project_id = None
+        if datum:
+            project_id = getattr(datum, 'tenant_id', None)
+        return {"project_id": project_id}
 
     def allowed(self, request, instance):
         return instance.status == 'VERIFY_RESIZE'
@@ -335,6 +421,13 @@ class RebuildInstance(tables.LinkAction):
     verbose_name = _("Rebuild Instance")
     classes = ("btn-rebuild", "ajax-modal")
     url = "horizon:project:instances:rebuild"
+    policy_rules = (("compute", "compute:rebuild"),)
+
+    def get_policy_target(self, request, datum=None):
+        project_id = None
+        if datum:
+            project_id = getattr(datum, 'tenant_id', None)
+        return {"project_id": project_id}
 
     def allowed(self, request, instance):
         return ((instance.status in ACTIVE_STATES
@@ -346,11 +439,41 @@ class RebuildInstance(tables.LinkAction):
         return urlresolvers.reverse(self.url, args=[instance_id])
 
 
+class DecryptInstancePassword(tables.LinkAction):
+    name = "decryptpassword"
+    verbose_name = _("Retrieve Password")
+    classes = ("btn-decrypt", "ajax-modal")
+    url = "horizon:project:instances:decryptpassword"
+
+    def allowed(self, request, instance):
+        enable = getattr(settings,
+                         'OPENSTACK_ENABLE_PASSWORD_RETRIEVE',
+                         False)
+        return (enable
+                and (instance.status in ACTIVE_STATES
+                     or instance.status == 'SHUTOFF')
+                and not is_deleting(instance)
+                and get_keyname(instance) is not None)
+
+    def get_link_url(self, datum):
+        instance_id = self.table.get_object_id(datum)
+        keypair_name = get_keyname(datum)
+        return urlresolvers.reverse(self.url, args=[instance_id,
+                                                    keypair_name])
+
+
 class AssociateIP(tables.LinkAction):
     name = "associate"
     verbose_name = _("Associate Floating IP")
     url = "horizon:project:access_and_security:floating_ips:associate"
     classes = ("ajax-modal", "btn-associate")
+    policy_rules = (("compute", "network:associate_floating_ip"),)
+
+    def get_policy_target(self, request, datum=None):
+        project_id = None
+        if datum:
+            project_id = getattr(datum, 'tenant_id', None)
+        return {"project_id": project_id}
 
     def allowed(self, request, instance):
         if api.network.floating_ip_simple_associate_supported(request):
@@ -370,6 +493,13 @@ class SimpleAssociateIP(tables.Action):
     name = "associate-simple"
     verbose_name = _("Associate Floating IP")
     classes = ("btn-associate-simple",)
+    policy_rules = (("compute", "network:associate_floating_ip"),)
+
+    def get_policy_target(self, request, datum=None):
+        project_id = None
+        if datum:
+            project_id = getattr(datum, 'tenant_id', None)
+        return {"project_id": project_id}
 
     def allowed(self, request, instance):
         if not api.network.floating_ip_simple_associate_supported(request):
@@ -398,6 +528,13 @@ class SimpleDisassociateIP(tables.Action):
     name = "disassociate"
     verbose_name = _("Disassociate Floating IP")
     classes = ("btn-danger", "btn-disassociate",)
+    policy_rules = (("compute", "network:disassociate_floating_ip"),)
+
+    def get_policy_target(self, request, datum=None):
+        project_id = None
+        if datum:
+            project_id = getattr(datum, 'tenant_id', None)
+        return {"project_id": project_id}
 
     def allowed(self, request, instance):
         if not conf.HORIZON_CONFIG["simple_ip_management"]:
@@ -408,18 +545,19 @@ class SimpleDisassociateIP(tables.Action):
         try:
             # target_id is port_id for Neutron and instance_id for Nova Network
             # (Neutron API wrapper returns a 'portid_fixedip' string)
-            target_id = api.network.floating_ip_target_get_by_instance(
-                request, instance_id).split('_')[0]
+            targets = api.network.floating_ip_target_list_by_instance(
+                request, instance_id)
+
+            target_ids = [t.split('_')[0] for t in targets]
 
             fips = [fip for fip in api.network.tenant_floating_ip_list(request)
-                    if fip.port_id == target_id]
+                    if fip.port_id in target_ids]
             # Removing multiple floating IPs at once doesn't work, so this pops
             # off the first one.
             if fips:
                 fip = fips.pop()
                 api.network.floating_ip_disassociate(request,
-                                                     fip.id, target_id)
-                api.network.tenant_floating_ip_release(request, fip.id)
+                                                     fip.id, fip.port_id)
                 messages.success(request,
                                  _("Successfully disassociated "
                                    "floating IP: %s") % fip.ip)
@@ -431,6 +569,29 @@ class SimpleDisassociateIP(tables.Action):
         return shortcuts.redirect("horizon:project:instances:index")
 
 
+def instance_fault_to_friendly_message(instance):
+    fault = getattr(instance, 'fault', {})
+    message = fault.get('message', _("Unknown"))
+    default_message = _("Please try again later [Error: %s].") % message
+    fault_map = {
+        'NoValidHost': _("There is not enough capacity for this "
+                         "flavor in the selected availability zone. "
+                         "Try again later or select a different availability "
+                         "zone.")
+    }
+    return fault_map.get(message, default_message)
+
+
+def get_instance_error(instance):
+    if instance.status.lower() != 'error':
+        return None
+    message = instance_fault_to_friendly_message(instance)
+    preamble = _('Failed to launch instance "%s"'
+                 ) % instance.name or instance.id
+    message = string_concat(preamble, ': ', message)
+    return message
+
+
 class UpdateRow(tables.Row):
     ajax = True
 
@@ -438,6 +599,9 @@ class UpdateRow(tables.Row):
         instance = api.nova.server_get(request, instance_id)
         instance.full_flavor = api.nova.flavor_get(request,
                                                    instance.flavor["id"])
+        error = get_instance_error(instance)
+        if error:
+            messages.error(request, error)
         return instance
 
 
@@ -447,6 +611,13 @@ class StartInstance(tables.BatchAction):
     action_past = _("Started")
     data_type_singular = _("Instance")
     data_type_plural = _("Instances")
+    policy_rules = (("compute", "compute:start"),)
+
+    def get_policy_target(self, request, datum=None):
+        project_id = None
+        if datum:
+            project_id = getattr(datum, 'tenant_id', None)
+        return {"project_id": project_id}
 
     def allowed(self, request, instance):
         return instance.status in ("SHUTDOWN", "SHUTOFF", "CRASHED")
@@ -462,6 +633,13 @@ class StopInstance(tables.BatchAction):
     data_type_singular = _("Instance")
     data_type_plural = _("Instances")
     classes = ('btn-danger',)
+    policy_rules = (("compute", "compute:stop"),)
+
+    def get_policy_target(self, request, datum=None):
+        project_id = None
+        if datum:
+            project_id = getattr(datum, 'tenant_id', None)
+        return {"project_id": project_id}
 
     def allowed(self, request, instance):
         return ((get_power_state(instance)
@@ -502,28 +680,28 @@ def get_power_state(instance):
 
 
 STATUS_DISPLAY_CHOICES = (
-    ("resize", "Resize/Migrate"),
-    ("verify_resize", "Confirm or Revert Resize/Migrate"),
-    ("revert_resize", "Revert Resize/Migrate"),
+    ("resize", _("Resize/Migrate")),
+    ("verify_resize", _("Confirm or Revert Resize/Migrate")),
+    ("revert_resize", _("Revert Resize/Migrate")),
 )
 
 
 TASK_DISPLAY_CHOICES = (
-    ("image_snapshot", "Snapshotting"),
-    ("resize_prep", "Preparing Resize or Migrate"),
-    ("resize_migrating", "Resizing or Migrating"),
-    ("resize_migrated", "Resized or Migrated"),
-    ("resize_finish", "Finishing Resize or Migrate"),
-    ("resize_confirming", "Confirming Resize or Nigrate"),
-    ("resize_reverting", "Reverting Resize or Migrate"),
-    ("unpausing", "Resuming"),
+    ("image_snapshot", _("Snapshotting")),
+    ("resize_prep", _("Preparing Resize or Migrate")),
+    ("resize_migrating", _("Resizing or Migrating")),
+    ("resize_migrated", _("Resized or Migrated")),
+    ("resize_finish", _("Finishing Resize or Migrate")),
+    ("resize_confirming", _("Confirming Resize or Migrate")),
+    ("resize_reverting", _("Reverting Resize or Migrate")),
+    ("unpausing", _("Resuming")),
 )
 
 
 class InstancesFilterAction(tables.FilterAction):
 
     def filter(self, table, instances, filter_string):
-        """ Naive case-insensitive search. """
+        """Naive case-insensitive search."""
         q = filter_string.lower()
         return [instance for instance in instances
                 if q in instance.name.lower()]
@@ -552,13 +730,15 @@ class InstancesTable(tables.DataTable):
     size = tables.Column(get_size,
                          verbose_name=_("Size"),
                          attrs={'data-type': 'size'})
-    keypair = tables.Column(get_keyname, verbose_name=_("Keypair"))
+    keypair = tables.Column(get_keyname, verbose_name=_("Key Pair"))
     status = tables.Column("status",
                            filters=(title, filters.replace_underscores),
                            verbose_name=_("Status"),
                            status=True,
                            status_choices=STATUS_CHOICES,
                            display_choices=STATUS_DISPLAY_CHOICES)
+    az = tables.Column("availability_zone",
+                       verbose_name=_("Availability Zone"))
     task = tables.Column("OS-EXT-STS:task_state",
                          verbose_name=_("Task"),
                          filters=(title, filters.replace_underscores),
@@ -570,7 +750,9 @@ class InstancesTable(tables.DataTable):
                           verbose_name=_("Power State"))
     created = tables.Column("created",
                             verbose_name=_("Uptime"),
-                            filters=(filters.parse_isotime, timesince))
+                            filters=(filters.parse_isotime,
+                                     filters.timesince_sortable),
+                            attrs={'data-type': 'timesince'})
 
     class Meta:
         name = "instances"
@@ -582,7 +764,7 @@ class InstancesTable(tables.DataTable):
         row_actions = (StartInstance, ConfirmResize, RevertResize,
                        CreateSnapshot, SimpleAssociateIP, AssociateIP,
                        SimpleDisassociateIP, EditInstance,
-                       EditInstanceSecurityGroups, ConsoleLink, LogLink,
-                       TogglePause, ToggleSuspend, ResizeLink,
-                       SoftRebootInstance, RebootInstance, StopInstance,
-                       RebuildInstance, TerminateInstance)
+                       DecryptInstancePassword, EditInstanceSecurityGroups,
+                       ConsoleLink, LogLink, TogglePause, ToggleSuspend,
+                       ResizeLink, SoftRebootInstance, RebootInstance,
+                       StopInstance, RebuildInstance, TerminateInstance)
