@@ -21,17 +21,18 @@
 """
 Views for managing instances.
 """
-from django.core.urlresolvers import reverse  # noqa
-from django.core.urlresolvers import reverse_lazy  # noqa
+from django.core.urlresolvers import reverse
+from django.core.urlresolvers import reverse_lazy
 from django import http
 from django import shortcuts
-from django.utils.datastructures import SortedDict  # noqa
-from django.utils.translation import ugettext_lazy as _  # noqa
+from django.utils.datastructures import SortedDict
+from django.utils.translation import ugettext_lazy as _
 
 from horizon import exceptions
 from horizon import forms
 from horizon import tables
 from horizon import tabs
+from horizon.utils import memoized
 from horizon import workflows
 
 from openstack_dashboard import api
@@ -66,8 +67,17 @@ class IndexView(tables.DataTableView):
             instances = []
             exceptions.handle(self.request,
                               _('Unable to retrieve instances.'))
-        # Gather our flavors and images and correlate our instances to them
+
         if instances:
+            try:
+                api.network.servers_update_addresses(self.request, instances)
+            except Exception:
+                exceptions.handle(
+                    self.request,
+                    message=_('Unable to retrieve IP addresses from Neutron.'),
+                    ignore=True)
+
+            # Gather our flavors and images and correlate our instances to them
             try:
                 flavors = api.nova.flavor_list(self.request)
             except Exception:
@@ -133,7 +143,7 @@ def console(request, instance_id):
     except Exception:
         data = _('Unable to get log for instance "%s".') % instance_id
         exceptions.handle(request, ignore=True)
-    response = http.HttpResponse(mimetype='text/plain')
+    response = http.HttpResponse(content_type='text/plain')
     response.write(data)
     response.flush()
     return response
@@ -163,6 +173,18 @@ def spice(request, instance_id):
         exceptions.handle(request, msg, redirect=redirect)
 
 
+def rdp(request, instance_id):
+    try:
+        console = api.nova.server_rdp_console(request, instance_id)
+        instance = api.nova.server_get(request, instance_id)
+        return shortcuts.redirect(console.url +
+                ("&title=%s(%s)" % (instance.name, instance_id)))
+    except Exception:
+        redirect = reverse("horizon:project:instances:index")
+        msg = _('Unable to get RDP console for instance "%s".') % instance_id
+        exceptions.handle(request, msg, redirect=redirect)
+
+
 class UpdateView(workflows.WorkflowView):
     workflow_class = project_workflows.UpdateInstance
     success_url = reverse_lazy("horizon:project:instances:index")
@@ -172,16 +194,15 @@ class UpdateView(workflows.WorkflowView):
         context["instance_id"] = self.kwargs['instance_id']
         return context
 
+    @memoized.memoized_method
     def get_object(self, *args, **kwargs):
-        if not hasattr(self, "_object"):
-            instance_id = self.kwargs['instance_id']
-            try:
-                self._object = api.nova.server_get(self.request, instance_id)
-            except Exception:
-                redirect = reverse("horizon:project:instances:index")
-                msg = _('Unable to retrieve instance details.')
-                exceptions.handle(self.request, msg, redirect=redirect)
-        return self._object
+        instance_id = self.kwargs['instance_id']
+        try:
+            return api.nova.server_get(self.request, instance_id)
+        except Exception:
+            redirect = reverse("horizon:project:instances:index")
+            msg = _('Unable to retrieve instance details.')
+            exceptions.handle(self.request, msg, redirect=redirect)
 
     def get_initial(self):
         initial = super(UpdateView, self).get_initial()
@@ -198,42 +219,69 @@ class RebuildView(forms.ModalFormView):
     def get_context_data(self, **kwargs):
         context = super(RebuildView, self).get_context_data(**kwargs)
         context['instance_id'] = self.kwargs['instance_id']
+        context['can_set_server_password'] = api.nova.can_set_server_password()
         return context
 
     def get_initial(self):
         return {'instance_id': self.kwargs['instance_id']}
 
 
+class DecryptPasswordView(forms.ModalFormView):
+    form_class = project_forms.DecryptPasswordInstanceForm
+    template_name = 'project/instances/decryptpassword.html'
+    success_url = reverse_lazy('horizon:project:instances:index')
+
+    def get_context_data(self, **kwargs):
+        context = super(DecryptPasswordView, self).get_context_data(**kwargs)
+        context['instance_id'] = self.kwargs['instance_id']
+        context['keypair_name'] = self.kwargs['keypair_name']
+        return context
+
+    def get_initial(self):
+        return {'instance_id': self.kwargs['instance_id'],
+                'keypair_name': self.kwargs['keypair_name']}
+
+
 class DetailView(tabs.TabView):
     tab_group_class = project_tabs.InstanceDetailTabs
     template_name = 'project/instances/detail.html'
+    redirect_url = 'horizon:project:instances:index'
 
     def get_context_data(self, **kwargs):
         context = super(DetailView, self).get_context_data(**kwargs)
         context["instance"] = self.get_data()
         return context
 
+    @memoized.memoized_method
     def get_data(self):
-        if not hasattr(self, "_instance"):
-            try:
-                instance_id = self.kwargs['instance_id']
-                instance = api.nova.server_get(self.request, instance_id)
-                instance.volumes = api.nova.instance_volumes_list(self.request,
-                                                                  instance_id)
-                # Sort by device name
-                instance.volumes.sort(key=lambda vol: vol.device)
-                instance.full_flavor = api.nova.flavor_get(
-                    self.request, instance.flavor["id"])
-                instance.security_groups = api.network.server_security_groups(
-                    self.request, instance_id)
-            except Exception:
-                redirect = reverse('horizon:project:instances:index')
-                exceptions.handle(self.request,
-                                  _('Unable to retrieve details for '
-                                    'instance "%s".') % instance_id,
-                                    redirect=redirect)
-            self._instance = instance
-        return self._instance
+        try:
+            instance_id = self.kwargs['instance_id']
+            instance = api.nova.server_get(self.request, instance_id)
+            instance.volumes = api.nova.instance_volumes_list(self.request,
+                                                              instance_id)
+            # Sort by device name
+            instance.volumes.sort(key=lambda vol: vol.device)
+            instance.full_flavor = api.nova.flavor_get(
+                self.request, instance.flavor["id"])
+            instance.security_groups = api.network.server_security_groups(
+                self.request, instance_id)
+        except Exception:
+            redirect = reverse(self.redirect_url)
+            exceptions.handle(self.request,
+                              _('Unable to retrieve details for '
+                                'instance "%s".') % instance_id,
+                                redirect=redirect)
+            # Not all exception types handled above will result in a redirect.
+            # Need to raise here just in case.
+            raise exceptions.Http302(redirect)
+        try:
+            api.network.servers_update_addresses(self.request, [instance])
+        except Exception:
+            exceptions.handle(
+                self.request,
+                _('Unable to retrieve IP addresses from Neutron for instance '
+                  '"%s".') % instance_id, ignore=True)
+        return instance
 
     def get_tabs(self, request, *args, **kwargs):
         instance = self.get_data()
@@ -249,35 +297,33 @@ class ResizeView(workflows.WorkflowView):
         context["instance_id"] = self.kwargs['instance_id']
         return context
 
+    @memoized.memoized_method
     def get_object(self, *args, **kwargs):
-        if not hasattr(self, "_object"):
-            instance_id = self.kwargs['instance_id']
-            try:
-                self._object = api.nova.server_get(self.request, instance_id)
-                flavor_id = self._object.flavor['id']
-                flavors = self.get_flavors()
-                if flavor_id in flavors:
-                    self._object.flavor_name = flavors[flavor_id].name
-                else:
-                    flavor = api.nova.flavor_get(self.request, flavor_id)
-                    self._object.flavor_name = flavor.name
-            except Exception:
-                redirect = reverse("horizon:project:instances:index")
-                msg = _('Unable to retrieve instance details.')
-                exceptions.handle(self.request, msg, redirect=redirect)
-        return self._object
+        instance_id = self.kwargs['instance_id']
+        try:
+            instance = api.nova.server_get(self.request, instance_id)
+            flavor_id = instance.flavor['id']
+            flavors = self.get_flavors()
+            if flavor_id in flavors:
+                instance.flavor_name = flavors[flavor_id].name
+            else:
+                flavor = api.nova.flavor_get(self.request, flavor_id)
+                instance.flavor_name = flavor.name
+        except Exception:
+            redirect = reverse("horizon:project:instances:index")
+            msg = _('Unable to retrieve instance details.')
+            exceptions.handle(self.request, msg, redirect=redirect)
+        return instance
 
+    @memoized.memoized_method
     def get_flavors(self, *args, **kwargs):
-        if not hasattr(self, "_flavors"):
-            try:
-                flavors = api.nova.flavor_list(self.request)
-                self._flavors = SortedDict([(str(flavor.id), flavor)
-                                        for flavor in flavors])
-            except Exception:
-                redirect = reverse("horizon:project:instances:index")
-                exceptions.handle(self.request,
-                    _('Unable to retrieve flavors.'), redirect=redirect)
-        return self._flavors
+        try:
+            flavors = api.nova.flavor_list(self.request)
+            return SortedDict((str(flavor.id), flavor) for flavor in flavors)
+        except Exception:
+            redirect = reverse("horizon:project:instances:index")
+            exceptions.handle(self.request,
+                _('Unable to retrieve flavors.'), redirect=redirect)
 
     def get_initial(self):
         initial = super(ResizeView, self).get_initial()
