@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2013, Mirantis Inc
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -11,6 +13,8 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
+#
+# @author: Tatiana Mazur
 
 import logging
 
@@ -30,14 +34,12 @@ LOG = logging.getLogger(__name__)
 class UpdatePool(forms.SelfHandlingForm):
     name = forms.CharField(max_length=80, label=_("Name"))
     pool_id = forms.CharField(label=_("ID"),
-                              widget=forms.TextInput(
-                                  attrs={'readonly': 'readonly'}))
+                                 widget=forms.TextInput(
+                                     attrs={'readonly': 'readonly'}))
     description = forms.CharField(required=False,
                                   max_length=80, label=_("Description"))
     lb_method = forms.ChoiceField(label=_("Load Balancing Method"))
-    admin_state_up = forms.ChoiceField(choices=[(True, _('UP')),
-                                                (False, _('DOWN'))],
-                                       label=_("Admin State"))
+    admin_state_up = forms.BooleanField(label=_("Admin State"), required=False)
 
     failure_url = 'horizon:project:loadbalancers:index'
 
@@ -50,7 +52,6 @@ class UpdatePool(forms.SelfHandlingForm):
         self.fields['lb_method'].choices = lb_method_choices
 
     def handle(self, request, context):
-        context['admin_state_up'] = (context['admin_state_up'] == 'True')
         try:
             data = {'pool': {'name': context['name'],
                              'description': context['description'],
@@ -72,8 +73,8 @@ class UpdatePool(forms.SelfHandlingForm):
 class UpdateVip(forms.SelfHandlingForm):
     name = forms.CharField(max_length=80, label=_("Name"))
     vip_id = forms.CharField(label=_("ID"),
-                             widget=forms.TextInput(
-                                 attrs={'readonly': 'readonly'}))
+                                 widget=forms.TextInput(
+                                     attrs={'readonly': 'readonly'}))
     description = forms.CharField(required=False,
                                   max_length=80, label=_("Description"))
     pool_id = forms.ChoiceField(label=_("Pool"))
@@ -90,9 +91,7 @@ class UpdateVip(forms.SelfHandlingForm):
         min_value=-1, label=_("Connection Limit"),
         help_text=_("Maximum number of connections allowed "
                     "for the VIP or '-1' if the limit is not set"))
-    admin_state_up = forms.ChoiceField(choices=[(True, _('UP')),
-                                                (False, _('DOWN'))],
-                                       label=_("Admin State"))
+    admin_state_up = forms.BooleanField(label=_("Admin State"), required=False)
 
     failure_url = 'horizon:project:loadbalancers:index'
 
@@ -132,7 +131,6 @@ class UpdateVip(forms.SelfHandlingForm):
         return cleaned_data
 
     def handle(self, request, context):
-        context['admin_state_up'] = (context['admin_state_up'] == 'True')
         if context['session_persistence']:
             stype = context['session_persistence']
             if stype == 'APP_COOKIE':
@@ -167,15 +165,13 @@ class UpdateVip(forms.SelfHandlingForm):
 
 class UpdateMember(forms.SelfHandlingForm):
     member_id = forms.CharField(label=_("ID"),
-                                widget=forms.TextInput(
-                                    attrs={'readonly': 'readonly'}))
+                                 widget=forms.TextInput(
+                                     attrs={'readonly': 'readonly'}))
     pool_id = forms.ChoiceField(label=_("Pool"))
     weight = forms.IntegerField(max_value=256, min_value=0, label=_("Weight"),
                                 help_text=_("Relative part of requests this "
                                 "pool member serves compared to others"))
-    admin_state_up = forms.ChoiceField(choices=[(True, _('UP')),
-                                                (False, _('DOWN'))],
-                                       label=_("Admin State"))
+    admin_state_up = forms.BooleanField(label=_("Admin State"), required=False)
 
     failure_url = 'horizon:project:loadbalancers:index'
 
@@ -197,7 +193,6 @@ class UpdateMember(forms.SelfHandlingForm):
         self.fields['pool_id'].choices = pool_id_choices
 
     def handle(self, request, context):
-        context['admin_state_up'] = (context['admin_state_up'] == 'True')
         try:
             data = {'member': {'pool_id': context['pool_id'],
                                'weight': context['weight'],
@@ -224,46 +219,33 @@ class UpdateMonitor(forms.SelfHandlingForm):
         min_value=1,
         label=_("Delay"),
         help_text=_("The minimum time in seconds between regular checks "
-                    "of a member. It must be greater than or equal to "
-                    "timeout"))
+                    "of a member"))
     timeout = forms.IntegerField(
         min_value=1,
         label=_("Timeout"),
         help_text=_("The maximum time in seconds for a monitor to wait "
-                    "for a reply. It must be less than or equal to delay"))
+                    "for a reply"))
     max_retries = forms.IntegerField(
         max_value=10, min_value=1,
         label=_("Max Retries (1~10)"),
         help_text=_("Number of permissible failures before changing "
                     "the status of member to inactive"))
-    admin_state_up = forms.ChoiceField(choices=[(True, _('UP')),
-                                                (False, _('DOWN'))],
-                                       label=_("Admin State"))
+    admin_state_up = forms.BooleanField(label=_("Admin State"), required=False)
 
     failure_url = 'horizon:project:loadbalancers:index'
 
     def __init__(self, request, *args, **kwargs):
         super(UpdateMonitor, self).__init__(request, *args, **kwargs)
 
-    def clean(self):
-        cleaned_data = super(UpdateMonitor, self).clean()
-        delay = cleaned_data.get('delay')
-        timeout = cleaned_data.get('timeout')
-        if not delay >= timeout:
-            msg = _('Delay must be greater than or equal to timeout')
-            self._errors['delay'] = self.error_class([msg])
-        return cleaned_data
-
     def handle(self, request, context):
-        context['admin_state_up'] = (context['admin_state_up'] == 'True')
         try:
             data = {'health_monitor': {
                     'delay': context['delay'],
                     'timeout': context['timeout'],
                     'max_retries': context['max_retries'],
                     'admin_state_up': context['admin_state_up']}}
-            monitor = api.lbaas.pool_health_monitor_update(
-                request, context['monitor_id'], **data)
+            monitor = api.lbaas.pool_health_monitor_update(request,
+                                             context['monitor_id'], **data)
             msg = _('Health monitor %s was successfully updated.')\
                 % context['monitor_id']
             LOG.debug(msg)
