@@ -1,15 +1,26 @@
 # vim: tabstop=4 shiftwidth=4 softtabstop=4
 
+# Licensed under the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License. You may obtain
+# a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+# License for the specific language governing permissions and limitations
+# under the License.
+
 from mox import IsA  # noqa
 
-from django.core.urlresolvers import reverse  # noqa
-from django.core.urlresolvers import reverse_lazy  # noqa
+from django.core.urlresolvers import reverse
+from django.core.urlresolvers import reverse_lazy
 from django import http
 
 from horizon.workflows import views
 
 from openstack_dashboard import api
-from openstack_dashboard.api import lbaas
 from openstack_dashboard.test import helpers as test
 
 from openstack_dashboard.dashboards.project.loadbalancers import workflows
@@ -46,50 +57,33 @@ class LoadBalancerTests(test.TestCase):
 
     def set_up_expect(self):
         # retrieve pools
-        vip1 = self.vips.first()
-
-        vip2 = self.vips.list()[1]
-
-        api.lbaas.pools_get(
+        api.lbaas.pool_list(
             IsA(http.HttpRequest), tenant_id=self.tenant.id) \
             .AndReturn(self.pools.list())
 
-        api.lbaas.vip_get(IsA(http.HttpRequest), vip1.id).AndReturn(vip1)
-        api.lbaas.vip_get(IsA(http.HttpRequest), vip2.id).AndReturn(vip2)
-
         # retrieves members
-        api.lbaas.members_get(
+        api.lbaas.member_list(
             IsA(http.HttpRequest), tenant_id=self.tenant.id) \
             .AndReturn(self.members.list())
 
-        pool1 = self.pools.first()
-        pool2 = self.pools.list()[1]
-
-        api.lbaas.pool_get(IsA(http.HttpRequest),
-                           self.members.list()[0].pool_id).AndReturn(pool1)
-        api.lbaas.pool_get(IsA(http.HttpRequest),
-                           self.members.list()[1].pool_id).AndReturn(pool2)
-
         # retrieves monitors
-        api.lbaas.pool_health_monitors_get(
+        api.lbaas.pool_health_monitor_list(
             IsA(http.HttpRequest), tenant_id=self.tenant.id).MultipleTimes() \
                 .AndReturn(self.monitors.list())
 
     def set_up_expect_with_exception(self):
-        api.lbaas.pools_get(
+        api.lbaas.pool_list(
             IsA(http.HttpRequest), tenant_id=self.tenant.id) \
             .AndRaise(self.exceptions.neutron)
-        api.lbaas.members_get(
+        api.lbaas.member_list(
             IsA(http.HttpRequest), tenant_id=self.tenant.id) \
             .AndRaise(self.exceptions.neutron)
-        api.lbaas.pool_health_monitors_get(
+        api.lbaas.pool_health_monitor_list(
             IsA(http.HttpRequest), tenant_id=self.tenant.id) \
             .AndRaise(self.exceptions.neutron)
 
-    @test.create_stubs({api.lbaas: ('pools_get', 'vip_get',
-                                    'members_get', 'pool_get',
-                                    'pool_health_monitors_get'),
-                        api.neutron: ('subnet_get',)})
+    @test.create_stubs({api.lbaas: ('pool_list', 'member_list',
+                                    'pool_health_monitor_list')})
     def test_index_pools(self):
         self.set_up_expect()
 
@@ -103,10 +97,8 @@ class LoadBalancerTests(test.TestCase):
         self.assertEqual(len(res.context['table'].data),
                          len(self.pools.list()))
 
-    @test.create_stubs({api.lbaas: ('pools_get', 'vip_get',
-                                    'members_get', 'pool_get',
-                                    'pool_health_monitors_get'),
-                        api.neutron: ('subnet_get',)})
+    @test.create_stubs({api.lbaas: ('pool_list', 'member_list',
+                                    'pool_health_monitor_list')})
     def test_index_members(self):
         self.set_up_expect()
 
@@ -120,10 +112,8 @@ class LoadBalancerTests(test.TestCase):
         self.assertEqual(len(res.context['memberstable_table'].data),
                               len(self.members.list()))
 
-    @test.create_stubs({api.lbaas: ('pools_get', 'vip_get',
-                                    'pool_health_monitors_get',
-                                    'members_get', 'pool_get'),
-                        api.neutron: ('subnet_get',)})
+    @test.create_stubs({api.lbaas: ('pool_list', 'member_list',
+                                    'pool_health_monitor_list')})
     def test_index_monitors(self):
         self.set_up_expect()
 
@@ -137,8 +127,8 @@ class LoadBalancerTests(test.TestCase):
         self.assertEqual(len(res.context['monitorstable_table'].data),
                               len(self.monitors.list()))
 
-    @test.create_stubs({api.lbaas: ('pools_get', 'members_get',
-                                    'pool_health_monitors_get')})
+    @test.create_stubs({api.lbaas: ('pool_list', 'member_list',
+                                    'pool_health_monitor_list')})
     def test_index_exception_pools(self):
         self.set_up_expect_with_exception()
 
@@ -153,8 +143,8 @@ class LoadBalancerTests(test.TestCase):
                                 'horizon/common/_detail_table.html')
         self.assertEqual(len(res.context['table'].data), 0)
 
-    @test.create_stubs({api.lbaas: ('pools_get', 'members_get',
-                                    'pool_health_monitors_get')})
+    @test.create_stubs({api.lbaas: ('pool_list', 'member_list',
+                                    'pool_health_monitor_list')})
     def test_index_exception_members(self):
         self.set_up_expect_with_exception()
 
@@ -169,8 +159,8 @@ class LoadBalancerTests(test.TestCase):
                                 'horizon/common/_detail_table.html')
         self.assertEqual(len(res.context['memberstable_table'].data), 0)
 
-    @test.create_stubs({api.lbaas: ('pools_get', 'members_get',
-                                    'pool_health_monitors_get')})
+    @test.create_stubs({api.lbaas: ('pool_list', 'member_list',
+                                    'pool_health_monitor_list')})
     def test_index_exception_monitors(self):
         self.set_up_expect_with_exception()
 
@@ -202,18 +192,6 @@ class LoadBalancerTests(test.TestCase):
         api.neutron.provider_list(IsA(http.HttpRequest)) \
             .AndReturn(self.providers.list())
 
-        api.lbaas.pool_create(
-            IsA(http.HttpRequest),
-            name=pool.name,
-            description=pool.description,
-            subnet_id=pool.subnet_id,
-            protocol=pool.protocol,
-            lb_method=pool.lb_method,
-            admin_state_up=pool.admin_state_up,
-            provider=pool.provider).AndReturn(pool)
-
-        self.mox.ReplayAll()
-
         form_data = {'name': pool.name,
                      'description': pool.description,
                      'subnet_id': pool.subnet_id,
@@ -221,6 +199,11 @@ class LoadBalancerTests(test.TestCase):
                      'lb_method': pool.lb_method,
                      'admin_state_up': pool.admin_state_up}
 
+        api.lbaas.pool_create(
+            IsA(http.HttpRequest), **form_data).AndReturn(pool)
+
+        self.mox.ReplayAll()
+
         res = self.client.post(reverse(self.ADDPOOL_PATH), form_data)
 
         self.assertNoFormErrors(res)
@@ -230,13 +213,13 @@ class LoadBalancerTests(test.TestCase):
                                       'provider_list',
                                       'is_extension_supported')})
     def test_add_pool_get(self):
-        self._test_add_pool_get(with_service_type=True)
+        self._test_add_pool_get()
 
     @test.create_stubs({api.neutron: ('network_list_for_tenant',
                                       'provider_list',
                                       'is_extension_supported')})
     def test_add_pool_get_provider_list_exception(self):
-        self._test_add_pool_get(with_service_type=True)
+        self._test_add_pool_get(with_provider_exception=True)
 
     @test.create_stubs({api.neutron: ('network_list_for_tenant',
                                       'is_extension_supported')})
@@ -275,10 +258,10 @@ class LoadBalancerTests(test.TestCase):
         if not with_service_type:
             self.assertNotContains(res, default_provider)
             self.assertContains(res, ('Provider for Load Balancer '
-                                      'is not supported.'))
+                                      'is not supported'))
         elif with_provider_exception:
             self.assertNotContains(res, default_provider)
-            self.assertContains(res, 'No provider is available.')
+            self.assertContains(res, 'No provider is available')
         else:
             self.assertContains(res, default_provider)
 
@@ -323,19 +306,20 @@ class LoadBalancerTests(test.TestCase):
 
         self.mox.ReplayAll()
 
-        form_data = {'name': vip.name,
-                     'description': vip.description,
-                     'pool_id': vip.pool_id,
-                     'address': vip.address,
-                     'floatip_address': vip.floatip_address,
-                     'other_address': vip.other_address,
-                     'subnet_id': vip.subnet_id,
-                     'subnet': vip.subnet,
-                     'protocol_port': vip.protocol_port,
-                     'protocol': vip.protocol,
-                     'session_persistence': vip.session_persistence['type'],
-                     'cookie_name': vip.session_persistence['cookie_name'],
-                     'admin_state_up': vip.admin_state_up}
+        form_data = {
+            'name': vip.name,
+            'description': vip.description,
+            'pool_id': vip.pool_id,
+            'address': vip.address,
+            'floatip_address': vip.floatip_address,
+            'other_address': vip.other_address,
+            'subnet_id': vip.subnet_id,
+            'subnet': vip.subnet,
+            'protocol_port': vip.protocol_port,
+            'protocol': vip.protocol,
+            'session_persistence': vip.session_persistence['type'].lower(),
+            'cookie_name': vip.session_persistence['cookie_name'],
+            'admin_state_up': vip.admin_state_up}
         if with_conn_limit:
             form_data['connection_limit'] = vip.connection_limit
 
@@ -359,17 +343,18 @@ class LoadBalancerTests(test.TestCase):
 
         self.mox.ReplayAll()
 
-        form_data = {'name': vip.name,
-                     'description': vip.description,
-                     'pool_id': vip.pool_id,
-                     'address': vip.address,
-                     'subnet_id': vip.subnet_id,
-                     'protocol_port': 65536,
-                     'protocol': vip.protocol,
-                     'session_persistence': vip.session_persistence['type'],
-                     'cookie_name': vip.session_persistence['cookie_name'],
-                     'connection_limit': -2,
-                     'admin_state_up': vip.admin_state_up}
+        form_data = {
+            'name': vip.name,
+            'description': vip.description,
+            'pool_id': vip.pool_id,
+            'address': vip.address,
+            'subnet_id': vip.subnet_id,
+            'protocol_port': 65536,
+            'protocol': vip.protocol,
+            'session_persistence': vip.session_persistence['type'].lower(),
+            'cookie_name': vip.session_persistence['cookie_name'],
+            'connection_limit': -2,
+            'admin_state_up': vip.admin_state_up}
 
         res = self.client.post(
             reverse(self.ADDVIP_PATH, args=(pool.id,)), form_data)
@@ -401,20 +386,6 @@ class LoadBalancerTests(test.TestCase):
     def test_add_monitor_post(self):
         monitor = self.monitors.first()
 
-        api.lbaas.pool_health_monitor_create(
-            IsA(http.HttpRequest),
-            type=monitor.type,
-            delay=monitor.delay,
-            timeout=monitor.timeout,
-            max_retries=monitor.max_retries,
-            http_method=monitor.http_method,
-            url_path=monitor.url_path,
-            expected_codes=monitor.expected_codes,
-            admin_state_up=monitor.admin_state_up).AndReturn(
-                lbaas.PoolMonitor(monitor))
-
-        self.mox.ReplayAll()
-
         form_data = {'type': monitor.type,
                      'delay': monitor.delay,
                      'timeout': monitor.timeout,
@@ -424,6 +395,11 @@ class LoadBalancerTests(test.TestCase):
                      'expected_codes': monitor.expected_codes,
                      'admin_state_up': monitor.admin_state_up}
 
+        api.lbaas.pool_health_monitor_create(
+            IsA(http.HttpRequest), **form_data).AndReturn(monitor)
+
+        self.mox.ReplayAll()
+
         res = self.client.post(reverse(self.ADDMONITOR_PATH), form_data)
 
         self.assertNoFormErrors(res)
@@ -477,7 +453,7 @@ class LoadBalancerTests(test.TestCase):
     def test_add_member_post_without_weight(self):
         self._test_add_member_post(with_weight=False)
 
-    @test.create_stubs({api.lbaas: ('pools_get', 'member_create'),
+    @test.create_stubs({api.lbaas: ('pool_list', 'member_create'),
                         api.neutron: ('port_list',),
                         api.nova: ('server_list',)})
     def _test_add_member_post(self, with_weight=True):
@@ -493,7 +469,7 @@ class LoadBalancerTests(test.TestCase):
         port1 = self.AttributeDict(
             {'fixed_ips': [{'ip_address': member.address}]})
 
-        api.lbaas.pools_get(IsA(http.HttpRequest), tenant_id=self.tenant.id) \
+        api.lbaas.pool_list(IsA(http.HttpRequest), tenant_id=self.tenant.id) \
             .AndReturn(self.pools.list())
 
         api.nova.server_list(IsA(http.HttpRequest)).AndReturn(
@@ -511,7 +487,7 @@ class LoadBalancerTests(test.TestCase):
         if with_weight:
             params['weight'] = member.weight
         api.lbaas.member_create(IsA(http.HttpRequest),
-                                **params).AndReturn(lbaas.Member(member))
+                                **params).AndReturn(member)
 
         self.mox.ReplayAll()
 
@@ -528,7 +504,7 @@ class LoadBalancerTests(test.TestCase):
         self.assertNoFormErrors(res)
         self.assertRedirectsNoFollow(res, str(self.INDEX_URL))
 
-    @test.create_stubs({api.lbaas: ('pools_get',),
+    @test.create_stubs({api.lbaas: ('pool_list',),
                         api.nova: ('server_list',)})
     def test_add_member_post_with_error(self):
         member = self.members.first()
@@ -540,7 +516,7 @@ class LoadBalancerTests(test.TestCase):
                                       '12381d38-c3eb-4fee-9763-12de3338043e',
                                       'name': 'vm2'})
 
-        api.lbaas.pools_get(IsA(http.HttpRequest), tenant_id=self.tenant.id) \
+        api.lbaas.pool_list(IsA(http.HttpRequest), tenant_id=self.tenant.id) \
             .AndReturn(self.pools.list())
 
         api.nova.server_list(IsA(http.HttpRequest)).AndReturn([[server1,
@@ -561,7 +537,7 @@ class LoadBalancerTests(test.TestCase):
 
         self.assertFormErrors(res, 2)
 
-    @test.create_stubs({api.lbaas: ('pools_get',),
+    @test.create_stubs({api.lbaas: ('pool_list',),
                         api.nova: ('server_list',)})
     def test_add_member_get(self):
         server1 = self.AttributeDict({'id':
@@ -571,7 +547,7 @@ class LoadBalancerTests(test.TestCase):
                                       '12381d38-c3eb-4fee-9763-12de3338043e',
                                       'name': 'vm2'})
 
-        api.lbaas.pools_get(IsA(http.HttpRequest), tenant_id=self.tenant.id) \
+        api.lbaas.pool_list(IsA(http.HttpRequest), tenant_id=self.tenant.id) \
             .AndReturn(self.pools.list())
         api.nova.server_list(
             IsA(http.HttpRequest)).AndReturn([[server1, server2], False])
@@ -624,12 +600,12 @@ class LoadBalancerTests(test.TestCase):
 
         self.assertTemplateUsed(res, 'project/loadbalancers/updatepool.html')
 
-    @test.create_stubs({api.lbaas: ('pools_get', 'vip_get',
+    @test.create_stubs({api.lbaas: ('pool_list', 'vip_get',
                                     'vip_update')})
     def test_update_vip_post(self):
         vip = self.vips.first()
 
-        api.lbaas.pools_get(IsA(http.HttpRequest), tenant_id=self.tenant.id) \
+        api.lbaas.pool_list(IsA(http.HttpRequest), tenant_id=self.tenant.id) \
             .AndReturn(self.pools.list())
         api.lbaas.vip_get(IsA(http.HttpRequest), vip.id).AndReturn(vip)
 
@@ -654,11 +630,11 @@ class LoadBalancerTests(test.TestCase):
         self.assertNoFormErrors(res)
         self.assertRedirectsNoFollow(res, str(self.INDEX_URL))
 
-    @test.create_stubs({api.lbaas: ('vip_get', 'pools_get')})
+    @test.create_stubs({api.lbaas: ('vip_get', 'pool_list')})
     def test_update_vip_get(self):
         vip = self.vips.first()
 
-        api.lbaas.pools_get(IsA(http.HttpRequest), tenant_id=self.tenant.id) \
+        api.lbaas.pool_list(IsA(http.HttpRequest), tenant_id=self.tenant.id) \
             .AndReturn(self.pools.list())
         api.lbaas.vip_get(IsA(http.HttpRequest), vip.id).AndReturn(vip)
 
@@ -668,12 +644,12 @@ class LoadBalancerTests(test.TestCase):
 
         self.assertTemplateUsed(res, 'project/loadbalancers/updatevip.html')
 
-    @test.create_stubs({api.lbaas: ('pools_get', 'member_get',
+    @test.create_stubs({api.lbaas: ('pool_list', 'member_get',
                                     'member_update')})
     def test_update_member_post(self):
         member = self.members.first()
 
-        api.lbaas.pools_get(IsA(http.HttpRequest), tenant_id=self.tenant.id) \
+        api.lbaas.pool_list(IsA(http.HttpRequest), tenant_id=self.tenant.id) \
             .AndReturn(self.pools.list())
         api.lbaas.member_get(IsA(http.HttpRequest), member.id)\
             .AndReturn(member)
@@ -696,11 +672,11 @@ class LoadBalancerTests(test.TestCase):
         self.assertNoFormErrors(res)
         self.assertRedirectsNoFollow(res, str(self.INDEX_URL))
 
-    @test.create_stubs({api.lbaas: ('member_get', 'pools_get')})
+    @test.create_stubs({api.lbaas: ('member_get', 'pool_list')})
     def test_update_member_get(self):
         member = self.members.first()
 
-        api.lbaas.pools_get(IsA(http.HttpRequest), tenant_id=self.tenant.id) \
+        api.lbaas.pool_list(IsA(http.HttpRequest), tenant_id=self.tenant.id) \
             .AndReturn(self.pools.list())
         api.lbaas.member_get(IsA(http.HttpRequest), member.id)\
             .AndReturn(member)
@@ -754,7 +730,7 @@ class LoadBalancerTests(test.TestCase):
         self.assertTemplateUsed(
             res, 'project/loadbalancers/updatemonitor.html')
 
-    @test.create_stubs({api.lbaas: ('pool_get', 'pool_health_monitors_get',
+    @test.create_stubs({api.lbaas: ('pool_get', 'pool_health_monitor_list',
                                     'pool_monitor_association_create')})
     def test_add_pool_monitor_association_post(self):
         pool = self.pools.first()
@@ -762,37 +738,33 @@ class LoadBalancerTests(test.TestCase):
         monitor = self.monitors.list()[1]
 
         api.lbaas.pool_get(IsA(http.HttpRequest), pool.id).AndReturn(pool)
-        api.lbaas.pool_health_monitors_get(
+        api.lbaas.pool_health_monitor_list(
             IsA(http.HttpRequest),
             tenant_id=self.tenant.id).AndReturn(monitors)
 
-        api.lbaas.pool_monitor_association_create(
-            IsA(http.HttpRequest),
-            monitor_id=monitor.id,
-            pool_id=pool.id,
-            pool_monitors=pool.health_monitors,
-            pool_name=pool.name).AndReturn(None)
-
-        self.mox.ReplayAll()
-
         form_data = {'monitor_id': monitor.id,
                      'pool_id': pool.id,
                      'pool_monitors': pool.health_monitors,
                      'pool_name': pool.name}
 
+        api.lbaas.pool_monitor_association_create(
+            IsA(http.HttpRequest), **form_data).AndReturn(None)
+
+        self.mox.ReplayAll()
+
         res = self.client.post(
             reverse(self.ADDASSOC_PATH, args=(pool.id,)), form_data)
 
         self.assertNoFormErrors(res)
         self.assertRedirectsNoFollow(res, str(self.INDEX_URL))
 
-    @test.create_stubs({api.lbaas: ('pool_get', 'pool_health_monitors_get')})
+    @test.create_stubs({api.lbaas: ('pool_get', 'pool_health_monitor_list')})
     def test_add_pool_monitor_association_get(self):
         pool = self.pools.first()
         monitors = self.monitors.list()
 
         api.lbaas.pool_get(IsA(http.HttpRequest), pool.id).AndReturn(pool)
-        api.lbaas.pool_health_monitors_get(
+        api.lbaas.pool_health_monitor_list(
             IsA(http.HttpRequest),
             tenant_id=self.tenant.id).AndReturn(monitors)
 
@@ -808,7 +780,7 @@ class LoadBalancerTests(test.TestCase):
         self.assertQuerysetEqual(workflow.steps, expected_objs)
 
     @test.create_stubs({api.lbaas: ('pool_get',
-                                    'pool_health_monitors_get',
+                                    'pool_health_monitor_list',
                                     'pool_monitor_association_delete')})
     def test_delete_pool_monitor_association_post(self):
         pool = self.pools.first()
@@ -816,23 +788,19 @@ class LoadBalancerTests(test.TestCase):
         monitor = monitors[0]
 
         api.lbaas.pool_get(IsA(http.HttpRequest), pool.id).AndReturn(pool)
-        api.lbaas.pool_health_monitors_get(
+        api.lbaas.pool_health_monitor_list(
             IsA(http.HttpRequest)).AndReturn(monitors)
 
-        api.lbaas.pool_monitor_association_delete(
-            IsA(http.HttpRequest),
-            monitor_id=monitor.id,
-            pool_id=pool.id,
-            pool_monitors=pool.health_monitors,
-            pool_name=pool.name).AndReturn(None)
-
-        self.mox.ReplayAll()
-
         form_data = {'monitor_id': monitor.id,
                      'pool_id': pool.id,
                      'pool_monitors': pool.health_monitors,
                      'pool_name': pool.name}
 
+        api.lbaas.pool_monitor_association_delete(
+            IsA(http.HttpRequest), **form_data).AndReturn(None)
+
+        self.mox.ReplayAll()
+
         res = self.client.post(
             reverse(self.DELETEASSOC_PATH, args=(pool.id,)), form_data)
 
@@ -840,13 +808,13 @@ class LoadBalancerTests(test.TestCase):
         self.assertRedirectsNoFollow(res, str(self.INDEX_URL))
 
     @test.create_stubs({api.lbaas: ('pool_get',
-                                    'pool_health_monitors_get')})
+                                    'pool_health_monitor_list')})
     def test_delete_pool_monitor_association_get(self):
         pool = self.pools.first()
         monitors = self.monitors.list()
 
         api.lbaas.pool_get(IsA(http.HttpRequest), pool.id).AndReturn(pool)
-        api.lbaas.pool_health_monitors_get(
+        api.lbaas.pool_health_monitor_list(
             IsA(http.HttpRequest)).AndReturn(monitors)
 
         self.mox.ReplayAll()
@@ -861,3 +829,61 @@ class LoadBalancerTests(test.TestCase):
         expected_objs = [
             '<DeletePMAssociationStep: deletepmassociationaction>', ]
         self.assertQuerysetEqual(workflow.steps, expected_objs)
+
+    @test.create_stubs({api.lbaas: ('pool_list', 'member_list',
+                                    'pool_health_monitor_list',
+                                    'pool_delete')})
+    def test_delete_pool(self):
+        self.set_up_expect()
+        pool = self.pools.first()
+        api.lbaas.pool_delete(IsA(http.HttpRequest), pool.id)
+        self.mox.ReplayAll()
+
+        form_data = {"action": "poolstable__deletepool__%s" % pool.id}
+        res = self.client.post(self.INDEX_URL, form_data)
+
+        self.assertNoFormErrors(res)
+
+    @test.create_stubs({api.lbaas: ('pool_list', 'member_list',
+                                    'pool_health_monitor_list',
+                                    'pool_get', 'vip_delete')})
+    def test_delete_vip(self):
+        self.set_up_expect()
+        pool = self.pools.first()
+        vip = self.vips.first()
+        api.lbaas.pool_get(IsA(http.HttpRequest), pool.id).AndReturn(pool)
+        api.lbaas.vip_delete(IsA(http.HttpRequest), vip.id)
+        self.mox.ReplayAll()
+
+        form_data = {"action": "poolstable__deletevip__%s" % pool.id}
+        res = self.client.post(self.INDEX_URL, form_data)
+
+        self.assertNoFormErrors(res)
+
+    @test.create_stubs({api.lbaas: ('pool_list', 'member_list',
+                                    'pool_health_monitor_list',
+                                    'member_delete')})
+    def test_delete_member(self):
+        self.set_up_expect()
+        member = self.members.first()
+        api.lbaas.member_delete(IsA(http.HttpRequest), member.id)
+        self.mox.ReplayAll()
+
+        form_data = {"action": "memberstable__deletemember__%s" % member.id}
+        res = self.client.post(self.INDEX_URL, form_data)
+
+        self.assertNoFormErrors(res)
+
+    @test.create_stubs({api.lbaas: ('pool_list', 'member_list',
+                                    'pool_health_monitor_list',
+                                    'pool_health_monitor_delete')})
+    def test_delete_monitor(self):
+        self.set_up_expect()
+        monitor = self.monitors.first()
+        api.lbaas.pool_health_monitor_delete(IsA(http.HttpRequest), monitor.id)
+        self.mox.ReplayAll()
+
+        form_data = {"action": "monitorstable__deletemonitor__%s" % monitor.id}
+        res = self.client.post(self.INDEX_URL, form_data)
+
+        self.assertNoFormErrors(res)
