@@ -14,13 +14,14 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.core.urlresolvers import reverse_lazy  # noqa
-from django.utils.translation import ugettext_lazy as _  # noqa
+from django.core.urlresolvers import reverse_lazy
+from django.utils.translation import ugettext_lazy as _
 
 from horizon import exceptions
 from horizon import forms
 from horizon import messages
 from horizon import tabs
+from horizon.utils import memoized
 from horizon import workflows
 
 from openstack_dashboard import api
@@ -89,18 +90,10 @@ class IndexView(tabs.TabView):
 class AddPoolView(workflows.WorkflowView):
     workflow_class = project_workflows.AddPool
 
-    def get_initial(self):
-        initial = super(AddPoolView, self).get_initial()
-        return initial
-
 
 class AddVipView(workflows.WorkflowView):
     workflow_class = project_workflows.AddVip
 
-    def get_context_data(self, **kwargs):
-        context = super(AddVipView, self).get_context_data(**kwargs)
-        return context
-
     def get_initial(self):
         initial = super(AddVipView, self).get_initial()
         initial['pool_id'] = self.kwargs['pool_id']
@@ -118,18 +111,10 @@ class AddVipView(workflows.WorkflowView):
 class AddMemberView(workflows.WorkflowView):
     workflow_class = project_workflows.AddMember
 
-    def get_initial(self):
-        initial = super(AddMemberView, self).get_initial()
-        return initial
-
 
 class AddMonitorView(workflows.WorkflowView):
     workflow_class = project_workflows.AddMonitor
 
-    def get_initial(self):
-        initial = super(AddMonitorView, self).get_initial()
-        return initial
-
 
 class PoolDetailsView(tabs.TabView):
     tab_group_class = (project_tabs.PoolDetailsTabs)
@@ -162,16 +147,15 @@ class UpdatePoolView(forms.ModalFormView):
         context["pool_id"] = self.kwargs['pool_id']
         return context
 
+    @memoized.memoized_method
     def _get_object(self, *args, **kwargs):
-        if not hasattr(self, "_object"):
-            pool_id = self.kwargs['pool_id']
-            try:
-                self._object = api.lbaas.pool_get(self.request, pool_id)
-            except Exception as e:
-                redirect = self.success_url
-                msg = _('Unable to retrieve pool details. %s') % e
-                exceptions.handle(self.request, msg, redirect=redirect)
-        return self._object
+        pool_id = self.kwargs['pool_id']
+        try:
+            return api.lbaas.pool_get(self.request, pool_id)
+        except Exception as e:
+            redirect = self.success_url
+            msg = _('Unable to retrieve pool details. %s') % e
+            exceptions.handle(self.request, msg, redirect=redirect)
 
     def get_initial(self):
         pool = self._get_object()
@@ -193,16 +177,15 @@ class UpdateVipView(forms.ModalFormView):
         context["vip_id"] = self.kwargs['vip_id']
         return context
 
+    @memoized.memoized_method
     def _get_object(self, *args, **kwargs):
-        if not hasattr(self, "_object"):
-            vip_id = self.kwargs['vip_id']
-            try:
-                self._object = api.lbaas.vip_get(self.request, vip_id)
-            except Exception as e:
-                redirect = self.success_url
-                msg = _('Unable to retrieve VIP details. %s') % e
-                exceptions.handle(self.request, msg, redirect=redirect)
-        return self._object
+        vip_id = self.kwargs['vip_id']
+        try:
+            return api.lbaas.vip_get(self.request, vip_id)
+        except Exception as e:
+            redirect = self.success_url
+            msg = _('Unable to retrieve VIP details. %s') % e
+            exceptions.handle(self.request, msg, redirect=redirect)
 
     def get_initial(self):
         vip = self._get_object()
@@ -238,16 +221,15 @@ class UpdateMemberView(forms.ModalFormView):
         context["member_id"] = self.kwargs['member_id']
         return context
 
+    @memoized.memoized_method
     def _get_object(self, *args, **kwargs):
-        if not hasattr(self, "_object"):
-            member_id = self.kwargs['member_id']
-            try:
-                self._object = api.lbaas.member_get(self.request, member_id)
-            except Exception as e:
-                redirect = self.success_url
-                msg = _('Unable to retrieve member details. %s') % e
-                exceptions.handle(self.request, msg, redirect=redirect)
-        return self._object
+        member_id = self.kwargs['member_id']
+        try:
+            return api.lbaas.member_get(self.request, member_id)
+        except Exception as e:
+            redirect = self.success_url
+            msg = _('Unable to retrieve member details. %s') % e
+            exceptions.handle(self.request, msg, redirect=redirect)
 
     def get_initial(self):
         member = self._get_object()
@@ -268,17 +250,15 @@ class UpdateMonitorView(forms.ModalFormView):
         context["monitor_id"] = self.kwargs['monitor_id']
         return context
 
+    @memoized.memoized_method
     def _get_object(self, *args, **kwargs):
-        if not hasattr(self, "_object"):
-            monitor_id = self.kwargs['monitor_id']
-            try:
-                self._object = api.lbaas.pool_health_monitor_get(
-                    self.request, monitor_id)
-            except Exception as e:
-                redirect = self.success_url
-                msg = _('Unable to retrieve health monitor details. %s') % e
-                exceptions.handle(self.request, msg, redirect=redirect)
-        return self._object
+        monitor_id = self.kwargs['monitor_id']
+        try:
+            return api.lbaas.pool_health_monitor_get(self.request, monitor_id)
+        except Exception as e:
+            redirect = self.success_url
+            msg = _('Unable to retrieve health monitor details. %s') % e
+            exceptions.handle(self.request, msg, redirect=redirect)
 
     def get_initial(self):
         monitor = self._get_object()
