@@ -14,7 +14,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.utils.translation import ugettext_lazy as _  # noqa
+from django.utils.translation import ugettext_lazy as _
 
 from horizon import exceptions
 from horizon import forms
@@ -95,9 +95,9 @@ class AddPoolAction(workflows.Action):
                         _("%s (default)") % default_provider))
         else:
             if providers is None:
-                msg = _("Provider for Load Balancer is not supported.")
+                msg = _("Provider for Load Balancer is not supported")
             else:
-                msg = _("No provider is available.")
+                msg = _("No provider is available")
             provider_choices = [('', msg)]
             self.fields['provider'].widget.attrs['readonly'] = True
         self.fields['provider'].choices = provider_choices
@@ -165,12 +165,21 @@ class AddVipAction(workflows.Action):
                               validators=[validators.validate_port_range])
     protocol = forms.ChoiceField(label=_("Protocol"))
     session_persistence = forms.ChoiceField(
-        required=False, initial={}, label=_("Session Persistence"))
+        required=False, initial={}, label=_("Session Persistence"),
+        widget=forms.Select(attrs={
+            'class': 'switchable',
+            'data-slug': 'persistence'
+        }))
     cookie_name = forms.CharField(
         initial="", required=False,
         max_length=80, label=_("Cookie Name"),
         help_text=_("Required for APP_COOKIE persistence;"
-                    " Ignored otherwise."))
+                    " Ignored otherwise."),
+        widget=forms.TextInput(attrs={
+            'class': 'switched',
+            'data-switch-on': 'persistence',
+            'data-persistence-app_cookie': 'APP_COOKIE',
+        }))
     connection_limit = forms.IntegerField(
         required=False, min_value=-1, label=_("Connection Limit"),
         help_text=_("Maximum number of connections allowed "
@@ -182,8 +191,7 @@ class AddVipAction(workflows.Action):
         super(AddVipAction, self).__init__(request, *args, **kwargs)
 
         self.fields['other_address'].label = _("Specify a free IP address"
-                                               " from %s" %
-                                               args[0]['subnet'])
+                                               " from %s") % args[0]['subnet']
 
         protocol_choices = [('', _("Select a Protocol"))]
         [protocol_choices.append((p, p)) for p in AVAILABLE_PROTOCOLS]
@@ -191,7 +199,7 @@ class AddVipAction(workflows.Action):
 
         session_persistence_choices = [('', _("No Session Persistence"))]
         for mode in ('SOURCE_IP', 'HTTP_COOKIE', 'APP_COOKIE'):
-            session_persistence_choices.append((mode, mode))
+            session_persistence_choices.append((mode.lower(), mode))
         self.fields[
             'session_persistence'].choices = session_persistence_choices
 
@@ -200,6 +208,9 @@ class AddVipAction(workflows.Action):
 
     def clean(self):
         cleaned_data = super(AddVipAction, self).clean()
+        persistence = cleaned_data.get('session_persistence')
+        if persistence:
+            cleaned_data['session_persistence'] = persistence.upper()
         if (cleaned_data.get('session_persistence') == 'APP_COOKIE' and
                 not cleaned_data.get('cookie_name')):
             msg = _('Cookie name is required for APP_COOKIE persistence.')
@@ -308,7 +319,7 @@ class AddMemberAction(workflows.Action):
         pool_id_choices = [('', _("Select a Pool"))]
         try:
             tenant_id = self.request.user.tenant_id
-            pools = api.lbaas.pools_get(request, tenant_id=tenant_id)
+            pools = api.lbaas.pool_list(request, tenant_id=tenant_id)
         except Exception:
             pools = []
             exceptions.handle(request,
@@ -328,13 +339,15 @@ class AddMemberAction(workflows.Action):
                               _('Unable to retrieve instances list.'))
 
         if len(servers) == 0:
-            self.fields['members'].label = _("No servers available. "
-                                             "Click Add to cancel.")
-            self.fields['members'].required = False
+            self.fields['members'].label = _(
+                "No servers available. To add a member, you "
+                "need at least one running instance.")
+            self.fields['members'].required = True
             self.fields['members'].help_text = _("Select members "
                                                  "for this pool ")
             self.fields['pool_id'].required = False
             self.fields['protocol_port'].required = False
+
             return
 
         for m in servers:
@@ -550,12 +563,12 @@ class AddPMAssociationAction(workflows.Action, MonitorMixin):
 
     def populate_monitor_id_choices(self, request, context):
         self.fields['monitor_id'].label = _("Select a monitor template "
-                                            "for %s" % context['pool_name'])
+                                            "for %s") % context['pool_name']
 
         monitor_id_choices = [('', _("Select a Monitor"))]
         try:
             tenant_id = self.request.user.tenant_id
-            monitors = api.lbaas.pool_health_monitors_get(request,
+            monitors = api.lbaas.pool_health_monitor_list(request,
                                                           tenant_id=tenant_id)
             for m in monitors:
                 if m.id not in context['pool_monitors']:
@@ -587,10 +600,10 @@ class AddPMAssociationStep(workflows.Step):
 
 class AddPMAssociation(workflows.Workflow):
     slug = "addassociation"
-    name = _("Add Association")
-    finalize_button_name = _("Add")
-    success_message = _('Added association.')
-    failure_message = _('Unable to add association.')
+    name = _("Associate Monitor")
+    finalize_button_name = _("Associate")
+    success_message = _('Associated monitor.')
+    failure_message = _('Unable to associate monitor.')
     success_url = "horizon:project:loadbalancers:index"
     default_steps = (AddPMAssociationStep,)
 
@@ -600,8 +613,8 @@ class AddPMAssociation(workflows.Workflow):
                 request, **context)
             return True
         except Exception:
-            exceptions.handle(request, _("Unable to add association."))
-        return False
+            exceptions.handle(request, _("Unable to associate monitor."))
+            return False
 
 
 class DeletePMAssociationAction(workflows.Action, MonitorMixin):
@@ -617,7 +630,7 @@ class DeletePMAssociationAction(workflows.Action, MonitorMixin):
 
         monitor_id_choices = [('', _("Select a Monitor"))]
         try:
-            monitors = api.lbaas.pool_health_monitors_get(request)
+            monitors = api.lbaas.pool_health_monitor_list(request)
             for m in monitors:
                 if m.id in context['pool_monitors']:
                     display_name = self._get_monitor_display_name(m)
@@ -649,10 +662,10 @@ class DeletePMAssociationStep(workflows.Step):
 
 class DeletePMAssociation(workflows.Workflow):
     slug = "deleteassociation"
-    name = _("Delete Association")
-    finalize_button_name = _("Delete")
-    success_message = _('Deleted association.')
-    failure_message = _('Unable to delete association.')
+    name = _("Disassociate Monitor")
+    finalize_button_name = _("Disassociate")
+    success_message = _('Disassociated monitor.')
+    failure_message = _('Unable to disassociate monitor.')
     success_url = "horizon:project:loadbalancers:index"
     default_steps = (DeletePMAssociationStep,)
 
@@ -662,5 +675,5 @@ class DeletePMAssociation(workflows.Workflow):
                 request, **context)
             return True
         except Exception:
-            exceptions.handle(request, _("Unable to delete association."))
+            exceptions.handle(request, _("Unable to disassociate monitor."))
         return False
