@@ -16,8 +16,8 @@
 
 import logging
 
-from django.core.urlresolvers import reverse  # noqa
-from django.utils.translation import ugettext_lazy as _  # noqa
+from django.core.urlresolvers import reverse
+from django.utils.translation import ugettext_lazy as _
 
 from horizon import exceptions
 from horizon import forms
@@ -41,7 +41,7 @@ class UpdatePort(forms.SelfHandlingForm):
     def handle(self, request, data):
         try:
             LOG.debug('params = %s' % data)
-            port = api.neutron.port_modify(request, data['port_id'],
+            port = api.neutron.port_update(request, data['port_id'],
                                            name=data['name'],
                                            admin_state_up=data['admin_state'])
             msg = _('Port %s was successfully updated.') % data['port_id']
