@@ -14,8 +14,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import logging
-
 from django.core.urlresolvers import reverse
 from django.utils.translation import ugettext_lazy as _
 
@@ -25,9 +23,6 @@ from horizon import tabs
 from openstack_dashboard import api
 
 
-LOG = logging.getLogger(__name__)
-
-
 class OverviewTab(tabs.Tab):
     name = _("Overview")
     slug = "overview"
@@ -36,8 +31,8 @@ class OverviewTab(tabs.Tab):
     def get_context_data(self, request):
         port_id = self.tab_group.kwargs['port_id']
         try:
-            port = api.quantum.port_get(self.request, port_id)
-        except:
+            port = api.neutron.port_get(self.request, port_id)
+        except Exception:
             redirect = reverse('horizon:project:networks:index')
             msg = _('Unable to retrieve port details.')
             exceptions.handle(request, msg, redirect=redirect)
