@@ -16,8 +16,8 @@
 
 import logging
 
-from django.core.urlresolvers import reverse  # noqa
-from django.utils.translation import ugettext_lazy as _  # noqa
+from django.core.urlresolvers import reverse
+from django.utils.translation import ugettext_lazy as _
 
 from horizon import exceptions
 from horizon import forms
@@ -149,8 +149,8 @@ class UpdateSubnetDetail(network_workflows.CreateSubnetDetail):
 
 class UpdateSubnet(network_workflows.CreateNetwork):
     slug = "update_subnet"
-    name = _("Update Subnet")
-    finalize_button_name = _("Update")
+    name = _("Edit Subnet")
+    finalize_button_name = _("Save")
     success_message = _('Updated subnet "%s".')
     failure_message = _('Unable to update subnet "%s".')
     success_url = "horizon:project:networks:detail"
@@ -187,7 +187,7 @@ class UpdateSubnet(network_workflows.CreateNetwork):
 
             self._setup_subnet_parameters(params, data, is_create=False)
 
-            subnet = api.neutron.subnet_modify(request, subnet_id, **params)
+            subnet = api.neutron.subnet_update(request, subnet_id, **params)
             msg = _('Subnet "%s" was successfully updated.') % data['cidr']
             LOG.debug(msg)
             return subnet
