@@ -15,39 +15,41 @@
 #    under the License.
 
 """
-Views for managing Quantum Networks.
+Views for managing Neutron Networks.
 """
-import logging
-
 from django.core.urlresolvers import reverse_lazy
 from django.utils.translation import ugettext_lazy as _
 
 from horizon import exceptions
 from horizon import forms
 from horizon import tables
+from horizon.utils import memoized
 from horizon import workflows
 
 from openstack_dashboard import api
-from .tables import NetworksTable
-from .subnets.tables import SubnetsTable
-from .ports.tables import PortsTable
-from .forms import UpdateNetwork
-from .workflows import CreateNetwork
 
-
-LOG = logging.getLogger(__name__)
+from openstack_dashboard.dashboards.project.networks \
+    import forms as project_forms
+from openstack_dashboard.dashboards.project.networks.ports \
+    import tables as port_tables
+from openstack_dashboard.dashboards.project.networks.subnets \
+    import tables as subnet_tables
+from openstack_dashboard.dashboards.project.networks \
+    import tables as project_tables
+from openstack_dashboard.dashboards.project.networks \
+    import workflows as project_workflows
 
 
 class IndexView(tables.DataTableView):
-    table_class = NetworksTable
+    table_class = project_tables.NetworksTable
     template_name = 'project/networks/index.html'
 
     def get_data(self):
         try:
             tenant_id = self.request.user.tenant_id
-            networks = api.quantum.network_list_for_tenant(self.request,
+            networks = api.neutron.network_list_for_tenant(self.request,
                                                            tenant_id)
-        except:
+        except Exception:
             networks = []
             msg = _('Network list can not be retrieved.')
             exceptions.handle(self.request, msg)
@@ -57,15 +59,14 @@ class IndexView(tables.DataTableView):
 
 
 class CreateView(workflows.WorkflowView):
-    workflow_class = CreateNetwork
-    template_name = 'project/networks/create.html'
+    workflow_class = project_workflows.CreateNetwork
 
     def get_initial(self):
         pass
 
 
 class UpdateView(forms.ModalFormView):
-    form_class = UpdateNetwork
+    form_class = project_forms.UpdateNetwork
     template_name = 'project/networks/update.html'
     context_object_name = 'network'
     success_url = reverse_lazy("horizon:project:networks:index")
@@ -75,17 +76,15 @@ class UpdateView(forms.ModalFormView):
         context["network_id"] = self.kwargs['network_id']
         return context
 
+    @memoized.memoized_method
     def _get_object(self, *args, **kwargs):
-        if not hasattr(self, "_object"):
-            network_id = self.kwargs['network_id']
-            try:
-                self._object = api.quantum.network_get(self.request,
-                                                       network_id)
-            except:
-                redirect = self.success_url
-                msg = _('Unable to retrieve network details.')
-                exceptions.handle(self.request, msg, redirect=redirect)
-        return self._object
+        network_id = self.kwargs['network_id']
+        try:
+            return api.neutron.network_get(self.request, network_id)
+        except Exception:
+            redirect = self.success_url
+            msg = _('Unable to retrieve network details.')
+            exceptions.handle(self.request, msg, redirect=redirect)
 
     def get_initial(self):
         network = self._get_object()
@@ -96,16 +95,16 @@ class UpdateView(forms.ModalFormView):
 
 
 class DetailView(tables.MultiTableView):
-    table_classes = (SubnetsTable, PortsTable)
+    table_classes = (subnet_tables.SubnetsTable, port_tables.PortsTable)
     template_name = 'project/networks/detail.html'
     failure_url = reverse_lazy('horizon:project:networks:index')
 
     def get_subnets_data(self):
         try:
             network = self._get_data()
-            subnets = api.quantum.subnet_list(self.request,
+            subnets = api.neutron.subnet_list(self.request,
                                               network_id=network.id)
-        except:
+        except Exception:
             subnets = []
             msg = _('Subnet list can not be retrieved.')
             exceptions.handle(self.request, msg)
@@ -116,8 +115,8 @@ class DetailView(tables.MultiTableView):
     def get_ports_data(self):
         try:
             network_id = self.kwargs['network_id']
-            ports = api.quantum.port_list(self.request, network_id=network_id)
-        except:
+            ports = api.neutron.port_list(self.request, network_id=network_id)
+        except Exception:
             ports = []
             msg = _('Port list can not be retrieved.')
             exceptions.handle(self.request, msg)
@@ -125,18 +124,17 @@ class DetailView(tables.MultiTableView):
             p.set_id_as_name_if_empty()
         return ports
 
+    @memoized.memoized_method
     def _get_data(self):
-        if not hasattr(self, "_network"):
-            try:
-                network_id = self.kwargs['network_id']
-                network = api.quantum.network_get(self.request, network_id)
-                network.set_id_as_name_if_empty(length=0)
-            except:
-                msg = _('Unable to retrieve details for network "%s".') \
-                      % (network_id)
-                exceptions.handle(self.request, msg, redirect=self.failure_url)
-            self._network = network
-        return self._network
+        try:
+            network_id = self.kwargs['network_id']
+            network = api.neutron.network_get(self.request, network_id)
+            network.set_id_as_name_if_empty(length=0)
+        except Exception:
+            msg = _('Unable to retrieve details for network "%s".') \
+                % (network_id)
+            exceptions.handle(self.request, msg, redirect=self.failure_url)
+        return network
 
     def get_context_data(self, **kwargs):
         context = super(DetailView, self).get_context_data(**kwargs)
