@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2013, Big Switch Networks
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -12,6 +14,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import logging
+
 from django.core.urlresolvers import reverse
 from django.utils.translation import ugettext_lazy as _
 
@@ -24,12 +28,14 @@ from openstack_dashboard.dashboards.project.routers.extensions.routerrules\
     import forms as rrforms
 
 
+LOG = logging.getLogger(__name__)
+
+
 class AddRouterRuleView(forms.ModalFormView):
     form_class = rrforms.AddRouterRule
     template_name = 'project/routers/extensions/routerrules/create.html'
     success_url = 'horizon:project:routers:detail'
     failure_url = 'horizon:project:routers:detail'
-    page_title = _("Add Router Rule")
 
     def get_success_url(self):
         return reverse(self.success_url,
@@ -56,4 +62,4 @@ class AddRouterRuleView(forms.ModalFormView):
         # to request it again from the API
         self.request.META['router'] = router
         return {"router_id": self.kwargs['router_id'],
-                "router_name": router.name_or_id}
+                "router_name": router.name}
