@@ -1,6 +1,7 @@
 # vim: tabstop=4 shiftwidth=4 softtabstop=4
 
 # Copyright 2012,  Nachi Ueno,  NTT MCL,  Inc.
+# Copyright 2013,  Big Switch Networks, Inc.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
@@ -18,25 +19,24 @@
 Views for managing Neutron Routers.
 """
 
-from django.core.urlresolvers import reverse_lazy  # noqa
-from django.utils.datastructures import SortedDict  # noqa
-from django.utils.translation import ugettext_lazy as _  # noqa
+from django.core.urlresolvers import reverse_lazy
+from django.utils.datastructures import SortedDict
+from django.utils.translation import ugettext_lazy as _
 
 from horizon import exceptions
 from horizon import forms
 from horizon import tables
+from horizon import tabs
+from horizon.utils import memoized
 from openstack_dashboard import api
-
-from openstack_dashboard.dashboards.project.routers \
+from openstack_dashboard.dashboards.project.routers\
     import forms as project_forms
-from openstack_dashboard.dashboards.project.routers.ports \
-    import tables as port_tables
-from openstack_dashboard.dashboards.project.routers \
-    import tables as project_tables
+from openstack_dashboard.dashboards.project.routers import tables as rtables
+from openstack_dashboard.dashboards.project.routers import tabs as rdtabs
 
 
 class IndexView(tables.DataTableView):
-    table_class = project_tables.RoutersTable
+    table_class = rtables.RoutersTable
     template_name = 'project/routers/index.html'
 
     def _get_routers(self, search_opts=None):
@@ -86,55 +86,44 @@ class IndexView(tables.DataTableView):
                 exceptions.handle(self.request, msg)
 
 
-class DetailView(tables.MultiTableView):
-    table_classes = (port_tables.PortsTable, )
+class DetailView(tabs.TabbedTableView):
+    tab_group_class = rdtabs.RouterDetailTabs
     template_name = 'project/routers/detail.html'
     failure_url = reverse_lazy('horizon:project:routers:index')
 
+    @memoized.memoized_method
     def _get_data(self):
-        if not hasattr(self, "_router"):
+        try:
+            router_id = self.kwargs['router_id']
+            router = api.neutron.router_get(self.request, router_id)
+            router.set_id_as_name_if_empty(length=0)
+        except Exception:
+            msg = _('Unable to retrieve details for router "%s".') \
+                % (router_id)
+            exceptions.handle(self.request, msg, redirect=self.failure_url)
+        if router.external_gateway_info:
+            ext_net_id = router.external_gateway_info['network_id']
             try:
-                router_id = self.kwargs['router_id']
-                router = api.neutron.router_get(self.request, router_id)
-                router.set_id_as_name_if_empty(length=0)
+                ext_net = api.neutron.network_get(self.request, ext_net_id,
+                                                  expand_subnet=False)
+                ext_net.set_id_as_name_if_empty(length=0)
+                router.external_gateway_info['network'] = ext_net.name
             except Exception:
-                msg = _('Unable to retrieve details for router "%s".') \
-                    % (router_id)
-                exceptions.handle(self.request, msg, redirect=self.failure_url)
-
-            if router.external_gateway_info:
-                ext_net_id = router.external_gateway_info['network_id']
-                try:
-                    ext_net = api.neutron.network_get(self.request, ext_net_id,
-                                                      expand_subnet=False)
-                    ext_net.set_id_as_name_if_empty(length=0)
-                    router.external_gateway_info['network'] = ext_net.name
-                except Exception:
-                    msg = _('Unable to retrieve an external network "%s".') \
-                        % (ext_net_id)
-                    exceptions.handle(self.request, msg)
-                    router.external_gateway_info['network'] = ext_net_id
-
-            self._router = router
-        return self._router
+                msg = _('Unable to retrieve an external network "%s".') \
+                    % (ext_net_id)
+                exceptions.handle(self.request, msg)
+                router.external_gateway_info['network'] = ext_net_id
+        return router
 
     def get_context_data(self, **kwargs):
         context = super(DetailView, self).get_context_data(**kwargs)
         context["router"] = self._get_data()
         return context
 
-    def get_interfaces_data(self):
-        try:
-            device_id = self.kwargs['router_id']
-            ports = api.neutron.port_list(self.request,
-                                          device_id=device_id)
-        except Exception:
-            ports = []
-            msg = _('Port list can not be retrieved.')
-            exceptions.handle(self.request, msg)
-        for p in ports:
-            p.set_id_as_name_if_empty()
-        return ports
+    def get(self, request, *args, **kwargs):
+        router = self._get_data()
+        self.kwargs['router'] = router
+        return super(DetailView, self).get(request, *args, **kwargs)
 
 
 class CreateView(forms.ModalFormView):
