@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -12,30 +14,45 @@
 
 import json
 import logging
+import re
 
-import django
-from django.conf import settings
-from django.utils import html
 from django.utils.translation import ugettext_lazy as _
-from django.views.decorators.debug import sensitive_variables
-
-from oslo_utils import strutils
-import six
+from django.views.decorators.debug import sensitive_variables  # noqa
 
 from horizon import exceptions
 from horizon import forms
 from horizon import messages
 
 from openstack_dashboard import api
-from openstack_dashboard.dashboards.project.images \
-    import utils as image_utils
-from openstack_dashboard.dashboards.project.instances \
-    import utils as instance_utils
-
 
 LOG = logging.getLogger(__name__)
 
 
+def exception_to_validation_msg(e):
+    """Extracts a validation message to display to the user."""
+    try:
+        error = json.loads(str(e))
+        # NOTE(jianingy): if no message exists, we just return 'None'
+        # and let the caller to deciede what to show
+        return error['error'].get('message', None)
+    except Exception:
+        # NOTE(jianingy): fallback to legacy message parsing approach
+        # either if error message isn't a json nor the json isn't in
+        # valid format.
+        validation_patterns = [
+            "Remote error: \w* {'Error': '(.*?)'}",
+            'Remote error: \w* (.*?) \[',
+            '400 Bad Request\n\nThe server could not comply with the request '
+            'since it is either malformed or otherwise incorrect.\n\n (.*)',
+            '(ParserError: .*)'
+        ]
+
+        for pattern in validation_patterns:
+            match = re.search(pattern, str(e))
+            if match:
+                return match.group(1)
+
+
 def create_upload_form_attributes(prefix, input_type, name):
     """Creates attribute dicts for the switchable upload form
 
@@ -55,20 +72,18 @@ def create_upload_form_attributes(prefix, input_type, name):
 
 class TemplateForm(forms.SelfHandlingForm):
 
-    class Meta(object):
+    class Meta:
         name = _('Select Template')
-        help_text = _('Select a template to launch a stack.')
+        help_text = _('From here you can select a template to launch '
+                      'a stack.')
 
-    # TODO(jomara) - update URL choice for template & environment files
-    # w/ client side download when applicable
-    base_choices = [('file', _('File')),
-                    ('raw', _('Direct Input'))]
-    url_choice = [('url', _('URL'))]
+    choices = [('url', _('URL')),
+               ('file', _('File')),
+               ('raw', _('Direct Input'))]
     attributes = {'class': 'switchable', 'data-slug': 'templatesource'}
     template_source = forms.ChoiceField(label=_('Template Source'),
-                                        choices=base_choices + url_choice,
-                                        widget=forms.ThemableSelectWidget(
-                                            attrs=attributes))
+                                        choices=choices,
+                                        widget=forms.Select(attrs=attributes))
 
     attributes = create_upload_form_attributes(
         'template',
@@ -103,8 +118,8 @@ class TemplateForm(forms.SelfHandlingForm):
     attributes = {'data-slug': 'envsource', 'class': 'switchable'}
     environment_source = forms.ChoiceField(
         label=_('Environment Source'),
-        choices=base_choices,
-        widget=forms.ThemableSelectWidget(attrs=attributes),
+        choices=choices,
+        widget=forms.Select(attrs=attributes),
         required=False)
 
     attributes = create_upload_form_attributes(
@@ -117,6 +132,16 @@ class TemplateForm(forms.SelfHandlingForm):
         widget=forms.FileInput(attrs=attributes),
         required=False)
 
+    attributes = create_upload_form_attributes(
+        'env',
+        'url',
+        _('Environment URL'))
+    environment_url = forms.URLField(
+        label=_('Environment URL'),
+        help_text=_('An external (HTTP) URL to load the environment from.'),
+        widget=forms.TextInput(attrs=attributes),
+        required=False)
+
     attributes = create_upload_form_attributes(
         'env',
         'raw',
@@ -127,13 +152,6 @@ class TemplateForm(forms.SelfHandlingForm):
         widget=forms.widgets.Textarea(attrs=attributes),
         required=False)
 
-    if django.VERSION >= (1, 9):
-        # Note(Itxaka): On django>=1.9 Charfield has an strip option that
-        # we need to set to False as to not hit
-        # https://bugs.launchpad.net/python-heatclient/+bug/1546166
-        environment_data.strip = False
-        template_data.strip = False
-
     def __init__(self, *args, **kwargs):
         self.next_view = kwargs.pop('next_view')
         super(TemplateForm, self).__init__(*args, **kwargs)
@@ -143,25 +161,27 @@ class TemplateForm(forms.SelfHandlingForm):
 
         files = self.request.FILES
         self.clean_uploaded_files('template', _('template'), cleaned, files)
-        self.clean_uploaded_files('environment', _('environment'), cleaned,
-                                  files)
+        self.clean_uploaded_files('environment',
+            _('environment'),
+            cleaned,
+            files)
 
         # Validate the template and get back the params.
         kwargs = {}
-        if cleaned['environment_data']:
-            kwargs['environment'] = cleaned['environment_data']
+        if cleaned['template_data']:
+            kwargs['template'] = cleaned['template_data']
+        else:
+            kwargs['template_url'] = cleaned['template_url']
+
         try:
-            files, tpl =\
-                api.heat.get_template_files(cleaned.get('template_data'),
-                                            cleaned.get('template_url'))
-            kwargs['files'] = files
-            kwargs['template'] = tpl
             validated = api.heat.template_validate(self.request, **kwargs)
             cleaned['template_validate'] = validated
-            cleaned['template_validate']['files'] = files
-            cleaned['template_validate']['template'] = tpl
         except Exception as e:
-            raise forms.ValidationError(six.text_type(e))
+            msg = exception_to_validation_msg(e)
+            if not msg:
+                msg = _('An unknown problem occurred validating the template.')
+                LOG.exception(msg)
+            raise forms.ValidationError(msg)
 
         return cleaned
 
@@ -191,7 +211,7 @@ class TemplateForm(forms.SelfHandlingForm):
         # Uploaded file handler
         if has_upload and not url:
             log_template_name = files[upload_str].name
-            LOG.info('got upload %s', log_template_name)
+            LOG.info('got upload %s' % log_template_name)
 
             tpl = files[upload_str].read()
             if tpl.startswith('{'):
@@ -200,7 +220,7 @@ class TemplateForm(forms.SelfHandlingForm):
                 except Exception as e:
                     msg = _('There was a problem parsing the'
                             ' %(prefix)s: %(error)s')
-                    msg = msg % {'prefix': prefix, 'error': six.text_type(e)}
+                    msg = msg % {'prefix': prefix, 'error': e}
                     raise forms.ValidationError(msg)
             cleaned[data_str] = tpl
 
@@ -219,7 +239,10 @@ class TemplateForm(forms.SelfHandlingForm):
 
     def create_kwargs(self, data):
         kwargs = {'parameters': data['template_validate'],
-                  'environment_data': data['environment_data']}
+                  'environment_data': data['environment_data'],
+                  'environment_url': data['environment_url'],
+                  'template_data': data['template_data'],
+                  'template_url': data['template_url']}
         if data.get('stack_id'):
             kwargs['stack_id'] = data['stack_id']
         return kwargs
@@ -235,53 +258,55 @@ class TemplateForm(forms.SelfHandlingForm):
 
 
 class ChangeTemplateForm(TemplateForm):
-    class Meta(object):
+    class Meta:
         name = _('Edit Template')
-        help_text = _('Select a new template to re-launch a stack.')
+        help_text = _('From here you can select a new template to re-launch '
+                      'a stack.')
     stack_id = forms.CharField(label=_('Stack ID'),
-                               widget=forms.widgets.HiddenInput)
+        widget=forms.widgets.HiddenInput,
+        required=True)
     stack_name = forms.CharField(label=_('Stack Name'),
-                                 widget=forms.TextInput(attrs={'readonly':
-                                                               'readonly'}))
-
-
-class PreviewTemplateForm(TemplateForm):
-    class Meta(object):
-        name = _('Preview Template')
-        help_text = _('Select a new template to preview a stack.')
+        widget=forms.TextInput(
+            attrs={'readonly': 'readonly'}
+        ))
 
 
 class CreateStackForm(forms.SelfHandlingForm):
 
     param_prefix = '__param_'
 
-    class Meta(object):
+    class Meta:
         name = _('Create Stack')
 
+    template_data = forms.CharField(
+        widget=forms.widgets.HiddenInput,
+        required=False)
+    template_url = forms.CharField(
+        widget=forms.widgets.HiddenInput,
+        required=False)
     environment_data = forms.CharField(
         widget=forms.widgets.HiddenInput,
         required=False)
-    if django.VERSION >= (1, 9):
-        # Note(Itxaka): On django>=1.9 Charfield has an strip option that
-        # we need to set to False as to not hit
-        # https://bugs.launchpad.net/python-heatclient/+bug/1546166
-        environment_data.strip = False
-
+    environment_url = forms.CharField(
+        widget=forms.widgets.HiddenInput,
+        required=False)
     parameters = forms.CharField(
-        widget=forms.widgets.HiddenInput)
+        widget=forms.widgets.HiddenInput,
+        required=True)
     stack_name = forms.RegexField(
-        max_length=255,
+        max_length='255',
         label=_('Stack Name'),
         help_text=_('Name of the stack to create.'),
         regex=r"^[a-zA-Z][a-zA-Z0-9_.-]*$",
-        error_messages={'invalid':
-                        _('Name must start with a letter and may '
-                          'only contain letters, numbers, underscores, '
-                          'periods and hyphens.')})
+        error_messages={'invalid': _('Name must start with a letter and may '
+                            'only contain letters, numbers, underscores, '
+                            'periods and hyphens.')},
+        required=True)
     timeout_mins = forms.IntegerField(
         initial=60,
         label=_('Creation Timeout (minutes)'),
-        help_text=_('Stack creation timeout in minutes.'))
+        help_text=_('Stack creation timeout in minutes.'),
+        required=True)
     enable_rollback = forms.BooleanField(
         label=_('Rollback On Failure'),
         help_text=_('Enable rollback on create/update failure.'),
@@ -290,75 +315,45 @@ class CreateStackForm(forms.SelfHandlingForm):
     def __init__(self, *args, **kwargs):
         parameters = kwargs.pop('parameters')
         # special case: load template data from API, not passed in params
-        if kwargs.get('validate_me'):
+        if(kwargs.get('validate_me')):
             parameters = kwargs.pop('validate_me')
         super(CreateStackForm, self).__init__(*args, **kwargs)
-
-        if self._stack_password_enabled():
-            self.fields['password'] = forms.CharField(
-                label=_('Password for user "%s"') % self.request.user.username,
-                help_text=_('This is required for operations to be performed '
-                            'throughout the lifecycle of the stack'),
-                widget=forms.PasswordInput())
-
         self._build_parameter_fields(parameters)
 
-    def _stack_password_enabled(self):
-        stack_settings = getattr(settings, 'OPENSTACK_HEAT_STACK', {})
-        return stack_settings.get('enable_user_pass', True)
-
     def _build_parameter_fields(self, template_validate):
+        self.fields['password'] = forms.CharField(
+            label=_('Password for user "%s"') % self.request.user.username,
+            help_text=_('This is required for operations to be performed '
+                        'throughout the lifecycle of the stack'),
+            required=True,
+            widget=forms.PasswordInput())
+
         self.help_text = template_validate['Description']
 
         params = template_validate.get('Parameters', {})
-        if template_validate.get('ParameterGroups'):
-            params_in_order = []
-            for group in template_validate['ParameterGroups']:
-                for param in group.get('parameters', []):
-                    if param in params:
-                        params_in_order.append((param, params[param]))
-        else:
-            # no parameter groups, simply sorted to make the order fixed
-            params_in_order = sorted(params.items())
-        for param_key, param in params_in_order:
-            field = None
+
+        for param_key, param in params.items():
             field_key = self.param_prefix + param_key
-            initial = param.get('Value',
-                                param.get('DefaultValue',
-                                          param.get('Default')))
             field_args = {
-                'initial': initial,
-                'label': param.get('Label', param_key),
-                'help_text': html.escape(param.get('Description', '')),
-                'required': initial is None,
+                'initial': param.get('Default', None),
+                'label': param_key,
+                'help_text': param.get('Description', ''),
+                'required': param.get('Default', None) is None
             }
 
             param_type = param.get('Type', None)
-            hidden = strutils.bool_from_string(param.get('NoEcho', 'false'))
-            if 'CustomConstraint' in param:
-                choices = self._populate_custom_choices(
-                    param['CustomConstraint'])
-                field_args['choices'] = choices
-                field = forms.ChoiceField(**field_args)
 
-            elif 'AllowedValues' in param:
+            if 'AllowedValues' in param:
                 choices = map(lambda x: (x, x), param['AllowedValues'])
                 field_args['choices'] = choices
                 field = forms.ChoiceField(**field_args)
 
-            elif param_type == 'Json' and 'Default' in param:
-                field_args['initial'] = json.dumps(param['Default'])
-                field = forms.CharField(**field_args)
-
-            elif param_type in ('CommaDelimitedList', 'String', 'Json'):
+            elif param_type in ('CommaDelimitedList', 'String'):
                 if 'MinLength' in param:
                     field_args['min_length'] = int(param['MinLength'])
-                    field_args['required'] = field_args['min_length'] > 0
+                    field_args['required'] = param.get('MinLength', 0) > 0
                 if 'MaxLength' in param:
                     field_args['max_length'] = int(param['MaxLength'])
-                if hidden:
-                    field_args['widget'] = forms.PasswordInput(
-                        render_value=True)
                 field = forms.CharField(**field_args)
 
             elif param_type == 'Number':
@@ -368,67 +363,57 @@ class CreateStackForm(forms.SelfHandlingForm):
                     field_args['max_value'] = int(param['MaxValue'])
                 field = forms.IntegerField(**field_args)
 
-            elif param_type == 'Boolean':
-                field_args['required'] = False
-                field = forms.BooleanField(**field_args)
-
-            if field:
-                self.fields[field_key] = field
+            self.fields[field_key] = field
 
     @sensitive_variables('password')
     def handle(self, request, data):
         prefix_length = len(self.param_prefix)
-        params_list = [(k[prefix_length:], v) for (k, v) in data.items()
+        params_list = [(k[prefix_length:], v) for (k, v) in data.iteritems()
                        if k.startswith(self.param_prefix)]
         fields = {
             'stack_name': data.get('stack_name'),
             'timeout_mins': data.get('timeout_mins'),
             'disable_rollback': not(data.get('enable_rollback')),
             'parameters': dict(params_list),
-            'files': json.loads(data.get('parameters')).get('files'),
-            'template': json.loads(data.get('parameters')).get('template')
+            'password': data.get('password')
         }
-        if data.get('password'):
-            fields['password'] = data.get('password')
+
+        if data.get('template_data'):
+            fields['template'] = data.get('template_data')
+        else:
+            fields['template_url'] = data.get('template_url')
 
         if data.get('environment_data'):
             fields['environment'] = data.get('environment_data')
+        elif data.get('environment_url'):
+            fields['environment_url'] = data.get('environment_url')
 
         try:
             api.heat.stack_create(self.request, **fields)
-            messages.info(request, _("Stack creation started."))
+            messages.success(request, _("Stack creation started."))
             return True
-        except Exception:
-            exceptions.handle(request)
-
-    def _populate_custom_choices(self, custom_type):
-        if custom_type == 'neutron.network':
-            return instance_utils.network_field_data(self.request, True)
-        if custom_type == 'nova.keypair':
-            return instance_utils.keypair_field_data(self.request, True)
-        if custom_type == 'glance.image':
-            return image_utils.image_field_data(self.request, True)
-        if custom_type == 'nova.flavor':
-            return instance_utils.flavor_field_data(self.request, True)
-        return []
+        except Exception as e:
+            msg = exception_to_validation_msg(e)
+            exceptions.handle(request, msg or _('Stack creation failed.'))
 
 
 class EditStackForm(CreateStackForm):
 
-    class Meta(object):
+    class Meta:
         name = _('Update Stack Parameters')
 
-    stack_id = forms.CharField(
-        label=_('Stack ID'),
-        widget=forms.widgets.HiddenInput)
-    stack_name = forms.CharField(
-        label=_('Stack Name'),
-        widget=forms.TextInput(attrs={'readonly': 'readonly'}))
+    stack_id = forms.CharField(label=_('Stack ID'),
+        widget=forms.widgets.HiddenInput,
+        required=True)
+    stack_name = forms.CharField(label=_('Stack Name'),
+        widget=forms.TextInput(
+            attrs={'readonly': 'readonly'}
+        ))
 
     @sensitive_variables('password')
     def handle(self, request, data):
         prefix_length = len(self.param_prefix)
-        params_list = [(k[prefix_length:], v) for (k, v) in data.items()
+        params_list = [(k[prefix_length:], v) for (k, v) in data.iteritems()
                        if k.startswith(self.param_prefix)]
 
         stack_id = data.get('stack_id')
@@ -437,52 +422,22 @@ class EditStackForm(CreateStackForm):
             'timeout_mins': data.get('timeout_mins'),
             'disable_rollback': not(data.get('enable_rollback')),
             'parameters': dict(params_list),
-            'files': json.loads(data.get('parameters')).get('files'),
-            'template': json.loads(data.get('parameters')).get('template')
+            'password': data.get('password')
         }
-        if data.get('password'):
-            fields['password'] = data.get('password')
 
-        if data.get('environment_data'):
-            fields['environment'] = data.get('environment_data')
+        # if the user went directly to this form, resubmit the existing
+        # template data. otherwise, submit what they had from the first form
+        if data.get('template_data'):
+            fields['template'] = data.get('template_data')
+        elif data.get('template_url'):
+            fields['template_url'] = data.get('template_url')
+        elif data.get('parameters'):
+            fields['template'] = data.get('parameters')
 
         try:
             api.heat.stack_update(self.request, stack_id=stack_id, **fields)
-            messages.info(request, _("Stack update started."))
+            messages.success(request, _("Stack update started."))
             return True
-        except Exception:
-            exceptions.handle(request)
-
-
-class PreviewStackForm(CreateStackForm):
-
-    class Meta(object):
-        name = _('Preview Stack Parameters')
-
-    def __init__(self, *args, **kwargs):
-        self.next_view = kwargs.pop('next_view')
-        super(CreateStackForm, self).__init__(*args, **kwargs)
-
-    def handle(self, request, data):
-        prefix_length = len(self.param_prefix)
-        params_list = [(k[prefix_length:], v) for (k, v) in data.items()
-                       if k.startswith(self.param_prefix)]
-        fields = {
-            'stack_name': data.get('stack_name'),
-            'timeout_mins': data.get('timeout_mins'),
-            'disable_rollback': not(data.get('enable_rollback')),
-            'parameters': dict(params_list),
-            'files': json.loads(data.get('parameters')).get('files'),
-            'template': json.loads(data.get('parameters')).get('template')
-        }
-
-        if data.get('environment_data'):
-            fields['environment'] = data.get('environment_data')
-
-        try:
-            stack_preview = api.heat.stack_preview(self.request, **fields)
-            request.method = 'GET'
-            return self.next_view.as_view()(request,
-                                            stack_preview=stack_preview)
-        except Exception:
-            exceptions.handle(request)
+        except Exception as e:
+            msg = exception_to_validation_msg(e)
+            exceptions.handle(request, msg or _('Stack update failed.'))
