@@ -12,10 +12,11 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+from django.core import urlresolvers
 from django.http import Http404  # noqa
-from django.template.defaultfilters import timesince  # noqa
 from django.template.defaultfilters import title  # noqa
-from django.utils.translation import ugettext_lazy as _  # noqa
+from django.utils.http import urlencode  # noqa
+from django.utils.translation import ugettext_lazy as _
 
 from horizon import messages
 from horizon import tables
@@ -34,10 +35,20 @@ class LaunchStack(tables.LinkAction):
     classes = ("btn-create", "ajax-modal")
 
 
+class ChangeStackTemplate(tables.LinkAction):
+    name = "edit"
+    verbose_name = _("Change Stack Template")
+    url = "horizon:project:stacks:change_template"
+    classes = ("ajax-modal", "btn-edit")
+
+    def get_link_url(self, stack):
+        return urlresolvers.reverse(self.url, args=[stack.id])
+
+
 class DeleteStack(tables.BatchAction):
     name = "delete"
     action_present = _("Delete")
-    action_past = _("Scheduled deletion of")
+    action_past = _("Scheduled deletion of %(data_type)s")
     data_type_singular = _("Stack")
     data_type_plural = _("Stacks")
     classes = ('btn-danger', 'btn-terminate')
@@ -45,10 +56,18 @@ class DeleteStack(tables.BatchAction):
     def action(self, request, stack_id):
         api.heat.stack_delete(request, stack_id)
 
+    def allowed(self, request, stack):
+        if stack is not None:
+            return stack.stack_status != 'DELETE_COMPLETE'
+        return True
+
 
 class StacksUpdateRow(tables.Row):
     ajax = True
 
+    def can_be_selected(self, datum):
+        return datum.stack_status != 'DELETE_COMPLETE'
+
     def get_data(self, request, stack_id):
         try:
             return api.heat.stack_get(request, stack_id)
@@ -62,21 +81,21 @@ class StacksUpdateRow(tables.Row):
 
 class StacksTable(tables.DataTable):
     STATUS_CHOICES = (
-        ("Create Complete", True),
-        ("Update Complete", True),
-        ("Create Failed", False),
-        ("Update Failed", False),
+        ("Complete", True),
+        ("Failed", False),
     )
     name = tables.Column("stack_name",
                          verbose_name=_("Stack Name"),
                          link="horizon:project:stacks:detail",)
     created = tables.Column("creation_time",
                             verbose_name=_("Created"),
-                            filters=(filters.parse_isotime, timesince))
+                            filters=(filters.parse_isotime,
+                                     filters.timesince_or_never))
     updated = tables.Column("updated_time",
                             verbose_name=_("Updated"),
-                            filters=(filters.parse_isotime, timesince))
-    status = tables.Column("stack_status",
+                            filters=(filters.parse_isotime,
+                                     filters.timesince_or_never))
+    status = tables.Column("status",
                            filters=(title, filters.replace_underscores),
                            verbose_name=_("Status"),
                            status=True,
@@ -91,7 +110,8 @@ class StacksTable(tables.DataTable):
         status_columns = ["status", ]
         row_class = StacksUpdateRow
         table_actions = (LaunchStack, DeleteStack,)
-        row_actions = (DeleteStack, )
+        row_actions = (DeleteStack,
+                       ChangeStackTemplate)
 
 
 class EventsTable(tables.DataTable):
@@ -104,7 +124,8 @@ class EventsTable(tables.DataTable):
                                       link=mappings.resource_to_url)
     timestamp = tables.Column('event_time',
                               verbose_name=_("Time Since Event"),
-                              filters=(filters.parse_isotime, timesince))
+                              filters=(filters.parse_isotime,
+                                       filters.timesince_or_never))
     status = tables.Column("resource_status",
                            filters=(title, filters.replace_underscores),
                            verbose_name=_("Status"),)
@@ -150,7 +171,8 @@ class ResourcesTable(tables.DataTable):
                            verbose_name=_("Stack Resource Type"),)
     updated_time = tables.Column('updated_time',
                               verbose_name=_("Date Updated"),
-                              filters=(filters.parse_isotime, timesince))
+                              filters=(filters.parse_isotime,
+                                       filters.timesince_or_never))
     status = tables.Column("resource_status",
                            filters=(title, filters.replace_underscores),
                            verbose_name=_("Status"),
