@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2012 Nebula, Inc.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -12,18 +14,17 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ugettext_lazy as _
 
 import horizon
 
+from openstack_dashboard.dashboards.project import dashboard
+
 
 class Volumes(horizon.Panel):
     name = _("Volumes")
     slug = 'volumes'
-    permissions = (
-        ('openstack.services.block-storage',
-         'openstack.services.block-store',
-         'openstack.services.volume',
-         'openstack.services.volumev3'),
-    )
-    policy_rules = (("volume", "volume:get_all"),)
+    permissions = ('openstack.services.volume',)
+
+
+dashboard.Project.register(Volumes)
