@@ -15,7 +15,7 @@
 # @author: Abishek Subramanian, Cisco Systems, Inc.
 # @author: Sergey Sudakovich,   Cisco Systems, Inc.
 
-from django.utils.translation import ugettext_lazy as _  # noqa
+from django.utils.translation import ugettext_lazy as _
 
 import horizon
 from openstack_dashboard.api import neutron as neutron
