@@ -23,7 +23,7 @@ import os
 import sys
 import warnings
 
-from django.utils.translation import ugettext_lazy as _  # noqa
+from django.utils.translation import ugettext_lazy as _
 
 from openstack_dashboard import exceptions
 
@@ -145,7 +145,7 @@ COMPRESS_OUTPUT_DIR = 'dashboard'
 COMPRESS_CSS_HASHING_METHOD = 'hash'
 COMPRESS_PARSER = 'compressor.parser.HtmlParser'
 
-INSTALLED_APPS = (
+INSTALLED_APPS = [
     'openstack_dashboard',
     'django.contrib.contenttypes',
     'django.contrib.auth',
@@ -155,12 +155,8 @@ INSTALLED_APPS = (
     'django.contrib.humanize',
     'compressor',
     'horizon',
-    'openstack_dashboard.dashboards.project',
-    'openstack_dashboard.dashboards.admin',
-    'openstack_dashboard.dashboards.settings',
     'openstack_auth',
-    'openstack_dashboard.dashboards.router',
-)
+]
 
 TEST_RUNNER = 'django_nose.NoseTestSuiteRunner'
 AUTHENTICATION_BACKENDS = ('openstack_auth.backend.KeystoneBackend',)
@@ -172,21 +168,30 @@ SESSION_EXPIRE_AT_BROWSER_CLOSE = True
 SESSION_COOKIE_SECURE = False
 SESSION_TIMEOUT = 1800
 
-gettext_noop = lambda s: s
+# When using cookie-based sessions, log error when the session cookie exceeds
+# the following size (common browsers drop cookies above a certain size):
+SESSION_COOKIE_MAX_SIZE = 4093
+
+# when doing upgrades, it may be wise to stick to PickleSerializer
+# TODO(mrunge): remove after Icehouse
+SESSION_SERIALIZER = 'django.contrib.sessions.serializers.PickleSerializer'
+
 LANGUAGES = (
-    ('en', gettext_noop('English')),
-    ('en-au', gettext_noop('Australian English')),
-    ('en-gb', gettext_noop('British English')),
-    ('es', gettext_noop('Spanish')),
-    ('fr', gettext_noop('French')),
-    ('ja', gettext_noop('Japanese')),
-    ('ko', gettext_noop('Korean (Korea)')),
-    ('nl', gettext_noop('Dutch (Netherlands)')),
-    ('pl', gettext_noop('Polish')),
-    ('pt-br', gettext_noop('Portuguese (Brazil)')),
-    ('ru', gettext_noop('Russian')),
-    ('zh-cn', gettext_noop('Simplified Chinese')),
-    ('zh-tw', gettext_noop('Traditional Chinese')),
+    ('de', 'German'),
+    ('en', 'English'),
+    ('en-au', 'Australian English'),
+    ('en-gb', 'British English'),
+    ('es', 'Spanish'),
+    ('fr', 'French'),
+    ('hi', 'Hindi'),
+    ('ja', 'Japanese'),
+    ('ko', 'Korean (Korea)'),
+    ('nl', 'Dutch (Netherlands)'),
+    ('pl', 'Polish'),
+    ('pt-br', 'Portuguese (Brazil)'),
+    ('sr', 'Serbian'),
+    ('zh-cn', 'Simplified Chinese'),
+    ('zh-tw', 'Chinese (Taiwan)'),
 )
 LANGUAGE_CODE = 'en'
 LANGUAGE_COOKIE_NAME = 'horizon_language'
@@ -194,7 +199,7 @@ USE_I18N = True
 USE_L10N = True
 USE_TZ = True
 
-OPENSTACK_KEYSTONE_DEFAULT_ROLE = 'Member'
+OPENSTACK_KEYSTONE_DEFAULT_ROLE = '_member_'
 
 DEFAULT_EXCEPTION_REPORTER_FILTER = 'horizon.exceptions.HorizonReporterFilter'
 
@@ -202,23 +207,39 @@ POLICY_FILES_PATH = os.path.join(ROOT_PATH, "conf")
 # Map of local copy of service policy files
 POLICY_FILES = {
     'identity': 'keystone_policy.json',
-    'compute': 'nova_policy.json'
+    'compute': 'nova_policy.json',
+    'volume': 'cinder_policy.json',
+    'image': 'glance_policy.json',
 }
 
 SECRET_KEY = None
+LOCAL_PATH = None
 
 try:
     from local.local_settings import *  # noqa
 except ImportError:
     logging.warning("No local_settings file found.")
 
+# Load the pluggable dashboard settings
+import openstack_dashboard.enabled
+import openstack_dashboard.local.enabled
+from openstack_dashboard.utils import settings
+
+INSTALLED_APPS = list(INSTALLED_APPS)  # Make sure it's mutable
+settings.update_dashboards([
+    openstack_dashboard.enabled,
+    openstack_dashboard.local.enabled,
+], HORIZON_CONFIG, INSTALLED_APPS)
+
 # Ensure that we always have a SECRET_KEY set, even when no local_settings.py
 # file is present. See local_settings.py.example for full documentation on the
 # horizon.utils.secret_key module and its use.
 if not SECRET_KEY:
+    if not LOCAL_PATH:
+        LOCAL_PATH = os.path.join(os.path.dirname(os.path.abspath(__file__)),
+                                  'local')
+
     from horizon.utils import secret_key
-    LOCAL_PATH = os.path.join(os.path.dirname(os.path.abspath(__file__)),
-                              'local')
     SECRET_KEY = secret_key.generate_or_read_from_file(os.path.join(LOCAL_PATH,
                                                        '.secret_key_store'))
 
@@ -233,3 +254,10 @@ COMPRESS_OFFLINE_CONTEXT = {
 
 if DEBUG:
     logging.basicConfig(level=logging.DEBUG)
+
+# during django reloads and an active user is logged in, the monkey
+# patch below will not otherwise be applied in time - resulting in developers
+# appearing to be logged out.  In typical production deployments this section
+# below may be ommited, though it should not be harmful
+from openstack_auth import utils as auth_utils
+auth_utils.patch_middleware_get_user()
