@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2012 United States Government as represented by the
 # Administrator of the National Aeronautics and Space Administration.
 # All Rights Reserved.
@@ -18,7 +20,7 @@
 
 from __future__ import absolute_import
 
-from mox3.mox import IsA  # noqa
+from mox import IsA  # noqa
 
 from horizon import exceptions
 
@@ -37,7 +39,7 @@ class SwiftApiTests(test.APITestCase):
         self.mox.ReplayAll()
 
         (conts, more) = api.swift.swift_get_containers(self.request)
-        self.assertEqual(len(containers), len(conts))
+        self.assertEqual(len(conts), len(containers))
         self.assertFalse(more)
 
     def test_swift_get_container_with_data(self):
@@ -49,8 +51,8 @@ class SwiftApiTests(test.APITestCase):
         self.mox.ReplayAll()
 
         cont = api.swift.swift_get_container(self.request, container.name)
-        self.assertEqual(container.name, cont.name)
-        self.assertEqual(len(objects), len(cont.data))
+        self.assertEqual(cont.name, container.name)
+        self.assertEqual(len(cont.data), len(objects))
 
     def test_swift_get_container_without_data(self):
         container = self.containers.first()
@@ -68,7 +70,7 @@ class SwiftApiTests(test.APITestCase):
         metadata = {'is_public': False}
         container = self.containers.first()
         headers = api.swift._metadata_to_header(metadata=(metadata))
-        swift_api = self.stub_swiftclient()
+        swift_api = self.stub_swiftclient(expected_calls=2)
         # Check for existence, then create
         exc = self.exceptions.swift
         swift_api.head_container(container.name).AndRaise(exc)
@@ -120,38 +122,23 @@ class SwiftApiTests(test.APITestCase):
 
         (objs, more) = api.swift.swift_get_objects(self.request,
                                                    container.name)
-        self.assertEqual(len(objects), len(objs))
+        self.assertEqual(len(objs), len(objects))
         self.assertFalse(more)
 
-    def test_swift_get_object_with_data_non_chunked(self):
+    def test_swift_get_object_with_data(self):
         container = self.containers.first()
         object = self.objects.first()
 
         swift_api = self.stub_swiftclient()
-        swift_api.get_object(
-            container.name, object.name, resp_chunk_size=None
-        ).AndReturn([object, object.data])
+        swift_api.get_object(container.name, object.name) \
+            .AndReturn([object, object.data])
 
         self.mox.ReplayAll()
 
-        obj = api.swift.swift_get_object(self.request, container.name,
-                                         object.name, resp_chunk_size=None)
-        self.assertEqual(object.name, obj.name)
-
-    def test_swift_get_object_with_data_chunked(self):
-        container = self.containers.first()
-        object = self.objects.first()
-
-        swift_api = self.stub_swiftclient()
-        swift_api.get_object(
-            container.name, object.name, resp_chunk_size=api.swift.CHUNK_SIZE
-        ).AndReturn([object, object.data])
-
-        self.mox.ReplayAll()
-
-        obj = api.swift.swift_get_object(
-            self.request, container.name, object.name)
-        self.assertEqual(object.name, obj.name)
+        obj = api.swift.swift_get_object(self.request,
+                                         container.name,
+                                         object.name)
+        self.assertEqual(obj.name, object.name)
 
     def test_swift_get_object_without_data(self):
         container = self.containers.first()
@@ -167,37 +154,9 @@ class SwiftApiTests(test.APITestCase):
                                          container.name,
                                          object.name,
                                          with_data=False)
-        self.assertEqual(object.name, obj.name)
+        self.assertEqual(obj.name, object.name)
         self.assertIsNone(obj.data)
 
-    def test_swift_create_pseudo_folder(self):
-        container = self.containers.first()
-        folder = self.folder.first()
-        swift_api = self.stub_swiftclient()
-        exc = self.exceptions.swift
-        swift_api.head_object(container.name, folder.name).AndRaise(exc)
-        swift_api.put_object(container.name,
-                             folder.name,
-                             None,
-                             headers={}).AndReturn(folder)
-        self.mox.ReplayAll()
-        # Verification handled by mox, no assertions needed.
-        api.swift.swift_create_pseudo_folder(self.request,
-                                             container.name,
-                                             folder.name)
-
-    def test_swift_create_duplicate_folder(self):
-        container = self.containers.first()
-        folder = self.folder.first()
-        swift_api = self.stub_swiftclient()
-        swift_api.head_object(container.name, folder.name).AndReturn(folder)
-        self.mox.ReplayAll()
-        # Verification handled by mox, no assertions needed.
-        with self.assertRaises(exceptions.AlreadyExists):
-            api.swift.swift_create_pseudo_folder(self.request,
-                                                 container.name,
-                                                 folder.name)
-
     def test_swift_upload_object(self):
         container = self.containers.first()
         obj = self.objects.first()
@@ -212,54 +171,25 @@ class SwiftApiTests(test.APITestCase):
         headers = {'X-Object-Meta-Orig-Filename': fake_name}
 
         swift_api = self.stub_swiftclient()
-        exc = self.exceptions.swift
-        swift_api.head_object(container.name, obj.name).AndRaise(exc)
-        test_file = FakeFile()
         swift_api.put_object(container.name,
                              obj.name,
                              IsA(FakeFile),
-                             content_length=test_file.size,
                              headers=headers)
         self.mox.ReplayAll()
 
         api.swift.swift_upload_object(self.request,
                                       container.name,
                                       obj.name,
-                                      test_file)
-
-    def test_swift_upload_duplicate_object(self):
-        container = self.containers.first()
-        obj = self.objects.first()
-        fake_name = 'fake_object.jpg'
-
-        class FakeFile(object):
-            def __init__(self):
-                self.name = fake_name
-                self.data = obj.data
-                self.size = len(obj.data)
-
-        swift_api = self.stub_swiftclient()
-        swift_api.head_object(container.name, obj.name).AndReturn(obj)
-        test_file = FakeFile()
-        self.mox.ReplayAll()
-
-        with self.assertRaises(exceptions.AlreadyExists):
-            api.swift.swift_upload_object(self.request,
-                                          container.name,
-                                          obj.name,
-                                          test_file)
+                                      FakeFile())
 
     def test_swift_upload_object_without_file(self):
         container = self.containers.first()
         obj = self.objects.first()
 
         swift_api = self.stub_swiftclient()
-        exc = self.exceptions.swift
-        swift_api.head_object(container.name, obj.name).AndRaise(exc)
         swift_api.put_object(container.name,
                              obj.name,
                              None,
-                             content_length=0,
                              headers={})
         self.mox.ReplayAll()
 
@@ -273,7 +203,7 @@ class SwiftApiTests(test.APITestCase):
         container = self.containers.first()
         obj = self.objects.first()
 
-        swift_api = self.stub_swiftclient()
+        swift_api = self.stub_swiftclient(expected_calls=2)
         swift_api.head_object(container.name, obj.name).AndReturn(container)
 
         exc = self.exceptions.swift
