@@ -21,10 +21,11 @@
 from functools import wraps  # noqa
 import os
 
-from django.conf import settings  # noqa
+from django.conf import settings
 from django.contrib.auth.middleware import AuthenticationMiddleware  # noqa
 from django.contrib.messages.storage import default_storage  # noqa
 from django.core.handlers import wsgi
+from django.core import urlresolvers
 from django import http
 from django.test.client import RequestFactory  # noqa
 from django.utils.importlib import import_module  # noqa
@@ -38,11 +39,8 @@ from keystoneclient.v2_0 import client as keystone_client
 from neutronclient.v2_0 import client as neutron_client
 from novaclient.v1_1 import client as nova_client
 from swiftclient import client as swift_client
-try:
-    from troveclient import client as trove_client
-    with_trove = True
-except ImportError:
-    with_trove = False
+from troveclient import client as trove_client
+
 
 import httplib2
 import mox
@@ -50,6 +48,8 @@ import mox
 from openstack_auth import user
 from openstack_auth import utils
 
+from horizon import base
+from horizon import conf
 from horizon import middleware
 from horizon.test import helpers as horizon_helpers
 
@@ -104,14 +104,14 @@ class RequestFactoryWithMessages(RequestFactory):
 @unittest.skipIf(os.environ.get('SKIP_UNITTESTS', False),
                      "The SKIP_UNITTESTS env variable is set.")
 class TestCase(horizon_helpers.TestCase):
-    """
-    Specialized base test case class for Horizon which gives access to
+    """Specialized base test case class for Horizon which gives access to
     numerous additional features:
 
       * A full suite of test data through various attached objects and
         managers (e.g. ``self.servers``, ``self.user``, etc.). See the
-        docs for :class:`~horizon.tests.test_data.utils.TestData` for more
-        information.
+        docs for
+        :class:`~openstack_dashboard.test.test_data.utils.TestData`
+        for more information.
       * The ``mox`` mocking framework via ``self.mox``.
       * A set of request context data via ``self.context``.
       * A ``RequestFactory`` class which supports Django's ``contrib.messages``
@@ -176,8 +176,7 @@ class TestCase(horizon_helpers.TestCase):
         utils.get_user = get_user
 
     def assertRedirectsNoFollow(self, response, expected_url):
-        """
-        Asserts that the given response issued a 302 redirect without
+        """Asserts that the given response issued a 302 redirect without
         processing the view which is redirected to.
         """
         assert (response.status_code / 100 == 3), \
@@ -187,8 +186,7 @@ class TestCase(horizon_helpers.TestCase):
         self.assertEqual(response.status_code, 302)
 
     def assertNoFormErrors(self, response, context_name="form"):
-        """
-        Asserts that the response either does not contain a form in it's
+        """Asserts that the response either does not contain a form in its
         context, or that if it does, that form has no errors.
         """
         context = getattr(response, "context", {})
@@ -200,8 +198,7 @@ class TestCase(horizon_helpers.TestCase):
 
     def assertFormErrors(self, response, count=0, message=None,
                          context_name="form"):
-        """
-        Asserts that the response does contain a form in it's
+        """Asserts that the response does contain a form in its
         context, and that form has errors, if count were given,
         it must match the exact numbers of errors
         """
@@ -222,8 +219,7 @@ class TestCase(horizon_helpers.TestCase):
 
 
 class BaseAdminViewTests(TestCase):
-    """
-    A ``TestCase`` subclass which sets an active user with the "admin" role
+    """A ``TestCase`` subclass which sets an active user with the "admin" role
     for testing admin-only views and functionality.
     """
     def setActiveUser(self, *args, **kwargs):
@@ -244,8 +240,7 @@ class BaseAdminViewTests(TestCase):
 
 
 class APITestCase(TestCase):
-    """
-    The ``APITestCase`` class is for use with tests which deal with the
+    """The ``APITestCase`` class is for use with tests which deal with the
     underlying clients rather than stubbing out the
     openstack_dashboard.api.* methods.
     """
@@ -254,8 +249,7 @@ class APITestCase(TestCase):
         utils.patch_middleware_get_user()
 
         def fake_keystoneclient(request, admin=False):
-            """
-            Wrapper function which returns the stub keystoneclient. Only
+            """Wrapper function which returns the stub keystoneclient. Only
             necessary because the function takes too many arguments to
             conveniently be a lambda.
             """
@@ -269,8 +263,7 @@ class APITestCase(TestCase):
         self._original_cinderclient = api.cinder.cinderclient
         self._original_heatclient = api.heat.heatclient
         self._original_ceilometerclient = api.ceilometer.ceilometerclient
-        if with_trove:
-            self._original_troveclient = api.trove.troveclient
+        self._original_troveclient = api.trove.troveclient
 
         # Replace the clients with our stubs.
         api.glance.glanceclient = lambda request: self.stub_glanceclient()
@@ -281,8 +274,7 @@ class APITestCase(TestCase):
         api.heat.heatclient = lambda request: self.stub_heatclient()
         api.ceilometer.ceilometerclient = lambda request: \
             self.stub_ceilometerclient()
-        if with_trove:
-            api.trove.troveclient = lambda request: self.stub_troveclient()
+        api.trove.troveclient = lambda request: self.stub_troveclient()
 
     def tearDown(self):
         super(APITestCase, self).tearDown()
@@ -293,8 +285,7 @@ class APITestCase(TestCase):
         api.cinder.cinderclient = self._original_cinderclient
         api.heat.heatclient = self._original_heatclient
         api.ceilometer.ceilometerclient = self._original_ceilometerclient
-        if with_trove:
-            api.trove.troveclient = self._original_troveclient
+        api.trove.troveclient = self._original_troveclient
 
     def stub_novaclient(self):
         if not hasattr(self, "novaclient"):
@@ -362,12 +353,11 @@ class APITestCase(TestCase):
                 CreateMock(ceilometer_client.Client)
         return self.ceilometerclient
 
-    if with_trove:
-        def stub_troveclient(self):
-            if not hasattr(self, "troveclient"):
-                self.mox.StubOutWithMock(trove_client, 'Client')
-                self.troveclient = self.mox.CreateMock(trove_client.Client)
-            return self.troveclient
+    def stub_troveclient(self):
+        if not hasattr(self, "troveclient"):
+            self.mox.StubOutWithMock(trove_client, 'Client')
+            self.troveclient = self.mox.CreateMock(trove_client.Client)
+        return self.troveclient
 
 
 @unittest.skipUnless(os.environ.get('WITH_SELENIUM', False),
@@ -412,11 +402,70 @@ class SeleniumTestCase(horizon_helpers.SeleniumTestCase):
 
 
 class SeleniumAdminTestCase(SeleniumTestCase):
-    """
-    A ``TestCase`` subclass which sets an active user with the "admin" role
+    """A ``TestCase`` subclass which sets an active user with the "admin" role
     for testing admin-only views and functionality.
     """
     def setActiveUser(self, *args, **kwargs):
         if "roles" not in kwargs:
             kwargs['roles'] = [self.roles.admin._info]
         super(SeleniumAdminTestCase, self).setActiveUser(*args, **kwargs)
+
+
+def my_custom_sort(flavor):
+    sort_order = {
+        'm1.secret': 0,
+        'm1.tiny': 1,
+        'm1.massive': 2,
+    }
+    return sort_order[flavor.name]
+
+
+class PluginTestCase(TestCase):
+    """The ``PluginTestCase`` class is for use with tests which deal with the
+    pluggable dashboard and panel configuration, it takes care of backing up
+    and restoring the Horizon configuration.
+    """
+    def setUp(self):
+        super(PluginTestCase, self).setUp()
+        self.old_horizon_config = conf.HORIZON_CONFIG
+        conf.HORIZON_CONFIG = conf.LazySettings()
+        base.Horizon._urls()
+        # Trigger discovery, registration, and URLconf generation if it
+        # hasn't happened yet.
+        self.client.get("/")
+        # Store our original dashboards
+        self._discovered_dashboards = base.Horizon._registry.keys()
+        # Gather up and store our original panels for each dashboard
+        self._discovered_panels = {}
+        for dash in self._discovered_dashboards:
+            panels = base.Horizon._registry[dash]._registry.keys()
+            self._discovered_panels[dash] = panels
+
+    def tearDown(self):
+        super(PluginTestCase, self).tearDown()
+        conf.HORIZON_CONFIG = self.old_horizon_config
+        # Destroy our singleton and re-create it.
+        base.HorizonSite._instance = None
+        del base.Horizon
+        base.Horizon = base.HorizonSite()
+        # Reload the convenience references to Horizon stored in __init__
+        reload(import_module("horizon"))
+        # Re-register our original dashboards and panels.
+        # This is necessary because autodiscovery only works on the first
+        # import, and calling reload introduces innumerable additional
+        # problems. Manual re-registration is the only good way for testing.
+        for dash in self._discovered_dashboards:
+            base.Horizon.register(dash)
+            for panel in self._discovered_panels[dash]:
+                dash.register(panel)
+        self._reload_urls()
+
+    def _reload_urls(self):
+        """Clears out the URL caches, reloads the root urls module, and
+        re-triggers the autodiscovery mechanism for Horizon. Allows URLs
+        to be re-calculated after registering new dashboards. Useful
+        only for testing and should never be used on a live site.
+        """
+        urlresolvers.clear_url_caches()
+        reload(import_module(settings.ROOT_URLCONF))
+        base.Horizon._urls()
