@@ -12,14 +12,16 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import ceilometerclient.exc as ceilometer_exceptions
+from cinderclient import exceptions as cinder_exceptions
 import glanceclient.exc as glance_exceptions
 from keystoneclient import exceptions as keystone_exceptions
+from neutronclient.common import exceptions as neutron_exceptions
 from novaclient import exceptions as nova_exceptions
-from quantumclient.common import exceptions as quantum_exceptions
 from swiftclient import client as swift_exceptions
-from cinderclient import exceptions as cinder_exceptions
+from troveclient import exceptions as trove_exceptions
 
-from .utils import TestDataContainer
+from openstack_dashboard.test.test_data import utils
 
 
 def create_stubbed_exception(cls, status_code=500):
@@ -43,7 +45,7 @@ def create_stubbed_exception(cls, status_code=500):
 
 
 def data(TEST):
-    TEST.exceptions = TestDataContainer()
+    TEST.exceptions = utils.TestDataContainer()
 
     unauth = keystone_exceptions.Unauthorized
     TEST.exceptions.keystone_unauthorized = create_stubbed_exception(unauth)
@@ -60,11 +62,21 @@ def data(TEST):
     glance_exception = glance_exceptions.ClientException
     TEST.exceptions.glance = create_stubbed_exception(glance_exception)
 
-    quantum_exception = quantum_exceptions.QuantumClientException
-    TEST.exceptions.quantum = create_stubbed_exception(quantum_exception)
+    ceilometer_exception = ceilometer_exceptions.ClientException
+    TEST.exceptions.ceilometer = create_stubbed_exception(ceilometer_exception)
+
+    neutron_exception = neutron_exceptions.NeutronClientException
+    TEST.exceptions.neutron = create_stubbed_exception(neutron_exception)
 
     swift_exception = swift_exceptions.ClientException
     TEST.exceptions.swift = create_stubbed_exception(swift_exception)
 
     cinder_exception = cinder_exceptions.BadRequest
     TEST.exceptions.cinder = create_stubbed_exception(cinder_exception)
+
+    trove_exception = trove_exceptions.ClientException
+    TEST.exceptions.trove = create_stubbed_exception(trove_exception)
+
+    trove_auth = trove_exceptions.Unauthorized
+    TEST.exceptions.trove_unauthorized =  \
+        create_stubbed_exception(trove_auth)
