@@ -1,6 +1,6 @@
 # vim: tabstop=4 shiftwidth=4 softtabstop=4
 
-# Copyright (c) 2012 OpenStack, LLC.
+# Copyright (c) 2012 OpenStack Foundation
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -23,7 +23,7 @@ from openstack_dashboard.test import helpers as test
 
 
 class ErrorPageTests(test.TestCase):
-    """ Tests for error pages """
+    """Tests for error pages."""
     urls = 'openstack_dashboard.test.error_pages_urls'
 
     def test_500_error(self):
