@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright (c) 2013 OpenStack Foundation
 # All Rights Reserved.
 #
@@ -13,7 +15,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo_utils import uuidutils
+import uuid
 
 from openstack_dashboard.test import helpers as test
 from openstack_dashboard.utils import filters
@@ -31,7 +33,7 @@ class UtilsFilterTests(test.TestCase):
         self.assertEqual(int(val), ret)
 
     def test_accept_valid_uuid(self):
-        val = uuidutils.generate_uuid()
+        val = str(uuid.uuid4())
         ret = filters.get_int_or_uuid(val)
         self.assertEqual(val, ret)
 
