@@ -22,11 +22,11 @@
 URL patterns for the OpenStack Dashboard.
 """
 
-from django.conf import settings  # noqa
-from django.conf.urls.defaults import include  # noqa
-from django.conf.urls.defaults import patterns  # noqa
-from django.conf.urls.defaults import url  # noqa
+from django.conf import settings
+from django.conf.urls import include  # noqa
+from django.conf.urls import patterns  # noqa
 from django.conf.urls.static import static  # noqa
+from django.conf.urls import url  # noqa
 from django.contrib.staticfiles.urls import staticfiles_urlpatterns  # noqa
 
 import horizon
