@@ -14,6 +14,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from .base import BaseUsage, TenantUsage, GlobalUsage, almost_now
-from .views import UsageView
-from .tables import BaseUsageTable, TenantUsageTable, GlobalUsageTable
+# Importing non-modules that are not used explicitly
+
+from openstack_dashboard.usage.base import BaseUsage  # noqa
+from openstack_dashboard.usage.base import GlobalUsage  # noqa
+from openstack_dashboard.usage.base import ProjectUsage  # noqa
+from openstack_dashboard.usage.tables import BaseUsageTable  # noqa
+from openstack_dashboard.usage.tables import GlobalUsageTable  # noqa
+from openstack_dashboard.usage.tables import ProjectUsageTable  # noqa
+from openstack_dashboard.usage.views import UsageView  # noqa
