@@ -1,10 +1,23 @@
+# Licensed under the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License. You may obtain
+# a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+# License for the specific language governing permissions and limitations
+# under the License.
+
 from django.core import urlresolvers
 from django.template.defaultfilters import floatformat  # noqa
 from django.template.defaultfilters import timesince  # noqa
-from django.utils.translation import ugettext_lazy as _  # noqa
+from django.utils.translation import ugettext_lazy as _
 
 from horizon import tables
 from horizon.templatetags import sizeformat
+from horizon.utils import filters
 
 
 class CSVSummary(tables.LinkAction):
@@ -38,7 +51,7 @@ class GlobalUsageTable(BaseUsageTable):
 
     class Meta:
         name = "global_usage"
-        verbose_name = _("Usage Summary")
+        verbose_name = _("Usage")
         columns = ("project", "vcpus", "disk", "memory",
                    "hours", "disk_hours")
         table_actions = (CSVSummary,)
@@ -59,14 +72,15 @@ class ProjectUsageTable(BaseUsageTable):
                              link=get_instance_link)
     uptime = tables.Column('uptime_at',
                            verbose_name=_("Uptime"),
-                           filters=(timesince,))
+                           filters=(filters.timesince_sortable,),
+                           attrs={'data-type': 'timesince'})
 
     def get_object_id(self, datum):
         return datum.get('instance_id', id(datum))
 
     class Meta:
         name = "project_usage"
-        verbose_name = _("Usage Summary")
+        verbose_name = _("Usage")
         columns = ("instance", "vcpus", "disk", "memory", "uptime")
         table_actions = (CSVSummary,)
         multi_select = False
