@@ -4,9 +4,9 @@ set -o errexit
 
 # ---------------UPDATE ME-------------------------------#
 # Increment me any time the environment should be rebuilt.
-# This includes dependncy changes, directory renames, etc.
-# Simple integer secuence: 1, 2, 3...
-environment_version=40
+# This includes dependency changes, directory renames, etc.
+# Simple integer sequence: 1, 2, 3...
+environment_version=42
 #--------------------------------------------------------#
 
 function usage {
@@ -22,15 +22,18 @@ function usage {
   echo "                           environment. Useful when dependencies have"
   echo "                           been added."
   echo "  -m, --manage             Run a Django management command."
-  echo "  --makemessages           Update all translation files."
+  echo "  --makemessages           Create/Update English translation files."
   echo "  --compilemessages        Compile all translation files."
   echo "  -p, --pep8               Just run pep8"
+  echo "  -P, --no-pep8            Don't run pep8 by default"
   echo "  -t, --tabs               Check for tab characters in files."
   echo "  -y, --pylint             Just run pylint"
   echo "  -q, --quiet              Run non-interactively. (Relatively) quiet."
   echo "                           Implies -V if -N is not set."
   echo "  --only-selenium          Run only the Selenium unit tests"
   echo "  --with-selenium          Run unit tests including Selenium tests"
+  echo "  --integration            Run the integration tests (requires a running "
+  echo "                           OpenStack environment)"
   echo "  --runserver              Run the Django development server for"
   echo "                           openstack_dashboard in the virtual"
   echo "                           environment."
@@ -49,7 +52,7 @@ function usage {
 
 # DEFAULTS FOR RUN_TESTS.SH
 #
-root=`pwd`
+root=`pwd -P`
 venv=$root/.venv
 with_venv=tools/with_venv.sh
 included_dirs="openstack_dashboard horizon"
@@ -60,6 +63,7 @@ command_wrapper=""
 destroy=0
 force=0
 just_pep8=0
+no_pep8=0
 just_pylint=0
 just_docs=0
 just_tabs=0
@@ -69,6 +73,7 @@ restore_env=0
 runserver=0
 only_selenium=0
 with_selenium=0
+integration=0
 testopts=""
 testargs=""
 with_coverage=0
@@ -91,6 +96,7 @@ function process_option {
     -V|--virtual-env) always_venv=1; never_venv=0;;
     -N|--no-virtual-env) always_venv=0; never_venv=1;;
     -p|--pep8) just_pep8=1;;
+    -P|--no-pep8) no_pep8=1;;
     -y|--pylint) just_pylint=1;;
     -f|--force) force=1;;
     -t|--tabs) just_tabs=1;;
@@ -101,6 +107,7 @@ function process_option {
     --compilemessages) compilemessages=1;;
     --only-selenium) only_selenium=1;;
     --with-selenium) with_selenium=1;;
+    --integration) integration=1;;
     --docs) just_docs=1;;
     --runserver) runserver=1;;
     --backup-environment) backup_env=1;;
@@ -137,6 +144,15 @@ function run_pylint {
 
 function run_pep8 {
   echo "Running flake8 ..."
+  set +o errexit
+  ${command_wrapper} python -c "import hacking" 2>/dev/null
+  no_hacking=$?
+  set -o errexit
+  if [ $never_venv -eq 1 -a $no_hacking -eq 1 ]; then
+      echo "**WARNING**:" >&2
+      echo "OpenStack hacking is not installed on your host. Its detection will be missed." >&2
+      echo "Please install or use virtual env if you need OpenStack hacking detection." >&2
+  fi
   DJANGO_SETTINGS_MODULE=openstack_dashboard.test.settings ${command_wrapper} flake8
 }
 
@@ -280,6 +296,10 @@ function run_tests {
     export SKIP_UNITTESTS=1
   fi
 
+  if [ $with_selenium -eq 0 -a $integration -eq 0 ]; then
+      testopts="$testopts --exclude-dir=openstack_dashboard/test/integration_tests"
+  fi
+
   if [ -z "$testargs" ]; then
      run_tests_all
   else
@@ -298,8 +318,11 @@ function run_tests_all {
   if [ "$NOSE_WITH_HTML_OUTPUT" = '1' ]; then
     export NOSE_HTML_OUT_FILE='horizon_nose_results.html'
   fi
-  ${command_wrapper} coverage erase
-  ${command_wrapper} coverage run -p $root/manage.py test horizon --settings=horizon.test.settings $testopts
+  if [ $with_coverage -eq 1 ]; then
+    ${command_wrapper} coverage erase
+    coverage_run="coverage run -p"
+  fi
+  ${command_wrapper} ${coverage_run} $root/manage.py test horizon --settings=horizon.test.settings $testopts
   # get results of the Horizon tests
   HORIZON_RESULT=$?
 
@@ -308,30 +331,45 @@ function run_tests_all {
   if [ "$NOSE_WITH_HTML_OUTPUT" = '1' ]; then
     export NOSE_HTML_OUT_FILE='dashboard_nose_results.html'
   fi
-  ${command_wrapper} coverage run -p $root/manage.py test openstack_dashboard --settings=openstack_dashboard.test.settings $testopts
+  ${command_wrapper} ${coverage_run} $root/manage.py test openstack_dashboard --settings=openstack_dashboard.test.settings $testopts
   # get results of the openstack_dashboard tests
   DASHBOARD_RESULT=$?
 
   if [ $with_coverage -eq 1 ]; then
     echo "Generating coverage reports"
     ${command_wrapper} coverage combine
-    ${command_wrapper} coverage xml -i --omit='/usr*,setup.py,*egg*,.venv/*'
-    ${command_wrapper} coverage html -i --omit='/usr*,setup.py,*egg*,.venv/*' -d reports
+    ${command_wrapper} coverage xml -i --include="horizon/*,openstack_dashboard/*" --omit='/usr*,setup.py,*egg*,.venv/*'
+    ${command_wrapper} coverage html -i --include="horizon/*,openstack_dashboard/*" --omit='/usr*,setup.py,*egg*,.venv/*' -d reports
   fi
   # Remove the leftover coverage files from the -p flag earlier.
   rm -f .coverage.*
 
-  if [ $(($HORIZON_RESULT || $DASHBOARD_RESULT)) -eq 0 ]; then
+  PEP8_RESULT=0
+  if [ $no_pep8 -eq 0 ] && [ $only_selenium -eq 0 ]; then
+      run_pep8
+      PEP8_RESULT=$?
+  fi
+
+  TEST_RESULT=$(($HORIZON_RESULT || $DASHBOARD_RESULT || $PEP8_RESULT))
+  if [ $TEST_RESULT -eq 0 ]; then
     echo "Tests completed successfully."
   else
     echo "Tests failed."
   fi
-  exit $(($HORIZON_RESULT || $DASHBOARD_RESULT))
+  exit $TEST_RESULT
+}
+
+function run_integration_tests {
+  export INTEGRATION_TESTS=1
+
+  echo "Running Horizon integration tests..."
+  ${command_wrapper} nosetests openstack_dashboard/test/integration_tests/tests
+  exit 0
 }
 
 function run_makemessages {
   OPTS="-l en --no-obsolete"
-  DASHBOARD_OPTS="--extension=html,txt,csv --ignore=openstack/common/*"
+  DASHBOARD_OPTS="--extension=html,txt,csv --ignore=openstack"
   echo -n "horizon: "
   cd horizon
   ${command_wrapper} $root/manage.py makemessages $OPTS
@@ -355,6 +393,9 @@ function run_compilemessages {
   ${command_wrapper} $root/manage.py compilemessages
   DASHBOARD_RESULT=$?
   cd ..
+  # English is the source language, so compiled catalogs are unnecessary.
+  rm -vf horizon/locale/en/LC_MESSAGES/django*.mo
+  rm -vf openstack_dashboard/locale/en/LC_MESSAGES/django.mo
   exit $(($HORIZON_PY_RESULT || $DASHBOARD_RESULT))
 }
 
@@ -443,6 +484,12 @@ if [ $just_tabs -eq 1 ]; then
     exit $?
 fi
 
+# Integration tests
+if [ $integration -eq 1 ]; then
+    run_integration_tests
+    exit $?
+fi
+
 # Django development server
 if [ $runserver -eq 1 ]; then
     run_server
